/* Autogen header for Unicorn Engine - DONOT MODIFY */
#ifndef UNICORN_AUTOGEN_X86_64_H
#define UNICORN_AUTOGEN_X86_64_H
#define arm_release arm_release_x86_64
#define aarch64_tb_set_jmp_target aarch64_tb_set_jmp_target_x86_64
#define ppc_tb_set_jmp_target ppc_tb_set_jmp_target_x86_64
#define use_idiv_instructions_rt use_idiv_instructions_rt_x86_64
#define tcg_target_deposit_valid tcg_target_deposit_valid_x86_64
#define helper_power_down helper_power_down_x86_64
#define check_exit_request check_exit_request_x86_64
#define address_space_unregister address_space_unregister_x86_64
#define tb_invalidate_phys_page_fast tb_invalidate_phys_page_fast_x86_64
#define phys_mem_clean phys_mem_clean_x86_64
#define tb_cleanup tb_cleanup_x86_64
#define memory_map memory_map_x86_64
#define memory_map_ptr memory_map_ptr_x86_64
#define memory_unmap memory_unmap_x86_64
#define memory_free memory_free_x86_64
#define free_code_gen_buffer free_code_gen_buffer_x86_64
#define helper_raise_exception helper_raise_exception_x86_64
#define tcg_enabled tcg_enabled_x86_64
#define tcg_exec_init tcg_exec_init_x86_64
#define memory_register_types memory_register_types_x86_64
#define cpu_exec_init_all cpu_exec_init_all_x86_64
#define vm_start vm_start_x86_64
#define resume_all_vcpus resume_all_vcpus_x86_64
#define a15_l2ctlr_read a15_l2ctlr_read_x86_64
#define a64_translate_init a64_translate_init_x86_64
#define aa32_generate_debug_exceptions aa32_generate_debug_exceptions_x86_64
#define aa64_cacheop_access aa64_cacheop_access_x86_64
#define aa64_daif_access aa64_daif_access_x86_64
#define aa64_daif_write aa64_daif_write_x86_64
#define aa64_dczid_read aa64_dczid_read_x86_64
#define aa64_fpcr_read aa64_fpcr_read_x86_64
#define aa64_fpcr_write aa64_fpcr_write_x86_64
#define aa64_fpsr_read aa64_fpsr_read_x86_64
#define aa64_fpsr_write aa64_fpsr_write_x86_64
#define aa64_generate_debug_exceptions aa64_generate_debug_exceptions_x86_64
#define aa64_zva_access aa64_zva_access_x86_64
#define aarch64_banked_spsr_index aarch64_banked_spsr_index_x86_64
#define aarch64_restore_sp aarch64_restore_sp_x86_64
#define aarch64_save_sp aarch64_save_sp_x86_64
#define accel_find accel_find_x86_64
#define accel_init_machine accel_init_machine_x86_64
#define accel_type accel_type_x86_64
#define access_with_adjusted_size access_with_adjusted_size_x86_64
#define add128 add128_x86_64
#define add16_sat add16_sat_x86_64
#define add16_usat add16_usat_x86_64
#define add192 add192_x86_64
#define add8_sat add8_sat_x86_64
#define add8_usat add8_usat_x86_64
#define add_cpreg_to_hashtable add_cpreg_to_hashtable_x86_64
#define add_cpreg_to_list add_cpreg_to_list_x86_64
#define addFloat128Sigs addFloat128Sigs_x86_64
#define addFloat32Sigs addFloat32Sigs_x86_64
#define addFloat64Sigs addFloat64Sigs_x86_64
#define addFloatx80Sigs addFloatx80Sigs_x86_64
#define add_qemu_ldst_label add_qemu_ldst_label_x86_64
#define address_space_access_valid address_space_access_valid_x86_64
#define address_space_destroy address_space_destroy_x86_64
#define address_space_destroy_dispatch address_space_destroy_dispatch_x86_64
#define address_space_get_flatview address_space_get_flatview_x86_64
#define address_space_init address_space_init_x86_64
#define address_space_init_dispatch address_space_init_dispatch_x86_64
#define address_space_lookup_region address_space_lookup_region_x86_64
#define address_space_map address_space_map_x86_64
#define address_space_read address_space_read_x86_64
#define address_space_rw address_space_rw_x86_64
#define address_space_translate address_space_translate_x86_64
#define address_space_translate_for_iotlb address_space_translate_for_iotlb_x86_64
#define address_space_translate_internal address_space_translate_internal_x86_64
#define address_space_unmap address_space_unmap_x86_64
#define address_space_update_topology address_space_update_topology_x86_64
#define address_space_update_topology_pass address_space_update_topology_pass_x86_64
#define address_space_write address_space_write_x86_64
#define addrrange_contains addrrange_contains_x86_64
#define addrrange_end addrrange_end_x86_64
#define addrrange_equal addrrange_equal_x86_64
#define addrrange_intersection addrrange_intersection_x86_64
#define addrrange_intersects addrrange_intersects_x86_64
#define addrrange_make addrrange_make_x86_64
#define adjust_endianness adjust_endianness_x86_64
#define all_helpers all_helpers_x86_64
#define alloc_code_gen_buffer alloc_code_gen_buffer_x86_64
#define alloc_entry alloc_entry_x86_64
#define always_true always_true_x86_64
#define arm1026_initfn arm1026_initfn_x86_64
#define arm1136_initfn arm1136_initfn_x86_64
#define arm1136_r2_initfn arm1136_r2_initfn_x86_64
#define arm1176_initfn arm1176_initfn_x86_64
#define arm11mpcore_initfn arm11mpcore_initfn_x86_64
#define arm926_initfn arm926_initfn_x86_64
#define arm946_initfn arm946_initfn_x86_64
#define arm_ccnt_enabled arm_ccnt_enabled_x86_64
#define arm_cp_read_zero arm_cp_read_zero_x86_64
#define arm_cp_reset_ignore arm_cp_reset_ignore_x86_64
#define arm_cpu_do_interrupt arm_cpu_do_interrupt_x86_64
#define arm_cpu_exec_interrupt arm_cpu_exec_interrupt_x86_64
#define arm_cpu_finalizefn arm_cpu_finalizefn_x86_64
#define arm_cpu_get_phys_page_debug arm_cpu_get_phys_page_debug_x86_64
#define arm_cpu_handle_mmu_fault arm_cpu_handle_mmu_fault_x86_64
#define arm_cpu_initfn arm_cpu_initfn_x86_64
#define arm_cpu_list arm_cpu_list_x86_64
#define cpu_loop_exit cpu_loop_exit_x86_64
#define arm_cpu_post_init arm_cpu_post_init_x86_64
#define arm_cpu_realizefn arm_cpu_realizefn_x86_64
#define arm_cpu_register_gdb_regs_for_features arm_cpu_register_gdb_regs_for_features_x86_64
#define arm_cpu_register_types arm_cpu_register_types_x86_64
#define cpu_resume_from_signal cpu_resume_from_signal_x86_64
#define arm_cpus arm_cpus_x86_64
#define arm_cpu_set_pc arm_cpu_set_pc_x86_64
#define arm_cp_write_ignore arm_cp_write_ignore_x86_64
#define arm_current_el arm_current_el_x86_64
#define arm_dc_feature arm_dc_feature_x86_64
#define arm_debug_excp_handler arm_debug_excp_handler_x86_64
#define arm_debug_target_el arm_debug_target_el_x86_64
#define arm_el_is_aa64 arm_el_is_aa64_x86_64
#define arm_env_get_cpu arm_env_get_cpu_x86_64
#define arm_excp_target_el arm_excp_target_el_x86_64
#define arm_excp_unmasked arm_excp_unmasked_x86_64
#define arm_feature arm_feature_x86_64
#define arm_generate_debug_exceptions arm_generate_debug_exceptions_x86_64
#define gen_intermediate_code gen_intermediate_code_x86_64
#define gen_intermediate_code_pc gen_intermediate_code_pc_x86_64
#define arm_gen_test_cc arm_gen_test_cc_x86_64
#define arm_gt_ptimer_cb arm_gt_ptimer_cb_x86_64
#define arm_gt_vtimer_cb arm_gt_vtimer_cb_x86_64
#define arm_handle_psci_call arm_handle_psci_call_x86_64
#define arm_is_psci_call arm_is_psci_call_x86_64
#define arm_is_secure arm_is_secure_x86_64
#define arm_is_secure_below_el3 arm_is_secure_below_el3_x86_64
#define arm_ldl_code arm_ldl_code_x86_64
#define arm_lduw_code arm_lduw_code_x86_64
#define arm_log_exception arm_log_exception_x86_64
#define arm_reg_read arm_reg_read_x86_64
#define arm_reg_reset arm_reg_reset_x86_64
#define arm_reg_write arm_reg_write_x86_64
#define restore_state_to_opc restore_state_to_opc_x86_64
#define arm_rmode_to_sf arm_rmode_to_sf_x86_64
#define arm_singlestep_active arm_singlestep_active_x86_64
#define tlb_fill tlb_fill_x86_64
#define tlb_flush tlb_flush_x86_64
#define tlb_flush_page tlb_flush_page_x86_64
#define tlb_set_page tlb_set_page_x86_64
#define arm_translate_init arm_translate_init_x86_64
#define arm_v7m_class_init arm_v7m_class_init_x86_64
#define arm_v7m_cpu_do_interrupt arm_v7m_cpu_do_interrupt_x86_64
#define ats_access ats_access_x86_64
#define ats_write ats_write_x86_64
#define bad_mode_switch bad_mode_switch_x86_64
#define bank_number bank_number_x86_64
#define bitmap_zero_extend bitmap_zero_extend_x86_64
#define bp_wp_matches bp_wp_matches_x86_64
#define breakpoint_invalidate breakpoint_invalidate_x86_64
#define build_page_bitmap build_page_bitmap_x86_64
#define bus_add_child bus_add_child_x86_64
#define bus_class_init bus_class_init_x86_64
#define bus_info bus_info_x86_64
#define bus_unparent bus_unparent_x86_64
#define cache_block_ops_cp_reginfo cache_block_ops_cp_reginfo_x86_64
#define cache_dirty_status_cp_reginfo cache_dirty_status_cp_reginfo_x86_64
#define cache_test_clean_cp_reginfo cache_test_clean_cp_reginfo_x86_64
#define call_recip_estimate call_recip_estimate_x86_64
#define can_merge can_merge_x86_64
#define capacity_increase capacity_increase_x86_64
#define ccsidr_read ccsidr_read_x86_64
#define check_ap check_ap_x86_64
#define check_breakpoints check_breakpoints_x86_64
#define check_watchpoints check_watchpoints_x86_64
#define cho cho_x86_64
#define clear_bit clear_bit_x86_64
#define clz32 clz32_x86_64
#define clz64 clz64_x86_64
#define cmp_flatrange_addr cmp_flatrange_addr_x86_64
#define code_gen_alloc code_gen_alloc_x86_64
#define commonNaNToFloat128 commonNaNToFloat128_x86_64
#define commonNaNToFloat16 commonNaNToFloat16_x86_64
#define commonNaNToFloat32 commonNaNToFloat32_x86_64
#define commonNaNToFloat64 commonNaNToFloat64_x86_64
#define commonNaNToFloatx80 commonNaNToFloatx80_x86_64
#define compute_abs_deadline compute_abs_deadline_x86_64
#define cond_name cond_name_x86_64
#define configure_accelerator configure_accelerator_x86_64
#define container_get container_get_x86_64
#define container_info container_info_x86_64
#define container_register_types container_register_types_x86_64
#define contextidr_write contextidr_write_x86_64
#define core_log_global_start core_log_global_start_x86_64
#define core_log_global_stop core_log_global_stop_x86_64
#define core_memory_listener core_memory_listener_x86_64
#define cortexa15_cp_reginfo cortexa15_cp_reginfo_x86_64
#define cortex_a15_initfn cortex_a15_initfn_x86_64
#define cortexa8_cp_reginfo cortexa8_cp_reginfo_x86_64
#define cortex_a8_initfn cortex_a8_initfn_x86_64
#define cortexa9_cp_reginfo cortexa9_cp_reginfo_x86_64
#define cortex_a9_initfn cortex_a9_initfn_x86_64
#define cortex_m3_initfn cortex_m3_initfn_x86_64
#define count_cpreg count_cpreg_x86_64
#define countLeadingZeros32 countLeadingZeros32_x86_64
#define countLeadingZeros64 countLeadingZeros64_x86_64
#define cp_access_ok cp_access_ok_x86_64
#define cpacr_write cpacr_write_x86_64
#define cpreg_field_is_64bit cpreg_field_is_64bit_x86_64
#define cp_reginfo cp_reginfo_x86_64
#define cpreg_key_compare cpreg_key_compare_x86_64
#define cpreg_make_keylist cpreg_make_keylist_x86_64
#define cp_reg_reset cp_reg_reset_x86_64
#define cpreg_to_kvm_id cpreg_to_kvm_id_x86_64
#define cpsr_read cpsr_read_x86_64
#define cpsr_write cpsr_write_x86_64
#define cptype_valid cptype_valid_x86_64
#define cpu_abort cpu_abort_x86_64
#define cpu_arm_exec cpu_arm_exec_x86_64
#define cpu_arm_gen_code cpu_arm_gen_code_x86_64
#define cpu_arm_init cpu_arm_init_x86_64
#define cpu_breakpoint_insert cpu_breakpoint_insert_x86_64
#define cpu_breakpoint_remove cpu_breakpoint_remove_x86_64
#define cpu_breakpoint_remove_all cpu_breakpoint_remove_all_x86_64
#define cpu_breakpoint_remove_by_ref cpu_breakpoint_remove_by_ref_x86_64
#define cpu_can_do_io cpu_can_do_io_x86_64
#define cpu_can_run cpu_can_run_x86_64
#define cpu_class_init cpu_class_init_x86_64
#define cpu_common_class_by_name cpu_common_class_by_name_x86_64
#define cpu_common_exec_interrupt cpu_common_exec_interrupt_x86_64
#define cpu_common_get_arch_id cpu_common_get_arch_id_x86_64
#define cpu_common_get_memory_mapping cpu_common_get_memory_mapping_x86_64
#define cpu_common_get_paging_enabled cpu_common_get_paging_enabled_x86_64
#define cpu_common_has_work cpu_common_has_work_x86_64
#define cpu_common_initfn cpu_common_initfn_x86_64
#define cpu_common_noop cpu_common_noop_x86_64
#define cpu_common_parse_features cpu_common_parse_features_x86_64
#define cpu_common_realizefn cpu_common_realizefn_x86_64
#define cpu_common_reset cpu_common_reset_x86_64
#define cpu_dump_statistics cpu_dump_statistics_x86_64
#define cpu_exec_init cpu_exec_init_x86_64
#define cpu_flush_icache_range cpu_flush_icache_range_x86_64
#define cpu_gen_init cpu_gen_init_x86_64
#define cpu_get_clock cpu_get_clock_x86_64
#define cpu_get_real_ticks cpu_get_real_ticks_x86_64
#define cpu_get_tb_cpu_state cpu_get_tb_cpu_state_x86_64
#define cpu_handle_debug_exception cpu_handle_debug_exception_x86_64
#define cpu_handle_guest_debug cpu_handle_guest_debug_x86_64
#define cpu_inb cpu_inb_x86_64
#define cpu_inl cpu_inl_x86_64
#define cpu_interrupt cpu_interrupt_x86_64
#define cpu_interrupt_handler cpu_interrupt_handler_x86_64
#define cpu_inw cpu_inw_x86_64
#define cpu_io_recompile cpu_io_recompile_x86_64
#define cpu_is_stopped cpu_is_stopped_x86_64
#define cpu_ldl_code cpu_ldl_code_x86_64
#define cpu_ldub_code cpu_ldub_code_x86_64
#define cpu_lduw_code cpu_lduw_code_x86_64
#define cpu_memory_rw_debug cpu_memory_rw_debug_x86_64
#define cpu_mmu_index cpu_mmu_index_x86_64
#define cpu_outb cpu_outb_x86_64
#define cpu_outl cpu_outl_x86_64
#define cpu_outw cpu_outw_x86_64
#define cpu_physical_memory_clear_dirty_range cpu_physical_memory_clear_dirty_range_x86_64
#define cpu_physical_memory_get_clean cpu_physical_memory_get_clean_x86_64
#define cpu_physical_memory_get_dirty cpu_physical_memory_get_dirty_x86_64
#define cpu_physical_memory_get_dirty_flag cpu_physical_memory_get_dirty_flag_x86_64
#define cpu_physical_memory_is_clean cpu_physical_memory_is_clean_x86_64
#define cpu_physical_memory_is_io cpu_physical_memory_is_io_x86_64
#define cpu_physical_memory_map cpu_physical_memory_map_x86_64
#define cpu_physical_memory_range_includes_clean cpu_physical_memory_range_includes_clean_x86_64
#define cpu_physical_memory_reset_dirty cpu_physical_memory_reset_dirty_x86_64
#define cpu_physical_memory_rw cpu_physical_memory_rw_x86_64
#define cpu_physical_memory_set_dirty_flag cpu_physical_memory_set_dirty_flag_x86_64
#define cpu_physical_memory_set_dirty_range cpu_physical_memory_set_dirty_range_x86_64
#define cpu_physical_memory_unmap cpu_physical_memory_unmap_x86_64
#define cpu_physical_memory_write_rom cpu_physical_memory_write_rom_x86_64
#define cpu_physical_memory_write_rom_internal cpu_physical_memory_write_rom_internal_x86_64
#define cpu_register cpu_register_x86_64
#define cpu_register_types cpu_register_types_x86_64
#define cpu_restore_state cpu_restore_state_x86_64
#define cpu_restore_state_from_tb cpu_restore_state_from_tb_x86_64
#define cpu_single_step cpu_single_step_x86_64
#define cpu_tb_exec cpu_tb_exec_x86_64
#define cpu_tlb_reset_dirty_all cpu_tlb_reset_dirty_all_x86_64
#define cpu_to_be64 cpu_to_be64_x86_64
#define cpu_to_le32 cpu_to_le32_x86_64
#define cpu_to_le64 cpu_to_le64_x86_64
#define cpu_type_info cpu_type_info_x86_64
#define cpu_unassigned_access cpu_unassigned_access_x86_64
#define cpu_watchpoint_address_matches cpu_watchpoint_address_matches_x86_64
#define cpu_watchpoint_insert cpu_watchpoint_insert_x86_64
#define cpu_watchpoint_remove cpu_watchpoint_remove_x86_64
#define cpu_watchpoint_remove_all cpu_watchpoint_remove_all_x86_64
#define cpu_watchpoint_remove_by_ref cpu_watchpoint_remove_by_ref_x86_64
#define crc32c_table crc32c_table_x86_64
#define create_new_memory_mapping create_new_memory_mapping_x86_64
#define csselr_write csselr_write_x86_64
#define cto32 cto32_x86_64
#define ctr_el0_access ctr_el0_access_x86_64
#define ctz32 ctz32_x86_64
#define ctz64 ctz64_x86_64
#define dacr_write dacr_write_x86_64
#define dbgbcr_write dbgbcr_write_x86_64
#define dbgbvr_write dbgbvr_write_x86_64
#define dbgwcr_write dbgwcr_write_x86_64
#define dbgwvr_write dbgwvr_write_x86_64
#define debug_cp_reginfo debug_cp_reginfo_x86_64
#define debug_frame debug_frame_x86_64
#define debug_lpae_cp_reginfo debug_lpae_cp_reginfo_x86_64
#define define_arm_cp_regs define_arm_cp_regs_x86_64
#define define_arm_cp_regs_with_opaque define_arm_cp_regs_with_opaque_x86_64
#define define_debug_regs define_debug_regs_x86_64
#define define_one_arm_cp_reg define_one_arm_cp_reg_x86_64
#define define_one_arm_cp_reg_with_opaque define_one_arm_cp_reg_with_opaque_x86_64
#define deposit32 deposit32_x86_64
#define deposit64 deposit64_x86_64
#define deregister_tm_clones deregister_tm_clones_x86_64
#define device_class_base_init device_class_base_init_x86_64
#define device_class_init device_class_init_x86_64
#define device_finalize device_finalize_x86_64
#define device_get_realized device_get_realized_x86_64
#define device_initfn device_initfn_x86_64
#define device_post_init device_post_init_x86_64
#define device_reset device_reset_x86_64
#define device_set_realized device_set_realized_x86_64
#define device_type_info device_type_info_x86_64
#define disas_arm_insn disas_arm_insn_x86_64
#define disas_coproc_insn disas_coproc_insn_x86_64
#define disas_dsp_insn disas_dsp_insn_x86_64
#define disas_iwmmxt_insn disas_iwmmxt_insn_x86_64
#define disas_neon_data_insn disas_neon_data_insn_x86_64
#define disas_neon_ls_insn disas_neon_ls_insn_x86_64
#define disas_thumb2_insn disas_thumb2_insn_x86_64
#define disas_thumb_insn disas_thumb_insn_x86_64
#define disas_vfp_insn disas_vfp_insn_x86_64
#define disas_vfp_v8_insn disas_vfp_v8_insn_x86_64
#define do_arm_semihosting do_arm_semihosting_x86_64
#define do_clz16 do_clz16_x86_64
#define do_clz8 do_clz8_x86_64
#define do_constant_folding do_constant_folding_x86_64
#define do_constant_folding_2 do_constant_folding_2_x86_64
#define do_constant_folding_cond do_constant_folding_cond_x86_64
#define do_constant_folding_cond2 do_constant_folding_cond2_x86_64
#define do_constant_folding_cond_32 do_constant_folding_cond_32_x86_64
#define do_constant_folding_cond_64 do_constant_folding_cond_64_x86_64
#define do_constant_folding_cond_eq do_constant_folding_cond_eq_x86_64
#define do_fcvt_f16_to_f32 do_fcvt_f16_to_f32_x86_64
#define do_fcvt_f32_to_f16 do_fcvt_f32_to_f16_x86_64
#define do_ssat do_ssat_x86_64
#define do_usad do_usad_x86_64
#define do_usat do_usat_x86_64
#define do_v7m_exception_exit do_v7m_exception_exit_x86_64
#define dummy_c15_cp_reginfo dummy_c15_cp_reginfo_x86_64
#define dummy_func dummy_func_x86_64
#define dummy_section dummy_section_x86_64
#define _DYNAMIC _DYNAMIC_x86_64
#define _edata _edata_x86_64
#define _end _end_x86_64
#define end_list end_list_x86_64
#define eq128 eq128_x86_64
#define ErrorClass_lookup ErrorClass_lookup_x86_64
#define error_copy error_copy_x86_64
#define error_exit error_exit_x86_64
#define error_get_class error_get_class_x86_64
#define error_get_pretty error_get_pretty_x86_64
#define error_setg_file_open error_setg_file_open_x86_64
#define estimateDiv128To64 estimateDiv128To64_x86_64
#define estimateSqrt32 estimateSqrt32_x86_64
#define excnames excnames_x86_64
#define excp_is_internal excp_is_internal_x86_64
#define extended_addresses_enabled extended_addresses_enabled_x86_64
#define extended_mpu_ap_bits extended_mpu_ap_bits_x86_64
#define extract32 extract32_x86_64
#define extract64 extract64_x86_64
#define extractFloat128Exp extractFloat128Exp_x86_64
#define extractFloat128Frac0 extractFloat128Frac0_x86_64
#define extractFloat128Frac1 extractFloat128Frac1_x86_64
#define extractFloat128Sign extractFloat128Sign_x86_64
#define extractFloat16Exp extractFloat16Exp_x86_64
#define extractFloat16Frac extractFloat16Frac_x86_64
#define extractFloat16Sign extractFloat16Sign_x86_64
#define extractFloat32Exp extractFloat32Exp_x86_64
#define extractFloat32Frac extractFloat32Frac_x86_64
#define extractFloat32Sign extractFloat32Sign_x86_64
#define extractFloat64Exp extractFloat64Exp_x86_64
#define extractFloat64Frac extractFloat64Frac_x86_64
#define extractFloat64Sign extractFloat64Sign_x86_64
#define extractFloatx80Exp extractFloatx80Exp_x86_64
#define extractFloatx80Frac extractFloatx80Frac_x86_64
#define extractFloatx80Sign extractFloatx80Sign_x86_64
#define fcse_write fcse_write_x86_64
#define find_better_copy find_better_copy_x86_64
#define find_default_machine find_default_machine_x86_64
#define find_desc_by_name find_desc_by_name_x86_64
#define find_first_bit find_first_bit_x86_64
#define find_paging_enabled_cpu find_paging_enabled_cpu_x86_64
#define find_ram_block find_ram_block_x86_64
#define find_ram_offset find_ram_offset_x86_64
#define find_string find_string_x86_64
#define find_type find_type_x86_64
#define _fini _fini_x86_64
#define flatrange_equal flatrange_equal_x86_64
#define flatview_destroy flatview_destroy_x86_64
#define flatview_init flatview_init_x86_64
#define flatview_insert flatview_insert_x86_64
#define flatview_lookup flatview_lookup_x86_64
#define flatview_ref flatview_ref_x86_64
#define flatview_simplify flatview_simplify_x86_64
#define flatview_unref flatview_unref_x86_64
#define float128_add float128_add_x86_64
#define float128_compare float128_compare_x86_64
#define float128_compare_internal float128_compare_internal_x86_64
#define float128_compare_quiet float128_compare_quiet_x86_64
#define float128_default_nan float128_default_nan_x86_64
#define float128_div float128_div_x86_64
#define float128_eq float128_eq_x86_64
#define float128_eq_quiet float128_eq_quiet_x86_64
#define float128_is_quiet_nan float128_is_quiet_nan_x86_64
#define float128_is_signaling_nan float128_is_signaling_nan_x86_64
#define float128_le float128_le_x86_64
#define float128_le_quiet float128_le_quiet_x86_64
#define float128_lt float128_lt_x86_64
#define float128_lt_quiet float128_lt_quiet_x86_64
#define float128_maybe_silence_nan float128_maybe_silence_nan_x86_64
#define float128_mul float128_mul_x86_64
#define float128_rem float128_rem_x86_64
#define float128_round_to_int float128_round_to_int_x86_64
#define float128_scalbn float128_scalbn_x86_64
#define float128_sqrt float128_sqrt_x86_64
#define float128_sub float128_sub_x86_64
#define float128ToCommonNaN float128ToCommonNaN_x86_64
#define float128_to_float32 float128_to_float32_x86_64
#define float128_to_float64 float128_to_float64_x86_64
#define float128_to_floatx80 float128_to_floatx80_x86_64
#define float128_to_int32 float128_to_int32_x86_64
#define float128_to_int32_round_to_zero float128_to_int32_round_to_zero_x86_64
#define float128_to_int64 float128_to_int64_x86_64
#define float128_to_int64_round_to_zero float128_to_int64_round_to_zero_x86_64
#define float128_unordered float128_unordered_x86_64
#define float128_unordered_quiet float128_unordered_quiet_x86_64
#define float16_default_nan float16_default_nan_x86_64
#define float16_is_quiet_nan float16_is_quiet_nan_x86_64
#define float16_is_signaling_nan float16_is_signaling_nan_x86_64
#define float16_maybe_silence_nan float16_maybe_silence_nan_x86_64
#define float16ToCommonNaN float16ToCommonNaN_x86_64
#define float16_to_float32 float16_to_float32_x86_64
#define float16_to_float64 float16_to_float64_x86_64
#define float32_abs float32_abs_x86_64
#define float32_add float32_add_x86_64
#define float32_chs float32_chs_x86_64
#define float32_compare float32_compare_x86_64
#define float32_compare_internal float32_compare_internal_x86_64
#define float32_compare_quiet float32_compare_quiet_x86_64
#define float32_default_nan float32_default_nan_x86_64
#define float32_div float32_div_x86_64
#define float32_eq float32_eq_x86_64
#define float32_eq_quiet float32_eq_quiet_x86_64
#define float32_exp2 float32_exp2_x86_64
#define float32_exp2_coefficients float32_exp2_coefficients_x86_64
#define float32_is_any_nan float32_is_any_nan_x86_64
#define float32_is_infinity float32_is_infinity_x86_64
#define float32_is_neg float32_is_neg_x86_64
#define float32_is_quiet_nan float32_is_quiet_nan_x86_64
#define float32_is_signaling_nan float32_is_signaling_nan_x86_64
#define float32_is_zero float32_is_zero_x86_64
#define float32_is_zero_or_denormal float32_is_zero_or_denormal_x86_64
#define float32_le float32_le_x86_64
#define float32_le_quiet float32_le_quiet_x86_64
#define float32_log2 float32_log2_x86_64
#define float32_lt float32_lt_x86_64
#define float32_lt_quiet float32_lt_quiet_x86_64
#define float32_max float32_max_x86_64
#define float32_maxnum float32_maxnum_x86_64
#define float32_maxnummag float32_maxnummag_x86_64
#define float32_maybe_silence_nan float32_maybe_silence_nan_x86_64
#define float32_min float32_min_x86_64
#define float32_minmax float32_minmax_x86_64
#define float32_minnum float32_minnum_x86_64
#define float32_minnummag float32_minnummag_x86_64
#define float32_mul float32_mul_x86_64
#define float32_muladd float32_muladd_x86_64
#define float32_rem float32_rem_x86_64
#define float32_round_to_int float32_round_to_int_x86_64
#define float32_scalbn float32_scalbn_x86_64
#define float32_set_sign float32_set_sign_x86_64
#define float32_sqrt float32_sqrt_x86_64
#define float32_squash_input_denormal float32_squash_input_denormal_x86_64
#define float32_sub float32_sub_x86_64
#define float32ToCommonNaN float32ToCommonNaN_x86_64
#define float32_to_float128 float32_to_float128_x86_64
#define float32_to_float16 float32_to_float16_x86_64
#define float32_to_float64 float32_to_float64_x86_64
#define float32_to_floatx80 float32_to_floatx80_x86_64
#define float32_to_int16 float32_to_int16_x86_64
#define float32_to_int16_round_to_zero float32_to_int16_round_to_zero_x86_64
#define float32_to_int32 float32_to_int32_x86_64
#define float32_to_int32_round_to_zero float32_to_int32_round_to_zero_x86_64
#define float32_to_int64 float32_to_int64_x86_64
#define float32_to_int64_round_to_zero float32_to_int64_round_to_zero_x86_64
#define float32_to_uint16 float32_to_uint16_x86_64
#define float32_to_uint16_round_to_zero float32_to_uint16_round_to_zero_x86_64
#define float32_to_uint32 float32_to_uint32_x86_64
#define float32_to_uint32_round_to_zero float32_to_uint32_round_to_zero_x86_64
#define float32_to_uint64 float32_to_uint64_x86_64
#define float32_to_uint64_round_to_zero float32_to_uint64_round_to_zero_x86_64
#define float32_unordered float32_unordered_x86_64
#define float32_unordered_quiet float32_unordered_quiet_x86_64
#define float64_abs float64_abs_x86_64
#define float64_add float64_add_x86_64
#define float64_chs float64_chs_x86_64
#define float64_compare float64_compare_x86_64
#define float64_compare_internal float64_compare_internal_x86_64
#define float64_compare_quiet float64_compare_quiet_x86_64
#define float64_default_nan float64_default_nan_x86_64
#define float64_div float64_div_x86_64
#define float64_eq float64_eq_x86_64
#define float64_eq_quiet float64_eq_quiet_x86_64
#define float64_is_any_nan float64_is_any_nan_x86_64
#define float64_is_infinity float64_is_infinity_x86_64
#define float64_is_neg float64_is_neg_x86_64
#define float64_is_quiet_nan float64_is_quiet_nan_x86_64
#define float64_is_signaling_nan float64_is_signaling_nan_x86_64
#define float64_is_zero float64_is_zero_x86_64
#define float64_le float64_le_x86_64
#define float64_le_quiet float64_le_quiet_x86_64
#define float64_log2 float64_log2_x86_64
#define float64_lt float64_lt_x86_64
#define float64_lt_quiet float64_lt_quiet_x86_64
#define float64_max float64_max_x86_64
#define float64_maxnum float64_maxnum_x86_64
#define float64_maxnummag float64_maxnummag_x86_64
#define float64_maybe_silence_nan float64_maybe_silence_nan_x86_64
#define float64_min float64_min_x86_64
#define float64_minmax float64_minmax_x86_64
#define float64_minnum float64_minnum_x86_64
#define float64_minnummag float64_minnummag_x86_64
#define float64_mul float64_mul_x86_64
#define float64_muladd float64_muladd_x86_64
#define float64_rem float64_rem_x86_64
#define float64_round_to_int float64_round_to_int_x86_64
#define float64_scalbn float64_scalbn_x86_64
#define float64_set_sign float64_set_sign_x86_64
#define float64_sqrt float64_sqrt_x86_64
#define float64_squash_input_denormal float64_squash_input_denormal_x86_64
#define float64_sub float64_sub_x86_64
#define float64ToCommonNaN float64ToCommonNaN_x86_64
#define float64_to_float128 float64_to_float128_x86_64
#define float64_to_float16 float64_to_float16_x86_64
#define float64_to_float32 float64_to_float32_x86_64
#define float64_to_floatx80 float64_to_floatx80_x86_64
#define float64_to_int16 float64_to_int16_x86_64
#define float64_to_int16_round_to_zero float64_to_int16_round_to_zero_x86_64
#define float64_to_int32 float64_to_int32_x86_64
#define float64_to_int32_round_to_zero float64_to_int32_round_to_zero_x86_64
#define float64_to_int64 float64_to_int64_x86_64
#define float64_to_int64_round_to_zero float64_to_int64_round_to_zero_x86_64
#define float64_to_uint16 float64_to_uint16_x86_64
#define float64_to_uint16_round_to_zero float64_to_uint16_round_to_zero_x86_64
#define float64_to_uint32 float64_to_uint32_x86_64
#define float64_to_uint32_round_to_zero float64_to_uint32_round_to_zero_x86_64
#define float64_to_uint64 float64_to_uint64_x86_64
#define float64_to_uint64_round_to_zero float64_to_uint64_round_to_zero_x86_64
#define float64_trunc_to_int float64_trunc_to_int_x86_64
#define float64_unordered float64_unordered_x86_64
#define float64_unordered_quiet float64_unordered_quiet_x86_64
#define float_raise float_raise_x86_64
#define floatx80_add floatx80_add_x86_64
#define floatx80_compare floatx80_compare_x86_64
#define floatx80_compare_internal floatx80_compare_internal_x86_64
#define floatx80_compare_quiet floatx80_compare_quiet_x86_64
#define floatx80_default_nan floatx80_default_nan_x86_64
#define floatx80_div floatx80_div_x86_64
#define floatx80_eq floatx80_eq_x86_64
#define floatx80_eq_quiet floatx80_eq_quiet_x86_64
#define floatx80_is_quiet_nan floatx80_is_quiet_nan_x86_64
#define floatx80_is_signaling_nan floatx80_is_signaling_nan_x86_64
#define floatx80_le floatx80_le_x86_64
#define floatx80_le_quiet floatx80_le_quiet_x86_64
#define floatx80_lt floatx80_lt_x86_64
#define floatx80_lt_quiet floatx80_lt_quiet_x86_64
#define floatx80_maybe_silence_nan floatx80_maybe_silence_nan_x86_64
#define floatx80_mul floatx80_mul_x86_64
#define floatx80_rem floatx80_rem_x86_64
#define floatx80_round_to_int floatx80_round_to_int_x86_64
#define floatx80_scalbn floatx80_scalbn_x86_64
#define floatx80_sqrt floatx80_sqrt_x86_64
#define floatx80_sub floatx80_sub_x86_64
#define floatx80ToCommonNaN floatx80ToCommonNaN_x86_64
#define floatx80_to_float128 floatx80_to_float128_x86_64
#define floatx80_to_float32 floatx80_to_float32_x86_64
#define floatx80_to_float64 floatx80_to_float64_x86_64
#define floatx80_to_int32 floatx80_to_int32_x86_64
#define floatx80_to_int32_round_to_zero floatx80_to_int32_round_to_zero_x86_64
#define floatx80_to_int64 floatx80_to_int64_x86_64
#define floatx80_to_int64_round_to_zero floatx80_to_int64_round_to_zero_x86_64
#define floatx80_unordered floatx80_unordered_x86_64
#define floatx80_unordered_quiet floatx80_unordered_quiet_x86_64
#define flush_icache_range flush_icache_range_x86_64
#define format_string format_string_x86_64
#define fp_decode_rm fp_decode_rm_x86_64
#define frame_dummy frame_dummy_x86_64
#define free_range free_range_x86_64
#define fstat64 fstat64_x86_64
#define futex_wait futex_wait_x86_64
#define futex_wake futex_wake_x86_64
#define gen_aa32_ld16s gen_aa32_ld16s_x86_64
#define gen_aa32_ld16u gen_aa32_ld16u_x86_64
#define gen_aa32_ld32u gen_aa32_ld32u_x86_64
#define gen_aa32_ld64 gen_aa32_ld64_x86_64
#define gen_aa32_ld8s gen_aa32_ld8s_x86_64
#define gen_aa32_ld8u gen_aa32_ld8u_x86_64
#define gen_aa32_st16 gen_aa32_st16_x86_64
#define gen_aa32_st32 gen_aa32_st32_x86_64
#define gen_aa32_st64 gen_aa32_st64_x86_64
#define gen_aa32_st8 gen_aa32_st8_x86_64
#define gen_adc gen_adc_x86_64
#define gen_adc_CC gen_adc_CC_x86_64
#define gen_add16 gen_add16_x86_64
#define gen_add_carry gen_add_carry_x86_64
#define gen_add_CC gen_add_CC_x86_64
#define gen_add_datah_offset gen_add_datah_offset_x86_64
#define gen_add_data_offset gen_add_data_offset_x86_64
#define gen_addq gen_addq_x86_64
#define gen_addq_lo gen_addq_lo_x86_64
#define gen_addq_msw gen_addq_msw_x86_64
#define gen_arm_parallel_addsub gen_arm_parallel_addsub_x86_64
#define gen_arm_shift_im gen_arm_shift_im_x86_64
#define gen_arm_shift_reg gen_arm_shift_reg_x86_64
#define gen_bx gen_bx_x86_64
#define gen_bx_im gen_bx_im_x86_64
#define gen_clrex gen_clrex_x86_64
#define generate_memory_topology generate_memory_topology_x86_64
#define generic_timer_cp_reginfo generic_timer_cp_reginfo_x86_64
#define gen_exception gen_exception_x86_64
#define gen_exception_insn gen_exception_insn_x86_64
#define gen_exception_internal gen_exception_internal_x86_64
#define gen_exception_internal_insn gen_exception_internal_insn_x86_64
#define gen_exception_return gen_exception_return_x86_64
#define gen_goto_tb gen_goto_tb_x86_64
#define gen_helper_access_check_cp_reg gen_helper_access_check_cp_reg_x86_64
#define gen_helper_add_saturate gen_helper_add_saturate_x86_64
#define gen_helper_add_setq gen_helper_add_setq_x86_64
#define gen_helper_clear_pstate_ss gen_helper_clear_pstate_ss_x86_64
#define gen_helper_clz32 gen_helper_clz32_x86_64
#define gen_helper_clz64 gen_helper_clz64_x86_64
#define gen_helper_clz_arm gen_helper_clz_arm_x86_64
#define gen_helper_cpsr_read gen_helper_cpsr_read_x86_64
#define gen_helper_cpsr_write gen_helper_cpsr_write_x86_64
#define gen_helper_crc32_arm gen_helper_crc32_arm_x86_64
#define gen_helper_crc32c gen_helper_crc32c_x86_64
#define gen_helper_crypto_aese gen_helper_crypto_aese_x86_64
#define gen_helper_crypto_aesmc gen_helper_crypto_aesmc_x86_64
#define gen_helper_crypto_sha1_3reg gen_helper_crypto_sha1_3reg_x86_64
#define gen_helper_crypto_sha1h gen_helper_crypto_sha1h_x86_64
#define gen_helper_crypto_sha1su1 gen_helper_crypto_sha1su1_x86_64
#define gen_helper_crypto_sha256h gen_helper_crypto_sha256h_x86_64
#define gen_helper_crypto_sha256h2 gen_helper_crypto_sha256h2_x86_64
#define gen_helper_crypto_sha256su0 gen_helper_crypto_sha256su0_x86_64
#define gen_helper_crypto_sha256su1 gen_helper_crypto_sha256su1_x86_64
#define gen_helper_double_saturate gen_helper_double_saturate_x86_64
#define gen_helper_exception_internal gen_helper_exception_internal_x86_64
#define gen_helper_exception_with_syndrome gen_helper_exception_with_syndrome_x86_64
#define gen_helper_get_cp_reg gen_helper_get_cp_reg_x86_64
#define gen_helper_get_cp_reg64 gen_helper_get_cp_reg64_x86_64
#define gen_helper_get_r13_banked gen_helper_get_r13_banked_x86_64
#define gen_helper_get_user_reg gen_helper_get_user_reg_x86_64
#define gen_helper_iwmmxt_addcb gen_helper_iwmmxt_addcb_x86_64
#define gen_helper_iwmmxt_addcl gen_helper_iwmmxt_addcl_x86_64
#define gen_helper_iwmmxt_addcw gen_helper_iwmmxt_addcw_x86_64
#define gen_helper_iwmmxt_addnb gen_helper_iwmmxt_addnb_x86_64
#define gen_helper_iwmmxt_addnl gen_helper_iwmmxt_addnl_x86_64
#define gen_helper_iwmmxt_addnw gen_helper_iwmmxt_addnw_x86_64
#define gen_helper_iwmmxt_addsb gen_helper_iwmmxt_addsb_x86_64
#define gen_helper_iwmmxt_addsl gen_helper_iwmmxt_addsl_x86_64
#define gen_helper_iwmmxt_addsw gen_helper_iwmmxt_addsw_x86_64
#define gen_helper_iwmmxt_addub gen_helper_iwmmxt_addub_x86_64
#define gen_helper_iwmmxt_addul gen_helper_iwmmxt_addul_x86_64
#define gen_helper_iwmmxt_adduw gen_helper_iwmmxt_adduw_x86_64
#define gen_helper_iwmmxt_align gen_helper_iwmmxt_align_x86_64
#define gen_helper_iwmmxt_avgb0 gen_helper_iwmmxt_avgb0_x86_64
#define gen_helper_iwmmxt_avgb1 gen_helper_iwmmxt_avgb1_x86_64
#define gen_helper_iwmmxt_avgw0 gen_helper_iwmmxt_avgw0_x86_64
#define gen_helper_iwmmxt_avgw1 gen_helper_iwmmxt_avgw1_x86_64
#define gen_helper_iwmmxt_bcstb gen_helper_iwmmxt_bcstb_x86_64
#define gen_helper_iwmmxt_bcstl gen_helper_iwmmxt_bcstl_x86_64
#define gen_helper_iwmmxt_bcstw gen_helper_iwmmxt_bcstw_x86_64
#define gen_helper_iwmmxt_cmpeqb gen_helper_iwmmxt_cmpeqb_x86_64
#define gen_helper_iwmmxt_cmpeql gen_helper_iwmmxt_cmpeql_x86_64
#define gen_helper_iwmmxt_cmpeqw gen_helper_iwmmxt_cmpeqw_x86_64
#define gen_helper_iwmmxt_cmpgtsb gen_helper_iwmmxt_cmpgtsb_x86_64
#define gen_helper_iwmmxt_cmpgtsl gen_helper_iwmmxt_cmpgtsl_x86_64
#define gen_helper_iwmmxt_cmpgtsw gen_helper_iwmmxt_cmpgtsw_x86_64
#define gen_helper_iwmmxt_cmpgtub gen_helper_iwmmxt_cmpgtub_x86_64
#define gen_helper_iwmmxt_cmpgtul gen_helper_iwmmxt_cmpgtul_x86_64
#define gen_helper_iwmmxt_cmpgtuw gen_helper_iwmmxt_cmpgtuw_x86_64
#define gen_helper_iwmmxt_insr gen_helper_iwmmxt_insr_x86_64
#define gen_helper_iwmmxt_macsw gen_helper_iwmmxt_macsw_x86_64
#define gen_helper_iwmmxt_macuw gen_helper_iwmmxt_macuw_x86_64
#define gen_helper_iwmmxt_maddsq gen_helper_iwmmxt_maddsq_x86_64
#define gen_helper_iwmmxt_madduq gen_helper_iwmmxt_madduq_x86_64
#define gen_helper_iwmmxt_maxsb gen_helper_iwmmxt_maxsb_x86_64
#define gen_helper_iwmmxt_maxsl gen_helper_iwmmxt_maxsl_x86_64
#define gen_helper_iwmmxt_maxsw gen_helper_iwmmxt_maxsw_x86_64
#define gen_helper_iwmmxt_maxub gen_helper_iwmmxt_maxub_x86_64
#define gen_helper_iwmmxt_maxul gen_helper_iwmmxt_maxul_x86_64
#define gen_helper_iwmmxt_maxuw gen_helper_iwmmxt_maxuw_x86_64
#define gen_helper_iwmmxt_minsb gen_helper_iwmmxt_minsb_x86_64
#define gen_helper_iwmmxt_minsl gen_helper_iwmmxt_minsl_x86_64
#define gen_helper_iwmmxt_minsw gen_helper_iwmmxt_minsw_x86_64
#define gen_helper_iwmmxt_minub gen_helper_iwmmxt_minub_x86_64
#define gen_helper_iwmmxt_minul gen_helper_iwmmxt_minul_x86_64
#define gen_helper_iwmmxt_minuw gen_helper_iwmmxt_minuw_x86_64
#define gen_helper_iwmmxt_msbb gen_helper_iwmmxt_msbb_x86_64
#define gen_helper_iwmmxt_msbl gen_helper_iwmmxt_msbl_x86_64
#define gen_helper_iwmmxt_msbw gen_helper_iwmmxt_msbw_x86_64
#define gen_helper_iwmmxt_muladdsl gen_helper_iwmmxt_muladdsl_x86_64
#define gen_helper_iwmmxt_muladdsw gen_helper_iwmmxt_muladdsw_x86_64
#define gen_helper_iwmmxt_muladdswl gen_helper_iwmmxt_muladdswl_x86_64
#define gen_helper_iwmmxt_mulshw gen_helper_iwmmxt_mulshw_x86_64
#define gen_helper_iwmmxt_mulslw gen_helper_iwmmxt_mulslw_x86_64
#define gen_helper_iwmmxt_muluhw gen_helper_iwmmxt_muluhw_x86_64
#define gen_helper_iwmmxt_mululw gen_helper_iwmmxt_mululw_x86_64
#define gen_helper_iwmmxt_packsl gen_helper_iwmmxt_packsl_x86_64
#define gen_helper_iwmmxt_packsq gen_helper_iwmmxt_packsq_x86_64
#define gen_helper_iwmmxt_packsw gen_helper_iwmmxt_packsw_x86_64
#define gen_helper_iwmmxt_packul gen_helper_iwmmxt_packul_x86_64
#define gen_helper_iwmmxt_packuq gen_helper_iwmmxt_packuq_x86_64
#define gen_helper_iwmmxt_packuw gen_helper_iwmmxt_packuw_x86_64
#define gen_helper_iwmmxt_rorl gen_helper_iwmmxt_rorl_x86_64
#define gen_helper_iwmmxt_rorq gen_helper_iwmmxt_rorq_x86_64
#define gen_helper_iwmmxt_rorw gen_helper_iwmmxt_rorw_x86_64
#define gen_helper_iwmmxt_sadb gen_helper_iwmmxt_sadb_x86_64
#define gen_helper_iwmmxt_sadw gen_helper_iwmmxt_sadw_x86_64
#define gen_helper_iwmmxt_setpsr_nz gen_helper_iwmmxt_setpsr_nz_x86_64
#define gen_helper_iwmmxt_shufh gen_helper_iwmmxt_shufh_x86_64
#define gen_helper_iwmmxt_slll gen_helper_iwmmxt_slll_x86_64
#define gen_helper_iwmmxt_sllq gen_helper_iwmmxt_sllq_x86_64
#define gen_helper_iwmmxt_sllw gen_helper_iwmmxt_sllw_x86_64
#define gen_helper_iwmmxt_sral gen_helper_iwmmxt_sral_x86_64
#define gen_helper_iwmmxt_sraq gen_helper_iwmmxt_sraq_x86_64
#define gen_helper_iwmmxt_sraw gen_helper_iwmmxt_sraw_x86_64
#define gen_helper_iwmmxt_srll gen_helper_iwmmxt_srll_x86_64
#define gen_helper_iwmmxt_srlq gen_helper_iwmmxt_srlq_x86_64
#define gen_helper_iwmmxt_srlw gen_helper_iwmmxt_srlw_x86_64
#define gen_helper_iwmmxt_subnb gen_helper_iwmmxt_subnb_x86_64
#define gen_helper_iwmmxt_subnl gen_helper_iwmmxt_subnl_x86_64
#define gen_helper_iwmmxt_subnw gen_helper_iwmmxt_subnw_x86_64
#define gen_helper_iwmmxt_subsb gen_helper_iwmmxt_subsb_x86_64
#define gen_helper_iwmmxt_subsl gen_helper_iwmmxt_subsl_x86_64
#define gen_helper_iwmmxt_subsw gen_helper_iwmmxt_subsw_x86_64
#define gen_helper_iwmmxt_subub gen_helper_iwmmxt_subub_x86_64
#define gen_helper_iwmmxt_subul gen_helper_iwmmxt_subul_x86_64
#define gen_helper_iwmmxt_subuw gen_helper_iwmmxt_subuw_x86_64
#define gen_helper_iwmmxt_unpackhb gen_helper_iwmmxt_unpackhb_x86_64
#define gen_helper_iwmmxt_unpackhl gen_helper_iwmmxt_unpackhl_x86_64
#define gen_helper_iwmmxt_unpackhsb gen_helper_iwmmxt_unpackhsb_x86_64
#define gen_helper_iwmmxt_unpackhsl gen_helper_iwmmxt_unpackhsl_x86_64
#define gen_helper_iwmmxt_unpackhsw gen_helper_iwmmxt_unpackhsw_x86_64
#define gen_helper_iwmmxt_unpackhub gen_helper_iwmmxt_unpackhub_x86_64
#define gen_helper_iwmmxt_unpackhul gen_helper_iwmmxt_unpackhul_x86_64
#define gen_helper_iwmmxt_unpackhuw gen_helper_iwmmxt_unpackhuw_x86_64
#define gen_helper_iwmmxt_unpackhw gen_helper_iwmmxt_unpackhw_x86_64
#define gen_helper_iwmmxt_unpacklb gen_helper_iwmmxt_unpacklb_x86_64
#define gen_helper_iwmmxt_unpackll gen_helper_iwmmxt_unpackll_x86_64
#define gen_helper_iwmmxt_unpacklsb gen_helper_iwmmxt_unpacklsb_x86_64
#define gen_helper_iwmmxt_unpacklsl gen_helper_iwmmxt_unpacklsl_x86_64
#define gen_helper_iwmmxt_unpacklsw gen_helper_iwmmxt_unpacklsw_x86_64
#define gen_helper_iwmmxt_unpacklub gen_helper_iwmmxt_unpacklub_x86_64
#define gen_helper_iwmmxt_unpacklul gen_helper_iwmmxt_unpacklul_x86_64
#define gen_helper_iwmmxt_unpackluw gen_helper_iwmmxt_unpackluw_x86_64
#define gen_helper_iwmmxt_unpacklw gen_helper_iwmmxt_unpacklw_x86_64
#define gen_helper_neon_abd_f32 gen_helper_neon_abd_f32_x86_64
#define gen_helper_neon_abdl_s16 gen_helper_neon_abdl_s16_x86_64
#define gen_helper_neon_abdl_s32 gen_helper_neon_abdl_s32_x86_64
#define gen_helper_neon_abdl_s64 gen_helper_neon_abdl_s64_x86_64
#define gen_helper_neon_abdl_u16 gen_helper_neon_abdl_u16_x86_64
#define gen_helper_neon_abdl_u32 gen_helper_neon_abdl_u32_x86_64
#define gen_helper_neon_abdl_u64 gen_helper_neon_abdl_u64_x86_64
#define gen_helper_neon_abd_s16 gen_helper_neon_abd_s16_x86_64
#define gen_helper_neon_abd_s32 gen_helper_neon_abd_s32_x86_64
#define gen_helper_neon_abd_s8 gen_helper_neon_abd_s8_x86_64
#define gen_helper_neon_abd_u16 gen_helper_neon_abd_u16_x86_64
#define gen_helper_neon_abd_u32 gen_helper_neon_abd_u32_x86_64
#define gen_helper_neon_abd_u8 gen_helper_neon_abd_u8_x86_64
#define gen_helper_neon_abs_s16 gen_helper_neon_abs_s16_x86_64
#define gen_helper_neon_abs_s8 gen_helper_neon_abs_s8_x86_64
#define gen_helper_neon_acge_f32 gen_helper_neon_acge_f32_x86_64
#define gen_helper_neon_acgt_f32 gen_helper_neon_acgt_f32_x86_64
#define gen_helper_neon_addl_saturate_s32 gen_helper_neon_addl_saturate_s32_x86_64
#define gen_helper_neon_addl_saturate_s64 gen_helper_neon_addl_saturate_s64_x86_64
#define gen_helper_neon_addl_u16 gen_helper_neon_addl_u16_x86_64
#define gen_helper_neon_addl_u32 gen_helper_neon_addl_u32_x86_64
#define gen_helper_neon_add_u16 gen_helper_neon_add_u16_x86_64
#define gen_helper_neon_add_u8 gen_helper_neon_add_u8_x86_64
#define gen_helper_neon_ceq_f32 gen_helper_neon_ceq_f32_x86_64
#define gen_helper_neon_ceq_u16 gen_helper_neon_ceq_u16_x86_64
#define gen_helper_neon_ceq_u32 gen_helper_neon_ceq_u32_x86_64
#define gen_helper_neon_ceq_u8 gen_helper_neon_ceq_u8_x86_64
#define gen_helper_neon_cge_f32 gen_helper_neon_cge_f32_x86_64
#define gen_helper_neon_cge_s16 gen_helper_neon_cge_s16_x86_64
#define gen_helper_neon_cge_s32 gen_helper_neon_cge_s32_x86_64
#define gen_helper_neon_cge_s8 gen_helper_neon_cge_s8_x86_64
#define gen_helper_neon_cge_u16 gen_helper_neon_cge_u16_x86_64
#define gen_helper_neon_cge_u32 gen_helper_neon_cge_u32_x86_64
#define gen_helper_neon_cge_u8 gen_helper_neon_cge_u8_x86_64
#define gen_helper_neon_cgt_f32 gen_helper_neon_cgt_f32_x86_64
#define gen_helper_neon_cgt_s16 gen_helper_neon_cgt_s16_x86_64
#define gen_helper_neon_cgt_s32 gen_helper_neon_cgt_s32_x86_64
#define gen_helper_neon_cgt_s8 gen_helper_neon_cgt_s8_x86_64
#define gen_helper_neon_cgt_u16 gen_helper_neon_cgt_u16_x86_64
#define gen_helper_neon_cgt_u32 gen_helper_neon_cgt_u32_x86_64
#define gen_helper_neon_cgt_u8 gen_helper_neon_cgt_u8_x86_64
#define gen_helper_neon_cls_s16 gen_helper_neon_cls_s16_x86_64
#define gen_helper_neon_cls_s32 gen_helper_neon_cls_s32_x86_64
#define gen_helper_neon_cls_s8 gen_helper_neon_cls_s8_x86_64
#define gen_helper_neon_clz_u16 gen_helper_neon_clz_u16_x86_64
#define gen_helper_neon_clz_u8 gen_helper_neon_clz_u8_x86_64
#define gen_helper_neon_cnt_u8 gen_helper_neon_cnt_u8_x86_64
#define gen_helper_neon_fcvt_f16_to_f32 gen_helper_neon_fcvt_f16_to_f32_x86_64
#define gen_helper_neon_fcvt_f32_to_f16 gen_helper_neon_fcvt_f32_to_f16_x86_64
#define gen_helper_neon_hadd_s16 gen_helper_neon_hadd_s16_x86_64
#define gen_helper_neon_hadd_s32 gen_helper_neon_hadd_s32_x86_64
#define gen_helper_neon_hadd_s8 gen_helper_neon_hadd_s8_x86_64
#define gen_helper_neon_hadd_u16 gen_helper_neon_hadd_u16_x86_64
#define gen_helper_neon_hadd_u32 gen_helper_neon_hadd_u32_x86_64
#define gen_helper_neon_hadd_u8 gen_helper_neon_hadd_u8_x86_64
#define gen_helper_neon_hsub_s16 gen_helper_neon_hsub_s16_x86_64
#define gen_helper_neon_hsub_s32 gen_helper_neon_hsub_s32_x86_64
#define gen_helper_neon_hsub_s8 gen_helper_neon_hsub_s8_x86_64
#define gen_helper_neon_hsub_u16 gen_helper_neon_hsub_u16_x86_64
#define gen_helper_neon_hsub_u32 gen_helper_neon_hsub_u32_x86_64
#define gen_helper_neon_hsub_u8 gen_helper_neon_hsub_u8_x86_64
#define gen_helper_neon_max_s16 gen_helper_neon_max_s16_x86_64
#define gen_helper_neon_max_s32 gen_helper_neon_max_s32_x86_64
#define gen_helper_neon_max_s8 gen_helper_neon_max_s8_x86_64
#define gen_helper_neon_max_u16 gen_helper_neon_max_u16_x86_64
#define gen_helper_neon_max_u32 gen_helper_neon_max_u32_x86_64
#define gen_helper_neon_max_u8 gen_helper_neon_max_u8_x86_64
#define gen_helper_neon_min_s16 gen_helper_neon_min_s16_x86_64
#define gen_helper_neon_min_s32 gen_helper_neon_min_s32_x86_64
#define gen_helper_neon_min_s8 gen_helper_neon_min_s8_x86_64
#define gen_helper_neon_min_u16 gen_helper_neon_min_u16_x86_64
#define gen_helper_neon_min_u32 gen_helper_neon_min_u32_x86_64
#define gen_helper_neon_min_u8 gen_helper_neon_min_u8_x86_64
#define gen_helper_neon_mull_p8 gen_helper_neon_mull_p8_x86_64
#define gen_helper_neon_mull_s16 gen_helper_neon_mull_s16_x86_64
#define gen_helper_neon_mull_s8 gen_helper_neon_mull_s8_x86_64
#define gen_helper_neon_mull_u16 gen_helper_neon_mull_u16_x86_64
#define gen_helper_neon_mull_u8 gen_helper_neon_mull_u8_x86_64
#define gen_helper_neon_mul_p8 gen_helper_neon_mul_p8_x86_64
#define gen_helper_neon_mul_u16 gen_helper_neon_mul_u16_x86_64
#define gen_helper_neon_mul_u8 gen_helper_neon_mul_u8_x86_64
#define gen_helper_neon_narrow_high_u16 gen_helper_neon_narrow_high_u16_x86_64
#define gen_helper_neon_narrow_high_u8 gen_helper_neon_narrow_high_u8_x86_64
#define gen_helper_neon_narrow_round_high_u16 gen_helper_neon_narrow_round_high_u16_x86_64
#define gen_helper_neon_narrow_round_high_u8 gen_helper_neon_narrow_round_high_u8_x86_64
#define gen_helper_neon_narrow_sat_s16 gen_helper_neon_narrow_sat_s16_x86_64
#define gen_helper_neon_narrow_sat_s32 gen_helper_neon_narrow_sat_s32_x86_64
#define gen_helper_neon_narrow_sat_s8 gen_helper_neon_narrow_sat_s8_x86_64
#define gen_helper_neon_narrow_sat_u16 gen_helper_neon_narrow_sat_u16_x86_64
#define gen_helper_neon_narrow_sat_u32 gen_helper_neon_narrow_sat_u32_x86_64
#define gen_helper_neon_narrow_sat_u8 gen_helper_neon_narrow_sat_u8_x86_64
#define gen_helper_neon_narrow_u16 gen_helper_neon_narrow_u16_x86_64
#define gen_helper_neon_narrow_u8 gen_helper_neon_narrow_u8_x86_64
#define gen_helper_neon_negl_u16 gen_helper_neon_negl_u16_x86_64
#define gen_helper_neon_negl_u32 gen_helper_neon_negl_u32_x86_64
#define gen_helper_neon_paddl_u16 gen_helper_neon_paddl_u16_x86_64
#define gen_helper_neon_paddl_u32 gen_helper_neon_paddl_u32_x86_64
#define gen_helper_neon_padd_u16 gen_helper_neon_padd_u16_x86_64
#define gen_helper_neon_padd_u8 gen_helper_neon_padd_u8_x86_64
#define gen_helper_neon_pmax_s16 gen_helper_neon_pmax_s16_x86_64
#define gen_helper_neon_pmax_s8 gen_helper_neon_pmax_s8_x86_64
#define gen_helper_neon_pmax_u16 gen_helper_neon_pmax_u16_x86_64
#define gen_helper_neon_pmax_u8 gen_helper_neon_pmax_u8_x86_64
#define gen_helper_neon_pmin_s16 gen_helper_neon_pmin_s16_x86_64
#define gen_helper_neon_pmin_s8 gen_helper_neon_pmin_s8_x86_64
#define gen_helper_neon_pmin_u16 gen_helper_neon_pmin_u16_x86_64
#define gen_helper_neon_pmin_u8 gen_helper_neon_pmin_u8_x86_64
#define gen_helper_neon_pmull_64_hi gen_helper_neon_pmull_64_hi_x86_64
#define gen_helper_neon_pmull_64_lo gen_helper_neon_pmull_64_lo_x86_64
#define gen_helper_neon_qabs_s16 gen_helper_neon_qabs_s16_x86_64
#define gen_helper_neon_qabs_s32 gen_helper_neon_qabs_s32_x86_64
#define gen_helper_neon_qabs_s8 gen_helper_neon_qabs_s8_x86_64
#define gen_helper_neon_qadd_s16 gen_helper_neon_qadd_s16_x86_64
#define gen_helper_neon_qadd_s32 gen_helper_neon_qadd_s32_x86_64
#define gen_helper_neon_qadd_s64 gen_helper_neon_qadd_s64_x86_64
#define gen_helper_neon_qadd_s8 gen_helper_neon_qadd_s8_x86_64
#define gen_helper_neon_qadd_u16 gen_helper_neon_qadd_u16_x86_64
#define gen_helper_neon_qadd_u32 gen_helper_neon_qadd_u32_x86_64
#define gen_helper_neon_qadd_u64 gen_helper_neon_qadd_u64_x86_64
#define gen_helper_neon_qadd_u8 gen_helper_neon_qadd_u8_x86_64
#define gen_helper_neon_qdmulh_s16 gen_helper_neon_qdmulh_s16_x86_64
#define gen_helper_neon_qdmulh_s32 gen_helper_neon_qdmulh_s32_x86_64
#define gen_helper_neon_qneg_s16 gen_helper_neon_qneg_s16_x86_64
#define gen_helper_neon_qneg_s32 gen_helper_neon_qneg_s32_x86_64
#define gen_helper_neon_qneg_s8 gen_helper_neon_qneg_s8_x86_64
#define gen_helper_neon_qrdmulh_s16 gen_helper_neon_qrdmulh_s16_x86_64
#define gen_helper_neon_qrdmulh_s32 gen_helper_neon_qrdmulh_s32_x86_64
#define gen_helper_neon_qrshl_s16 gen_helper_neon_qrshl_s16_x86_64
#define gen_helper_neon_qrshl_s32 gen_helper_neon_qrshl_s32_x86_64
#define gen_helper_neon_qrshl_s64 gen_helper_neon_qrshl_s64_x86_64
#define gen_helper_neon_qrshl_s8 gen_helper_neon_qrshl_s8_x86_64
#define gen_helper_neon_qrshl_u16 gen_helper_neon_qrshl_u16_x86_64
#define gen_helper_neon_qrshl_u32 gen_helper_neon_qrshl_u32_x86_64
#define gen_helper_neon_qrshl_u64 gen_helper_neon_qrshl_u64_x86_64
#define gen_helper_neon_qrshl_u8 gen_helper_neon_qrshl_u8_x86_64
#define gen_helper_neon_qshl_s16 gen_helper_neon_qshl_s16_x86_64
#define gen_helper_neon_qshl_s32 gen_helper_neon_qshl_s32_x86_64
#define gen_helper_neon_qshl_s64 gen_helper_neon_qshl_s64_x86_64
#define gen_helper_neon_qshl_s8 gen_helper_neon_qshl_s8_x86_64
#define gen_helper_neon_qshl_u16 gen_helper_neon_qshl_u16_x86_64
#define gen_helper_neon_qshl_u32 gen_helper_neon_qshl_u32_x86_64
#define gen_helper_neon_qshl_u64 gen_helper_neon_qshl_u64_x86_64
#define gen_helper_neon_qshl_u8 gen_helper_neon_qshl_u8_x86_64
#define gen_helper_neon_qshlu_s16 gen_helper_neon_qshlu_s16_x86_64
#define gen_helper_neon_qshlu_s32 gen_helper_neon_qshlu_s32_x86_64
#define gen_helper_neon_qshlu_s64 gen_helper_neon_qshlu_s64_x86_64
#define gen_helper_neon_qshlu_s8 gen_helper_neon_qshlu_s8_x86_64
#define gen_helper_neon_qsub_s16 gen_helper_neon_qsub_s16_x86_64
#define gen_helper_neon_qsub_s32 gen_helper_neon_qsub_s32_x86_64
#define gen_helper_neon_qsub_s64 gen_helper_neon_qsub_s64_x86_64
#define gen_helper_neon_qsub_s8 gen_helper_neon_qsub_s8_x86_64
#define gen_helper_neon_qsub_u16 gen_helper_neon_qsub_u16_x86_64
#define gen_helper_neon_qsub_u32 gen_helper_neon_qsub_u32_x86_64
#define gen_helper_neon_qsub_u64 gen_helper_neon_qsub_u64_x86_64
#define gen_helper_neon_qsub_u8 gen_helper_neon_qsub_u8_x86_64
#define gen_helper_neon_qunzip16 gen_helper_neon_qunzip16_x86_64
#define gen_helper_neon_qunzip32 gen_helper_neon_qunzip32_x86_64
#define gen_helper_neon_qunzip8 gen_helper_neon_qunzip8_x86_64
#define gen_helper_neon_qzip16 gen_helper_neon_qzip16_x86_64
#define gen_helper_neon_qzip32 gen_helper_neon_qzip32_x86_64
#define gen_helper_neon_qzip8 gen_helper_neon_qzip8_x86_64
#define gen_helper_neon_rhadd_s16 gen_helper_neon_rhadd_s16_x86_64
#define gen_helper_neon_rhadd_s32 gen_helper_neon_rhadd_s32_x86_64
#define gen_helper_neon_rhadd_s8 gen_helper_neon_rhadd_s8_x86_64
#define gen_helper_neon_rhadd_u16 gen_helper_neon_rhadd_u16_x86_64
#define gen_helper_neon_rhadd_u32 gen_helper_neon_rhadd_u32_x86_64
#define gen_helper_neon_rhadd_u8 gen_helper_neon_rhadd_u8_x86_64
#define gen_helper_neon_rshl_s16 gen_helper_neon_rshl_s16_x86_64
#define gen_helper_neon_rshl_s32 gen_helper_neon_rshl_s32_x86_64
#define gen_helper_neon_rshl_s64 gen_helper_neon_rshl_s64_x86_64
#define gen_helper_neon_rshl_s8 gen_helper_neon_rshl_s8_x86_64
#define gen_helper_neon_rshl_u16 gen_helper_neon_rshl_u16_x86_64
#define gen_helper_neon_rshl_u32 gen_helper_neon_rshl_u32_x86_64
#define gen_helper_neon_rshl_u64 gen_helper_neon_rshl_u64_x86_64
#define gen_helper_neon_rshl_u8 gen_helper_neon_rshl_u8_x86_64
#define gen_helper_neon_shl_s16 gen_helper_neon_shl_s16_x86_64
#define gen_helper_neon_shl_s32 gen_helper_neon_shl_s32_x86_64
#define gen_helper_neon_shl_s64 gen_helper_neon_shl_s64_x86_64
#define gen_helper_neon_shl_s8 gen_helper_neon_shl_s8_x86_64
#define gen_helper_neon_shl_u16 gen_helper_neon_shl_u16_x86_64
#define gen_helper_neon_shl_u32 gen_helper_neon_shl_u32_x86_64
#define gen_helper_neon_shl_u64 gen_helper_neon_shl_u64_x86_64
#define gen_helper_neon_shl_u8 gen_helper_neon_shl_u8_x86_64
#define gen_helper_neon_subl_u16 gen_helper_neon_subl_u16_x86_64
#define gen_helper_neon_subl_u32 gen_helper_neon_subl_u32_x86_64
#define gen_helper_neon_sub_u16 gen_helper_neon_sub_u16_x86_64
#define gen_helper_neon_sub_u8 gen_helper_neon_sub_u8_x86_64
#define gen_helper_neon_tbl gen_helper_neon_tbl_x86_64
#define gen_helper_neon_tst_u16 gen_helper_neon_tst_u16_x86_64
#define gen_helper_neon_tst_u32 gen_helper_neon_tst_u32_x86_64
#define gen_helper_neon_tst_u8 gen_helper_neon_tst_u8_x86_64
#define gen_helper_neon_unarrow_sat16 gen_helper_neon_unarrow_sat16_x86_64
#define gen_helper_neon_unarrow_sat32 gen_helper_neon_unarrow_sat32_x86_64
#define gen_helper_neon_unarrow_sat8 gen_helper_neon_unarrow_sat8_x86_64
#define gen_helper_neon_unzip16 gen_helper_neon_unzip16_x86_64
#define gen_helper_neon_unzip8 gen_helper_neon_unzip8_x86_64
#define gen_helper_neon_widen_s16 gen_helper_neon_widen_s16_x86_64
#define gen_helper_neon_widen_s8 gen_helper_neon_widen_s8_x86_64
#define gen_helper_neon_widen_u16 gen_helper_neon_widen_u16_x86_64
#define gen_helper_neon_widen_u8 gen_helper_neon_widen_u8_x86_64
#define gen_helper_neon_zip16 gen_helper_neon_zip16_x86_64
#define gen_helper_neon_zip8 gen_helper_neon_zip8_x86_64
#define gen_helper_pre_hvc gen_helper_pre_hvc_x86_64
#define gen_helper_pre_smc gen_helper_pre_smc_x86_64
#define gen_helper_qadd16 gen_helper_qadd16_x86_64
#define gen_helper_qadd8 gen_helper_qadd8_x86_64
#define gen_helper_qaddsubx gen_helper_qaddsubx_x86_64
#define gen_helper_qsub16 gen_helper_qsub16_x86_64
#define gen_helper_qsub8 gen_helper_qsub8_x86_64
#define gen_helper_qsubaddx gen_helper_qsubaddx_x86_64
#define gen_helper_rbit gen_helper_rbit_x86_64
#define gen_helper_recpe_f32 gen_helper_recpe_f32_x86_64
#define gen_helper_recpe_u32 gen_helper_recpe_u32_x86_64
#define gen_helper_recps_f32 gen_helper_recps_f32_x86_64
#define gen_helper_rintd gen_helper_rintd_x86_64
#define gen_helper_rintd_exact gen_helper_rintd_exact_x86_64
#define gen_helper_rints gen_helper_rints_x86_64
#define gen_helper_rints_exact gen_helper_rints_exact_x86_64
#define gen_helper_ror_cc gen_helper_ror_cc_x86_64
#define gen_helper_rsqrte_f32 gen_helper_rsqrte_f32_x86_64
#define gen_helper_rsqrte_u32 gen_helper_rsqrte_u32_x86_64
#define gen_helper_rsqrts_f32 gen_helper_rsqrts_f32_x86_64
#define gen_helper_sadd16 gen_helper_sadd16_x86_64
#define gen_helper_sadd8 gen_helper_sadd8_x86_64
#define gen_helper_saddsubx gen_helper_saddsubx_x86_64
#define gen_helper_sar_cc gen_helper_sar_cc_x86_64
#define gen_helper_sdiv gen_helper_sdiv_x86_64
#define gen_helper_sel_flags gen_helper_sel_flags_x86_64
#define gen_helper_set_cp_reg gen_helper_set_cp_reg_x86_64
#define gen_helper_set_cp_reg64 gen_helper_set_cp_reg64_x86_64
#define gen_helper_set_neon_rmode gen_helper_set_neon_rmode_x86_64
#define gen_helper_set_r13_banked gen_helper_set_r13_banked_x86_64
#define gen_helper_set_rmode gen_helper_set_rmode_x86_64
#define gen_helper_set_user_reg gen_helper_set_user_reg_x86_64
#define gen_helper_shadd16 gen_helper_shadd16_x86_64
#define gen_helper_shadd8 gen_helper_shadd8_x86_64
#define gen_helper_shaddsubx gen_helper_shaddsubx_x86_64
#define gen_helper_shl_cc gen_helper_shl_cc_x86_64
#define gen_helper_shr_cc gen_helper_shr_cc_x86_64
#define gen_helper_shsub16 gen_helper_shsub16_x86_64
#define gen_helper_shsub8 gen_helper_shsub8_x86_64
#define gen_helper_shsubaddx gen_helper_shsubaddx_x86_64
#define gen_helper_ssat gen_helper_ssat_x86_64
#define gen_helper_ssat16 gen_helper_ssat16_x86_64
#define gen_helper_ssub16 gen_helper_ssub16_x86_64
#define gen_helper_ssub8 gen_helper_ssub8_x86_64
#define gen_helper_ssubaddx gen_helper_ssubaddx_x86_64
#define gen_helper_sub_saturate gen_helper_sub_saturate_x86_64
#define gen_helper_sxtb16 gen_helper_sxtb16_x86_64
#define gen_helper_uadd16 gen_helper_uadd16_x86_64
#define gen_helper_uadd8 gen_helper_uadd8_x86_64
#define gen_helper_uaddsubx gen_helper_uaddsubx_x86_64
#define gen_helper_udiv gen_helper_udiv_x86_64
#define gen_helper_uhadd16 gen_helper_uhadd16_x86_64
#define gen_helper_uhadd8 gen_helper_uhadd8_x86_64
#define gen_helper_uhaddsubx gen_helper_uhaddsubx_x86_64
#define gen_helper_uhsub16 gen_helper_uhsub16_x86_64
#define gen_helper_uhsub8 gen_helper_uhsub8_x86_64
#define gen_helper_uhsubaddx gen_helper_uhsubaddx_x86_64
#define gen_helper_uqadd16 gen_helper_uqadd16_x86_64
#define gen_helper_uqadd8 gen_helper_uqadd8_x86_64
#define gen_helper_uqaddsubx gen_helper_uqaddsubx_x86_64
#define gen_helper_uqsub16 gen_helper_uqsub16_x86_64
#define gen_helper_uqsub8 gen_helper_uqsub8_x86_64
#define gen_helper_uqsubaddx gen_helper_uqsubaddx_x86_64
#define gen_helper_usad8 gen_helper_usad8_x86_64
#define gen_helper_usat gen_helper_usat_x86_64
#define gen_helper_usat16 gen_helper_usat16_x86_64
#define gen_helper_usub16 gen_helper_usub16_x86_64
#define gen_helper_usub8 gen_helper_usub8_x86_64
#define gen_helper_usubaddx gen_helper_usubaddx_x86_64
#define gen_helper_uxtb16 gen_helper_uxtb16_x86_64
#define gen_helper_v7m_mrs gen_helper_v7m_mrs_x86_64
#define gen_helper_v7m_msr gen_helper_v7m_msr_x86_64
#define gen_helper_vfp_absd gen_helper_vfp_absd_x86_64
#define gen_helper_vfp_abss gen_helper_vfp_abss_x86_64
#define gen_helper_vfp_addd gen_helper_vfp_addd_x86_64
#define gen_helper_vfp_adds gen_helper_vfp_adds_x86_64
#define gen_helper_vfp_cmpd gen_helper_vfp_cmpd_x86_64
#define gen_helper_vfp_cmped gen_helper_vfp_cmped_x86_64
#define gen_helper_vfp_cmpes gen_helper_vfp_cmpes_x86_64
#define gen_helper_vfp_cmps gen_helper_vfp_cmps_x86_64
#define gen_helper_vfp_divd gen_helper_vfp_divd_x86_64
#define gen_helper_vfp_divs gen_helper_vfp_divs_x86_64
#define gen_helper_vfp_fcvtds gen_helper_vfp_fcvtds_x86_64
#define gen_helper_vfp_fcvt_f16_to_f32 gen_helper_vfp_fcvt_f16_to_f32_x86_64
#define gen_helper_vfp_fcvt_f16_to_f64 gen_helper_vfp_fcvt_f16_to_f64_x86_64
#define gen_helper_vfp_fcvt_f32_to_f16 gen_helper_vfp_fcvt_f32_to_f16_x86_64
#define gen_helper_vfp_fcvt_f64_to_f16 gen_helper_vfp_fcvt_f64_to_f16_x86_64
#define gen_helper_vfp_fcvtsd gen_helper_vfp_fcvtsd_x86_64
#define gen_helper_vfp_get_fpscr gen_helper_vfp_get_fpscr_x86_64
#define gen_helper_vfp_maxnumd gen_helper_vfp_maxnumd_x86_64
#define gen_helper_vfp_maxnums gen_helper_vfp_maxnums_x86_64
#define gen_helper_vfp_maxs gen_helper_vfp_maxs_x86_64
#define gen_helper_vfp_minnumd gen_helper_vfp_minnumd_x86_64
#define gen_helper_vfp_minnums gen_helper_vfp_minnums_x86_64
#define gen_helper_vfp_mins gen_helper_vfp_mins_x86_64
#define gen_helper_vfp_muladdd gen_helper_vfp_muladdd_x86_64
#define gen_helper_vfp_muladds gen_helper_vfp_muladds_x86_64
#define gen_helper_vfp_muld gen_helper_vfp_muld_x86_64
#define gen_helper_vfp_muls gen_helper_vfp_muls_x86_64
#define gen_helper_vfp_negd gen_helper_vfp_negd_x86_64
#define gen_helper_vfp_negs gen_helper_vfp_negs_x86_64
#define gen_helper_vfp_set_fpscr gen_helper_vfp_set_fpscr_x86_64
#define gen_helper_vfp_shtod gen_helper_vfp_shtod_x86_64
#define gen_helper_vfp_shtos gen_helper_vfp_shtos_x86_64
#define gen_helper_vfp_sitod gen_helper_vfp_sitod_x86_64
#define gen_helper_vfp_sitos gen_helper_vfp_sitos_x86_64
#define gen_helper_vfp_sltod gen_helper_vfp_sltod_x86_64
#define gen_helper_vfp_sltos gen_helper_vfp_sltos_x86_64
#define gen_helper_vfp_sqrtd gen_helper_vfp_sqrtd_x86_64
#define gen_helper_vfp_sqrts gen_helper_vfp_sqrts_x86_64
#define gen_helper_vfp_subd gen_helper_vfp_subd_x86_64
#define gen_helper_vfp_subs gen_helper_vfp_subs_x86_64
#define gen_helper_vfp_toshd_round_to_zero gen_helper_vfp_toshd_round_to_zero_x86_64
#define gen_helper_vfp_toshs_round_to_zero gen_helper_vfp_toshs_round_to_zero_x86_64
#define gen_helper_vfp_tosid gen_helper_vfp_tosid_x86_64
#define gen_helper_vfp_tosis gen_helper_vfp_tosis_x86_64
#define gen_helper_vfp_tosizd gen_helper_vfp_tosizd_x86_64
#define gen_helper_vfp_tosizs gen_helper_vfp_tosizs_x86_64
#define gen_helper_vfp_tosld gen_helper_vfp_tosld_x86_64
#define gen_helper_vfp_tosld_round_to_zero gen_helper_vfp_tosld_round_to_zero_x86_64
#define gen_helper_vfp_tosls gen_helper_vfp_tosls_x86_64
#define gen_helper_vfp_tosls_round_to_zero gen_helper_vfp_tosls_round_to_zero_x86_64
#define gen_helper_vfp_touhd_round_to_zero gen_helper_vfp_touhd_round_to_zero_x86_64
#define gen_helper_vfp_touhs_round_to_zero gen_helper_vfp_touhs_round_to_zero_x86_64
#define gen_helper_vfp_touid gen_helper_vfp_touid_x86_64
#define gen_helper_vfp_touis gen_helper_vfp_touis_x86_64
#define gen_helper_vfp_touizd gen_helper_vfp_touizd_x86_64
#define gen_helper_vfp_touizs gen_helper_vfp_touizs_x86_64
#define gen_helper_vfp_tould gen_helper_vfp_tould_x86_64
#define gen_helper_vfp_tould_round_to_zero gen_helper_vfp_tould_round_to_zero_x86_64
#define gen_helper_vfp_touls gen_helper_vfp_touls_x86_64
#define gen_helper_vfp_touls_round_to_zero gen_helper_vfp_touls_round_to_zero_x86_64
#define gen_helper_vfp_uhtod gen_helper_vfp_uhtod_x86_64
#define gen_helper_vfp_uhtos gen_helper_vfp_uhtos_x86_64
#define gen_helper_vfp_uitod gen_helper_vfp_uitod_x86_64
#define gen_helper_vfp_uitos gen_helper_vfp_uitos_x86_64
#define gen_helper_vfp_ultod gen_helper_vfp_ultod_x86_64
#define gen_helper_vfp_ultos gen_helper_vfp_ultos_x86_64
#define gen_helper_wfe gen_helper_wfe_x86_64
#define gen_helper_wfi gen_helper_wfi_x86_64
#define gen_hvc gen_hvc_x86_64
#define gen_intermediate_code_internal gen_intermediate_code_internal_x86_64
#define gen_intermediate_code_internal_a64 gen_intermediate_code_internal_a64_x86_64
#define gen_iwmmxt_address gen_iwmmxt_address_x86_64
#define gen_iwmmxt_shift gen_iwmmxt_shift_x86_64
#define gen_jmp gen_jmp_x86_64
#define gen_load_and_replicate gen_load_and_replicate_x86_64
#define gen_load_exclusive gen_load_exclusive_x86_64
#define gen_logic_CC gen_logic_CC_x86_64
#define gen_logicq_cc gen_logicq_cc_x86_64
#define gen_lookup_tb gen_lookup_tb_x86_64
#define gen_mov_F0_vreg gen_mov_F0_vreg_x86_64
#define gen_mov_F1_vreg gen_mov_F1_vreg_x86_64
#define gen_mov_vreg_F0 gen_mov_vreg_F0_x86_64
#define gen_muls_i64_i32 gen_muls_i64_i32_x86_64
#define gen_mulu_i64_i32 gen_mulu_i64_i32_x86_64
#define gen_mulxy gen_mulxy_x86_64
#define gen_neon_add gen_neon_add_x86_64
#define gen_neon_addl gen_neon_addl_x86_64
#define gen_neon_addl_saturate gen_neon_addl_saturate_x86_64
#define gen_neon_bsl gen_neon_bsl_x86_64
#define gen_neon_dup_high16 gen_neon_dup_high16_x86_64
#define gen_neon_dup_low16 gen_neon_dup_low16_x86_64
#define gen_neon_dup_u8 gen_neon_dup_u8_x86_64
#define gen_neon_mull gen_neon_mull_x86_64
#define gen_neon_narrow gen_neon_narrow_x86_64
#define gen_neon_narrow_op gen_neon_narrow_op_x86_64
#define gen_neon_narrow_sats gen_neon_narrow_sats_x86_64
#define gen_neon_narrow_satu gen_neon_narrow_satu_x86_64
#define gen_neon_negl gen_neon_negl_x86_64
#define gen_neon_rsb gen_neon_rsb_x86_64
#define gen_neon_shift_narrow gen_neon_shift_narrow_x86_64
#define gen_neon_subl gen_neon_subl_x86_64
#define gen_neon_trn_u16 gen_neon_trn_u16_x86_64
#define gen_neon_trn_u8 gen_neon_trn_u8_x86_64
#define gen_neon_unarrow_sats gen_neon_unarrow_sats_x86_64
#define gen_neon_unzip gen_neon_unzip_x86_64
#define gen_neon_widen gen_neon_widen_x86_64
#define gen_neon_zip gen_neon_zip_x86_64
#define gen_new_label gen_new_label_x86_64
#define gen_nop_hint gen_nop_hint_x86_64
#define gen_op_iwmmxt_addl_M0_wRn gen_op_iwmmxt_addl_M0_wRn_x86_64
#define gen_op_iwmmxt_addnb_M0_wRn gen_op_iwmmxt_addnb_M0_wRn_x86_64
#define gen_op_iwmmxt_addnl_M0_wRn gen_op_iwmmxt_addnl_M0_wRn_x86_64
#define gen_op_iwmmxt_addnw_M0_wRn gen_op_iwmmxt_addnw_M0_wRn_x86_64
#define gen_op_iwmmxt_addsb_M0_wRn gen_op_iwmmxt_addsb_M0_wRn_x86_64
#define gen_op_iwmmxt_addsl_M0_wRn gen_op_iwmmxt_addsl_M0_wRn_x86_64
#define gen_op_iwmmxt_addsw_M0_wRn gen_op_iwmmxt_addsw_M0_wRn_x86_64
#define gen_op_iwmmxt_addub_M0_wRn gen_op_iwmmxt_addub_M0_wRn_x86_64
#define gen_op_iwmmxt_addul_M0_wRn gen_op_iwmmxt_addul_M0_wRn_x86_64
#define gen_op_iwmmxt_adduw_M0_wRn gen_op_iwmmxt_adduw_M0_wRn_x86_64
#define gen_op_iwmmxt_andq_M0_wRn gen_op_iwmmxt_andq_M0_wRn_x86_64
#define gen_op_iwmmxt_avgb0_M0_wRn gen_op_iwmmxt_avgb0_M0_wRn_x86_64
#define gen_op_iwmmxt_avgb1_M0_wRn gen_op_iwmmxt_avgb1_M0_wRn_x86_64
#define gen_op_iwmmxt_avgw0_M0_wRn gen_op_iwmmxt_avgw0_M0_wRn_x86_64
#define gen_op_iwmmxt_avgw1_M0_wRn gen_op_iwmmxt_avgw1_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpeqb_M0_wRn gen_op_iwmmxt_cmpeqb_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpeql_M0_wRn gen_op_iwmmxt_cmpeql_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpeqw_M0_wRn gen_op_iwmmxt_cmpeqw_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtsb_M0_wRn gen_op_iwmmxt_cmpgtsb_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtsl_M0_wRn gen_op_iwmmxt_cmpgtsl_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtsw_M0_wRn gen_op_iwmmxt_cmpgtsw_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtub_M0_wRn gen_op_iwmmxt_cmpgtub_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtul_M0_wRn gen_op_iwmmxt_cmpgtul_M0_wRn_x86_64
#define gen_op_iwmmxt_cmpgtuw_M0_wRn gen_op_iwmmxt_cmpgtuw_M0_wRn_x86_64
#define gen_op_iwmmxt_macsw_M0_wRn gen_op_iwmmxt_macsw_M0_wRn_x86_64
#define gen_op_iwmmxt_macuw_M0_wRn gen_op_iwmmxt_macuw_M0_wRn_x86_64
#define gen_op_iwmmxt_maddsq_M0_wRn gen_op_iwmmxt_maddsq_M0_wRn_x86_64
#define gen_op_iwmmxt_madduq_M0_wRn gen_op_iwmmxt_madduq_M0_wRn_x86_64
#define gen_op_iwmmxt_maxsb_M0_wRn gen_op_iwmmxt_maxsb_M0_wRn_x86_64
#define gen_op_iwmmxt_maxsl_M0_wRn gen_op_iwmmxt_maxsl_M0_wRn_x86_64
#define gen_op_iwmmxt_maxsw_M0_wRn gen_op_iwmmxt_maxsw_M0_wRn_x86_64
#define gen_op_iwmmxt_maxub_M0_wRn gen_op_iwmmxt_maxub_M0_wRn_x86_64
#define gen_op_iwmmxt_maxul_M0_wRn gen_op_iwmmxt_maxul_M0_wRn_x86_64
#define gen_op_iwmmxt_maxuw_M0_wRn gen_op_iwmmxt_maxuw_M0_wRn_x86_64
#define gen_op_iwmmxt_minsb_M0_wRn gen_op_iwmmxt_minsb_M0_wRn_x86_64
#define gen_op_iwmmxt_minsl_M0_wRn gen_op_iwmmxt_minsl_M0_wRn_x86_64
#define gen_op_iwmmxt_minsw_M0_wRn gen_op_iwmmxt_minsw_M0_wRn_x86_64
#define gen_op_iwmmxt_minub_M0_wRn gen_op_iwmmxt_minub_M0_wRn_x86_64
#define gen_op_iwmmxt_minul_M0_wRn gen_op_iwmmxt_minul_M0_wRn_x86_64
#define gen_op_iwmmxt_minuw_M0_wRn gen_op_iwmmxt_minuw_M0_wRn_x86_64
#define gen_op_iwmmxt_movq_M0_wRn gen_op_iwmmxt_movq_M0_wRn_x86_64
#define gen_op_iwmmxt_movq_wRn_M0 gen_op_iwmmxt_movq_wRn_M0_x86_64
#define gen_op_iwmmxt_mulshw_M0_wRn gen_op_iwmmxt_mulshw_M0_wRn_x86_64
#define gen_op_iwmmxt_mulslw_M0_wRn gen_op_iwmmxt_mulslw_M0_wRn_x86_64
#define gen_op_iwmmxt_muluhw_M0_wRn gen_op_iwmmxt_muluhw_M0_wRn_x86_64
#define gen_op_iwmmxt_mululw_M0_wRn gen_op_iwmmxt_mululw_M0_wRn_x86_64
#define gen_op_iwmmxt_orq_M0_wRn gen_op_iwmmxt_orq_M0_wRn_x86_64
#define gen_op_iwmmxt_packsl_M0_wRn gen_op_iwmmxt_packsl_M0_wRn_x86_64
#define gen_op_iwmmxt_packsq_M0_wRn gen_op_iwmmxt_packsq_M0_wRn_x86_64
#define gen_op_iwmmxt_packsw_M0_wRn gen_op_iwmmxt_packsw_M0_wRn_x86_64
#define gen_op_iwmmxt_packul_M0_wRn gen_op_iwmmxt_packul_M0_wRn_x86_64
#define gen_op_iwmmxt_packuq_M0_wRn gen_op_iwmmxt_packuq_M0_wRn_x86_64
#define gen_op_iwmmxt_packuw_M0_wRn gen_op_iwmmxt_packuw_M0_wRn_x86_64
#define gen_op_iwmmxt_sadb_M0_wRn gen_op_iwmmxt_sadb_M0_wRn_x86_64
#define gen_op_iwmmxt_sadw_M0_wRn gen_op_iwmmxt_sadw_M0_wRn_x86_64
#define gen_op_iwmmxt_set_cup gen_op_iwmmxt_set_cup_x86_64
#define gen_op_iwmmxt_set_mup gen_op_iwmmxt_set_mup_x86_64
#define gen_op_iwmmxt_setpsr_nz gen_op_iwmmxt_setpsr_nz_x86_64
#define gen_op_iwmmxt_subnb_M0_wRn gen_op_iwmmxt_subnb_M0_wRn_x86_64
#define gen_op_iwmmxt_subnl_M0_wRn gen_op_iwmmxt_subnl_M0_wRn_x86_64
#define gen_op_iwmmxt_subnw_M0_wRn gen_op_iwmmxt_subnw_M0_wRn_x86_64
#define gen_op_iwmmxt_subsb_M0_wRn gen_op_iwmmxt_subsb_M0_wRn_x86_64
#define gen_op_iwmmxt_subsl_M0_wRn gen_op_iwmmxt_subsl_M0_wRn_x86_64
#define gen_op_iwmmxt_subsw_M0_wRn gen_op_iwmmxt_subsw_M0_wRn_x86_64
#define gen_op_iwmmxt_subub_M0_wRn gen_op_iwmmxt_subub_M0_wRn_x86_64
#define gen_op_iwmmxt_subul_M0_wRn gen_op_iwmmxt_subul_M0_wRn_x86_64
#define gen_op_iwmmxt_subuw_M0_wRn gen_op_iwmmxt_subuw_M0_wRn_x86_64
#define gen_op_iwmmxt_unpackhb_M0_wRn gen_op_iwmmxt_unpackhb_M0_wRn_x86_64
#define gen_op_iwmmxt_unpackhl_M0_wRn gen_op_iwmmxt_unpackhl_M0_wRn_x86_64
#define gen_op_iwmmxt_unpackhsb_M0 gen_op_iwmmxt_unpackhsb_M0_x86_64
#define gen_op_iwmmxt_unpackhsl_M0 gen_op_iwmmxt_unpackhsl_M0_x86_64
#define gen_op_iwmmxt_unpackhsw_M0 gen_op_iwmmxt_unpackhsw_M0_x86_64
#define gen_op_iwmmxt_unpackhub_M0 gen_op_iwmmxt_unpackhub_M0_x86_64
#define gen_op_iwmmxt_unpackhul_M0 gen_op_iwmmxt_unpackhul_M0_x86_64
#define gen_op_iwmmxt_unpackhuw_M0 gen_op_iwmmxt_unpackhuw_M0_x86_64
#define gen_op_iwmmxt_unpackhw_M0_wRn gen_op_iwmmxt_unpackhw_M0_wRn_x86_64
#define gen_op_iwmmxt_unpacklb_M0_wRn gen_op_iwmmxt_unpacklb_M0_wRn_x86_64
#define gen_op_iwmmxt_unpackll_M0_wRn gen_op_iwmmxt_unpackll_M0_wRn_x86_64
#define gen_op_iwmmxt_unpacklsb_M0 gen_op_iwmmxt_unpacklsb_M0_x86_64
#define gen_op_iwmmxt_unpacklsl_M0 gen_op_iwmmxt_unpacklsl_M0_x86_64
#define gen_op_iwmmxt_unpacklsw_M0 gen_op_iwmmxt_unpacklsw_M0_x86_64
#define gen_op_iwmmxt_unpacklub_M0 gen_op_iwmmxt_unpacklub_M0_x86_64
#define gen_op_iwmmxt_unpacklul_M0 gen_op_iwmmxt_unpacklul_M0_x86_64
#define gen_op_iwmmxt_unpackluw_M0 gen_op_iwmmxt_unpackluw_M0_x86_64
#define gen_op_iwmmxt_unpacklw_M0_wRn gen_op_iwmmxt_unpacklw_M0_wRn_x86_64
#define gen_op_iwmmxt_xorq_M0_wRn gen_op_iwmmxt_xorq_M0_wRn_x86_64
#define gen_rev16 gen_rev16_x86_64
#define gen_revsh gen_revsh_x86_64
#define gen_rfe gen_rfe_x86_64
#define gen_sar gen_sar_x86_64
#define gen_sbc_CC gen_sbc_CC_x86_64
#define gen_sbfx gen_sbfx_x86_64
#define gen_set_CF_bit31 gen_set_CF_bit31_x86_64
#define gen_set_condexec gen_set_condexec_x86_64
#define gen_set_cpsr gen_set_cpsr_x86_64
#define gen_set_label gen_set_label_x86_64
#define gen_set_pc_im gen_set_pc_im_x86_64
#define gen_set_psr gen_set_psr_x86_64
#define gen_set_psr_im gen_set_psr_im_x86_64
#define gen_shl gen_shl_x86_64
#define gen_shr gen_shr_x86_64
#define gen_smc gen_smc_x86_64
#define gen_smul_dual gen_smul_dual_x86_64
#define gen_srs gen_srs_x86_64
#define gen_ss_advance gen_ss_advance_x86_64
#define gen_step_complete_exception gen_step_complete_exception_x86_64
#define gen_store_exclusive gen_store_exclusive_x86_64
#define gen_storeq_reg gen_storeq_reg_x86_64
#define gen_sub_carry gen_sub_carry_x86_64
#define gen_sub_CC gen_sub_CC_x86_64
#define gen_subq_msw gen_subq_msw_x86_64
#define gen_swap_half gen_swap_half_x86_64
#define gen_thumb2_data_op gen_thumb2_data_op_x86_64
#define gen_thumb2_parallel_addsub gen_thumb2_parallel_addsub_x86_64
#define gen_ubfx gen_ubfx_x86_64
#define gen_vfp_abs gen_vfp_abs_x86_64
#define gen_vfp_add gen_vfp_add_x86_64
#define gen_vfp_cmp gen_vfp_cmp_x86_64
#define gen_vfp_cmpe gen_vfp_cmpe_x86_64
#define gen_vfp_div gen_vfp_div_x86_64
#define gen_vfp_F1_ld0 gen_vfp_F1_ld0_x86_64
#define gen_vfp_F1_mul gen_vfp_F1_mul_x86_64
#define gen_vfp_F1_neg gen_vfp_F1_neg_x86_64
#define gen_vfp_ld gen_vfp_ld_x86_64
#define gen_vfp_mrs gen_vfp_mrs_x86_64
#define gen_vfp_msr gen_vfp_msr_x86_64
#define gen_vfp_mul gen_vfp_mul_x86_64
#define gen_vfp_neg gen_vfp_neg_x86_64
#define gen_vfp_shto gen_vfp_shto_x86_64
#define gen_vfp_sito gen_vfp_sito_x86_64
#define gen_vfp_slto gen_vfp_slto_x86_64
#define gen_vfp_sqrt gen_vfp_sqrt_x86_64
#define gen_vfp_st gen_vfp_st_x86_64
#define gen_vfp_sub gen_vfp_sub_x86_64
#define gen_vfp_tosh gen_vfp_tosh_x86_64
#define gen_vfp_tosi gen_vfp_tosi_x86_64
#define gen_vfp_tosiz gen_vfp_tosiz_x86_64
#define gen_vfp_tosl gen_vfp_tosl_x86_64
#define gen_vfp_touh gen_vfp_touh_x86_64
#define gen_vfp_toui gen_vfp_toui_x86_64
#define gen_vfp_touiz gen_vfp_touiz_x86_64
#define gen_vfp_toul gen_vfp_toul_x86_64
#define gen_vfp_uhto gen_vfp_uhto_x86_64
#define gen_vfp_uito gen_vfp_uito_x86_64
#define gen_vfp_ulto gen_vfp_ulto_x86_64
#define get_arm_cp_reginfo get_arm_cp_reginfo_x86_64
#define get_clock get_clock_x86_64
#define get_clock_realtime get_clock_realtime_x86_64
#define get_constraint_priority get_constraint_priority_x86_64
#define get_float_exception_flags get_float_exception_flags_x86_64
#define get_float_rounding_mode get_float_rounding_mode_x86_64
#define get_fpstatus_ptr get_fpstatus_ptr_x86_64
#define get_level1_table_address get_level1_table_address_x86_64
#define get_mem_index get_mem_index_x86_64
#define get_next_param_value get_next_param_value_x86_64
#define get_opt_name get_opt_name_x86_64
#define get_opt_value get_opt_value_x86_64
#define get_page_addr_code get_page_addr_code_x86_64
#define get_param_value get_param_value_x86_64
#define get_phys_addr get_phys_addr_x86_64
#define get_phys_addr_lpae get_phys_addr_lpae_x86_64
#define get_phys_addr_mpu get_phys_addr_mpu_x86_64
#define get_phys_addr_v5 get_phys_addr_v5_x86_64
#define get_phys_addr_v6 get_phys_addr_v6_x86_64
#define get_system_memory get_system_memory_x86_64
#define get_ticks_per_sec get_ticks_per_sec_x86_64
#define g_list_insert_sorted_merged g_list_insert_sorted_merged_x86_64
#define _GLOBAL_OFFSET_TABLE_ _GLOBAL_OFFSET_TABLE__x86_64
#define gt_cntfrq_access gt_cntfrq_access_x86_64
#define gt_cnt_read gt_cnt_read_x86_64
#define gt_cnt_reset gt_cnt_reset_x86_64
#define gt_counter_access gt_counter_access_x86_64
#define gt_ctl_write gt_ctl_write_x86_64
#define gt_cval_write gt_cval_write_x86_64
#define gt_get_countervalue gt_get_countervalue_x86_64
#define gt_pct_access gt_pct_access_x86_64
#define gt_ptimer_access gt_ptimer_access_x86_64
#define gt_recalc_timer gt_recalc_timer_x86_64
#define gt_timer_access gt_timer_access_x86_64
#define gt_tval_read gt_tval_read_x86_64
#define gt_tval_write gt_tval_write_x86_64
#define gt_vct_access gt_vct_access_x86_64
#define gt_vtimer_access gt_vtimer_access_x86_64
#define guest_phys_blocks_free guest_phys_blocks_free_x86_64
#define guest_phys_blocks_init guest_phys_blocks_init_x86_64
#define handle_vcvt handle_vcvt_x86_64
#define handle_vminmaxnm handle_vminmaxnm_x86_64
#define handle_vrint handle_vrint_x86_64
#define handle_vsel handle_vsel_x86_64
#define has_help_option has_help_option_x86_64
#define have_bmi1 have_bmi1_x86_64
#define have_bmi2 have_bmi2_x86_64
#define hcr_write hcr_write_x86_64
#define helper_access_check_cp_reg helper_access_check_cp_reg_x86_64
#define helper_add_saturate helper_add_saturate_x86_64
#define helper_add_setq helper_add_setq_x86_64
#define helper_add_usaturate helper_add_usaturate_x86_64
#define helper_be_ldl_cmmu helper_be_ldl_cmmu_x86_64
#define helper_be_ldq_cmmu helper_be_ldq_cmmu_x86_64
#define helper_be_ldq_mmu helper_be_ldq_mmu_x86_64
#define helper_be_ldsl_mmu helper_be_ldsl_mmu_x86_64
#define helper_be_ldsw_mmu helper_be_ldsw_mmu_x86_64
#define helper_be_ldul_mmu helper_be_ldul_mmu_x86_64
#define helper_be_lduw_mmu helper_be_lduw_mmu_x86_64
#define helper_be_ldw_cmmu helper_be_ldw_cmmu_x86_64
#define helper_be_stl_mmu helper_be_stl_mmu_x86_64
#define helper_be_stq_mmu helper_be_stq_mmu_x86_64
#define helper_be_stw_mmu helper_be_stw_mmu_x86_64
#define helper_clear_pstate_ss helper_clear_pstate_ss_x86_64
#define helper_clz_arm helper_clz_arm_x86_64
#define helper_cpsr_read helper_cpsr_read_x86_64
#define helper_cpsr_write helper_cpsr_write_x86_64
#define helper_crc32_arm helper_crc32_arm_x86_64
#define helper_crc32c helper_crc32c_x86_64
#define helper_crypto_aese helper_crypto_aese_x86_64
#define helper_crypto_aesmc helper_crypto_aesmc_x86_64
#define helper_crypto_sha1_3reg helper_crypto_sha1_3reg_x86_64
#define helper_crypto_sha1h helper_crypto_sha1h_x86_64
#define helper_crypto_sha1su1 helper_crypto_sha1su1_x86_64
#define helper_crypto_sha256h helper_crypto_sha256h_x86_64
#define helper_crypto_sha256h2 helper_crypto_sha256h2_x86_64
#define helper_crypto_sha256su0 helper_crypto_sha256su0_x86_64
#define helper_crypto_sha256su1 helper_crypto_sha256su1_x86_64
#define helper_dc_zva helper_dc_zva_x86_64
#define helper_double_saturate helper_double_saturate_x86_64
#define helper_exception_internal helper_exception_internal_x86_64
#define helper_exception_return helper_exception_return_x86_64
#define helper_exception_with_syndrome helper_exception_with_syndrome_x86_64
#define helper_get_cp_reg helper_get_cp_reg_x86_64
#define helper_get_cp_reg64 helper_get_cp_reg64_x86_64
#define helper_get_r13_banked helper_get_r13_banked_x86_64
#define helper_get_user_reg helper_get_user_reg_x86_64
#define helper_iwmmxt_addcb helper_iwmmxt_addcb_x86_64
#define helper_iwmmxt_addcl helper_iwmmxt_addcl_x86_64
#define helper_iwmmxt_addcw helper_iwmmxt_addcw_x86_64
#define helper_iwmmxt_addnb helper_iwmmxt_addnb_x86_64
#define helper_iwmmxt_addnl helper_iwmmxt_addnl_x86_64
#define helper_iwmmxt_addnw helper_iwmmxt_addnw_x86_64
#define helper_iwmmxt_addsb helper_iwmmxt_addsb_x86_64
#define helper_iwmmxt_addsl helper_iwmmxt_addsl_x86_64
#define helper_iwmmxt_addsw helper_iwmmxt_addsw_x86_64
#define helper_iwmmxt_addub helper_iwmmxt_addub_x86_64
#define helper_iwmmxt_addul helper_iwmmxt_addul_x86_64
#define helper_iwmmxt_adduw helper_iwmmxt_adduw_x86_64
#define helper_iwmmxt_align helper_iwmmxt_align_x86_64
#define helper_iwmmxt_avgb0 helper_iwmmxt_avgb0_x86_64
#define helper_iwmmxt_avgb1 helper_iwmmxt_avgb1_x86_64
#define helper_iwmmxt_avgw0 helper_iwmmxt_avgw0_x86_64
#define helper_iwmmxt_avgw1 helper_iwmmxt_avgw1_x86_64
#define helper_iwmmxt_bcstb helper_iwmmxt_bcstb_x86_64
#define helper_iwmmxt_bcstl helper_iwmmxt_bcstl_x86_64
#define helper_iwmmxt_bcstw helper_iwmmxt_bcstw_x86_64
#define helper_iwmmxt_cmpeqb helper_iwmmxt_cmpeqb_x86_64
#define helper_iwmmxt_cmpeql helper_iwmmxt_cmpeql_x86_64
#define helper_iwmmxt_cmpeqw helper_iwmmxt_cmpeqw_x86_64
#define helper_iwmmxt_cmpgtsb helper_iwmmxt_cmpgtsb_x86_64
#define helper_iwmmxt_cmpgtsl helper_iwmmxt_cmpgtsl_x86_64
#define helper_iwmmxt_cmpgtsw helper_iwmmxt_cmpgtsw_x86_64
#define helper_iwmmxt_cmpgtub helper_iwmmxt_cmpgtub_x86_64
#define helper_iwmmxt_cmpgtul helper_iwmmxt_cmpgtul_x86_64
#define helper_iwmmxt_cmpgtuw helper_iwmmxt_cmpgtuw_x86_64
#define helper_iwmmxt_insr helper_iwmmxt_insr_x86_64
#define helper_iwmmxt_macsw helper_iwmmxt_macsw_x86_64
#define helper_iwmmxt_macuw helper_iwmmxt_macuw_x86_64
#define helper_iwmmxt_maddsq helper_iwmmxt_maddsq_x86_64
#define helper_iwmmxt_madduq helper_iwmmxt_madduq_x86_64
#define helper_iwmmxt_maxsb helper_iwmmxt_maxsb_x86_64
#define helper_iwmmxt_maxsl helper_iwmmxt_maxsl_x86_64
#define helper_iwmmxt_maxsw helper_iwmmxt_maxsw_x86_64
#define helper_iwmmxt_maxub helper_iwmmxt_maxub_x86_64
#define helper_iwmmxt_maxul helper_iwmmxt_maxul_x86_64
#define helper_iwmmxt_maxuw helper_iwmmxt_maxuw_x86_64
#define helper_iwmmxt_minsb helper_iwmmxt_minsb_x86_64
#define helper_iwmmxt_minsl helper_iwmmxt_minsl_x86_64
#define helper_iwmmxt_minsw helper_iwmmxt_minsw_x86_64
#define helper_iwmmxt_minub helper_iwmmxt_minub_x86_64
#define helper_iwmmxt_minul helper_iwmmxt_minul_x86_64
#define helper_iwmmxt_minuw helper_iwmmxt_minuw_x86_64
#define helper_iwmmxt_msbb helper_iwmmxt_msbb_x86_64
#define helper_iwmmxt_msbl helper_iwmmxt_msbl_x86_64
#define helper_iwmmxt_msbw helper_iwmmxt_msbw_x86_64
#define helper_iwmmxt_muladdsl helper_iwmmxt_muladdsl_x86_64
#define helper_iwmmxt_muladdsw helper_iwmmxt_muladdsw_x86_64
#define helper_iwmmxt_muladdswl helper_iwmmxt_muladdswl_x86_64
#define helper_iwmmxt_mulshw helper_iwmmxt_mulshw_x86_64
#define helper_iwmmxt_mulslw helper_iwmmxt_mulslw_x86_64
#define helper_iwmmxt_muluhw helper_iwmmxt_muluhw_x86_64
#define helper_iwmmxt_mululw helper_iwmmxt_mululw_x86_64
#define helper_iwmmxt_packsl helper_iwmmxt_packsl_x86_64
#define helper_iwmmxt_packsq helper_iwmmxt_packsq_x86_64
#define helper_iwmmxt_packsw helper_iwmmxt_packsw_x86_64
#define helper_iwmmxt_packul helper_iwmmxt_packul_x86_64
#define helper_iwmmxt_packuq helper_iwmmxt_packuq_x86_64
#define helper_iwmmxt_packuw helper_iwmmxt_packuw_x86_64
#define helper_iwmmxt_rorl helper_iwmmxt_rorl_x86_64
#define helper_iwmmxt_rorq helper_iwmmxt_rorq_x86_64
#define helper_iwmmxt_rorw helper_iwmmxt_rorw_x86_64
#define helper_iwmmxt_sadb helper_iwmmxt_sadb_x86_64
#define helper_iwmmxt_sadw helper_iwmmxt_sadw_x86_64
#define helper_iwmmxt_setpsr_nz helper_iwmmxt_setpsr_nz_x86_64
#define helper_iwmmxt_shufh helper_iwmmxt_shufh_x86_64
#define helper_iwmmxt_slll helper_iwmmxt_slll_x86_64
#define helper_iwmmxt_sllq helper_iwmmxt_sllq_x86_64
#define helper_iwmmxt_sllw helper_iwmmxt_sllw_x86_64
#define helper_iwmmxt_sral helper_iwmmxt_sral_x86_64
#define helper_iwmmxt_sraq helper_iwmmxt_sraq_x86_64
#define helper_iwmmxt_sraw helper_iwmmxt_sraw_x86_64
#define helper_iwmmxt_srll helper_iwmmxt_srll_x86_64
#define helper_iwmmxt_srlq helper_iwmmxt_srlq_x86_64
#define helper_iwmmxt_srlw helper_iwmmxt_srlw_x86_64
#define helper_iwmmxt_subnb helper_iwmmxt_subnb_x86_64
#define helper_iwmmxt_subnl helper_iwmmxt_subnl_x86_64
#define helper_iwmmxt_subnw helper_iwmmxt_subnw_x86_64
#define helper_iwmmxt_subsb helper_iwmmxt_subsb_x86_64
#define helper_iwmmxt_subsl helper_iwmmxt_subsl_x86_64
#define helper_iwmmxt_subsw helper_iwmmxt_subsw_x86_64
#define helper_iwmmxt_subub helper_iwmmxt_subub_x86_64
#define helper_iwmmxt_subul helper_iwmmxt_subul_x86_64
#define helper_iwmmxt_subuw helper_iwmmxt_subuw_x86_64
#define helper_iwmmxt_unpackhb helper_iwmmxt_unpackhb_x86_64
#define helper_iwmmxt_unpackhl helper_iwmmxt_unpackhl_x86_64
#define helper_iwmmxt_unpackhsb helper_iwmmxt_unpackhsb_x86_64
#define helper_iwmmxt_unpackhsl helper_iwmmxt_unpackhsl_x86_64
#define helper_iwmmxt_unpackhsw helper_iwmmxt_unpackhsw_x86_64
#define helper_iwmmxt_unpackhub helper_iwmmxt_unpackhub_x86_64
#define helper_iwmmxt_unpackhul helper_iwmmxt_unpackhul_x86_64
#define helper_iwmmxt_unpackhuw helper_iwmmxt_unpackhuw_x86_64
#define helper_iwmmxt_unpackhw helper_iwmmxt_unpackhw_x86_64
#define helper_iwmmxt_unpacklb helper_iwmmxt_unpacklb_x86_64
#define helper_iwmmxt_unpackll helper_iwmmxt_unpackll_x86_64
#define helper_iwmmxt_unpacklsb helper_iwmmxt_unpacklsb_x86_64
#define helper_iwmmxt_unpacklsl helper_iwmmxt_unpacklsl_x86_64
#define helper_iwmmxt_unpacklsw helper_iwmmxt_unpacklsw_x86_64
#define helper_iwmmxt_unpacklub helper_iwmmxt_unpacklub_x86_64
#define helper_iwmmxt_unpacklul helper_iwmmxt_unpacklul_x86_64
#define helper_iwmmxt_unpackluw helper_iwmmxt_unpackluw_x86_64
#define helper_iwmmxt_unpacklw helper_iwmmxt_unpacklw_x86_64
#define helper_ldb_cmmu helper_ldb_cmmu_x86_64
#define helper_ldb_mmu helper_ldb_mmu_x86_64
#define helper_ldl_cmmu helper_ldl_cmmu_x86_64
#define helper_ldl_mmu helper_ldl_mmu_x86_64
#define helper_ldq_cmmu helper_ldq_cmmu_x86_64
#define helper_ldq_mmu helper_ldq_mmu_x86_64
#define helper_ldw_cmmu helper_ldw_cmmu_x86_64
#define helper_ldw_mmu helper_ldw_mmu_x86_64
#define helper_le_ldl_cmmu helper_le_ldl_cmmu_x86_64
#define helper_le_ldq_cmmu helper_le_ldq_cmmu_x86_64
#define helper_le_ldq_mmu helper_le_ldq_mmu_x86_64
#define helper_le_ldsl_mmu helper_le_ldsl_mmu_x86_64
#define helper_le_ldsw_mmu helper_le_ldsw_mmu_x86_64
#define helper_le_ldul_mmu helper_le_ldul_mmu_x86_64
#define helper_le_lduw_mmu helper_le_lduw_mmu_x86_64
#define helper_le_ldw_cmmu helper_le_ldw_cmmu_x86_64
#define helper_le_stl_mmu helper_le_stl_mmu_x86_64
#define helper_le_stq_mmu helper_le_stq_mmu_x86_64
#define helper_le_stw_mmu helper_le_stw_mmu_x86_64
#define helper_msr_i_pstate helper_msr_i_pstate_x86_64
#define helper_neon_abd_f32 helper_neon_abd_f32_x86_64
#define helper_neon_abdl_s16 helper_neon_abdl_s16_x86_64
#define helper_neon_abdl_s32 helper_neon_abdl_s32_x86_64
#define helper_neon_abdl_s64 helper_neon_abdl_s64_x86_64
#define helper_neon_abdl_u16 helper_neon_abdl_u16_x86_64
#define helper_neon_abdl_u32 helper_neon_abdl_u32_x86_64
#define helper_neon_abdl_u64 helper_neon_abdl_u64_x86_64
#define helper_neon_abd_s16 helper_neon_abd_s16_x86_64
#define helper_neon_abd_s32 helper_neon_abd_s32_x86_64
#define helper_neon_abd_s8 helper_neon_abd_s8_x86_64
#define helper_neon_abd_u16 helper_neon_abd_u16_x86_64
#define helper_neon_abd_u32 helper_neon_abd_u32_x86_64
#define helper_neon_abd_u8 helper_neon_abd_u8_x86_64
#define helper_neon_abs_s16 helper_neon_abs_s16_x86_64
#define helper_neon_abs_s8 helper_neon_abs_s8_x86_64
#define helper_neon_acge_f32 helper_neon_acge_f32_x86_64
#define helper_neon_acge_f64 helper_neon_acge_f64_x86_64
#define helper_neon_acgt_f32 helper_neon_acgt_f32_x86_64
#define helper_neon_acgt_f64 helper_neon_acgt_f64_x86_64
#define helper_neon_addl_saturate_s32 helper_neon_addl_saturate_s32_x86_64
#define helper_neon_addl_saturate_s64 helper_neon_addl_saturate_s64_x86_64
#define helper_neon_addl_u16 helper_neon_addl_u16_x86_64
#define helper_neon_addl_u32 helper_neon_addl_u32_x86_64
#define helper_neon_add_u16 helper_neon_add_u16_x86_64
#define helper_neon_add_u8 helper_neon_add_u8_x86_64
#define helper_neon_ceq_f32 helper_neon_ceq_f32_x86_64
#define helper_neon_ceq_u16 helper_neon_ceq_u16_x86_64
#define helper_neon_ceq_u32 helper_neon_ceq_u32_x86_64
#define helper_neon_ceq_u8 helper_neon_ceq_u8_x86_64
#define helper_neon_cge_f32 helper_neon_cge_f32_x86_64
#define helper_neon_cge_s16 helper_neon_cge_s16_x86_64
#define helper_neon_cge_s32 helper_neon_cge_s32_x86_64
#define helper_neon_cge_s8 helper_neon_cge_s8_x86_64
#define helper_neon_cge_u16 helper_neon_cge_u16_x86_64
#define helper_neon_cge_u32 helper_neon_cge_u32_x86_64
#define helper_neon_cge_u8 helper_neon_cge_u8_x86_64
#define helper_neon_cgt_f32 helper_neon_cgt_f32_x86_64
#define helper_neon_cgt_s16 helper_neon_cgt_s16_x86_64
#define helper_neon_cgt_s32 helper_neon_cgt_s32_x86_64
#define helper_neon_cgt_s8 helper_neon_cgt_s8_x86_64
#define helper_neon_cgt_u16 helper_neon_cgt_u16_x86_64
#define helper_neon_cgt_u32 helper_neon_cgt_u32_x86_64
#define helper_neon_cgt_u8 helper_neon_cgt_u8_x86_64
#define helper_neon_cls_s16 helper_neon_cls_s16_x86_64
#define helper_neon_cls_s32 helper_neon_cls_s32_x86_64
#define helper_neon_cls_s8 helper_neon_cls_s8_x86_64
#define helper_neon_clz_u16 helper_neon_clz_u16_x86_64
#define helper_neon_clz_u8 helper_neon_clz_u8_x86_64
#define helper_neon_cnt_u8 helper_neon_cnt_u8_x86_64
#define helper_neon_fcvt_f16_to_f32 helper_neon_fcvt_f16_to_f32_x86_64
#define helper_neon_fcvt_f32_to_f16 helper_neon_fcvt_f32_to_f16_x86_64
#define helper_neon_hadd_s16 helper_neon_hadd_s16_x86_64
#define helper_neon_hadd_s32 helper_neon_hadd_s32_x86_64
#define helper_neon_hadd_s8 helper_neon_hadd_s8_x86_64
#define helper_neon_hadd_u16 helper_neon_hadd_u16_x86_64
#define helper_neon_hadd_u32 helper_neon_hadd_u32_x86_64
#define helper_neon_hadd_u8 helper_neon_hadd_u8_x86_64
#define helper_neon_hsub_s16 helper_neon_hsub_s16_x86_64
#define helper_neon_hsub_s32 helper_neon_hsub_s32_x86_64
#define helper_neon_hsub_s8 helper_neon_hsub_s8_x86_64
#define helper_neon_hsub_u16 helper_neon_hsub_u16_x86_64
#define helper_neon_hsub_u32 helper_neon_hsub_u32_x86_64
#define helper_neon_hsub_u8 helper_neon_hsub_u8_x86_64
#define helper_neon_max_s16 helper_neon_max_s16_x86_64
#define helper_neon_max_s32 helper_neon_max_s32_x86_64
#define helper_neon_max_s8 helper_neon_max_s8_x86_64
#define helper_neon_max_u16 helper_neon_max_u16_x86_64
#define helper_neon_max_u32 helper_neon_max_u32_x86_64
#define helper_neon_max_u8 helper_neon_max_u8_x86_64
#define helper_neon_min_s16 helper_neon_min_s16_x86_64
#define helper_neon_min_s32 helper_neon_min_s32_x86_64
#define helper_neon_min_s8 helper_neon_min_s8_x86_64
#define helper_neon_min_u16 helper_neon_min_u16_x86_64
#define helper_neon_min_u32 helper_neon_min_u32_x86_64
#define helper_neon_min_u8 helper_neon_min_u8_x86_64
#define helper_neon_mull_p8 helper_neon_mull_p8_x86_64
#define helper_neon_mull_s16 helper_neon_mull_s16_x86_64
#define helper_neon_mull_s8 helper_neon_mull_s8_x86_64
#define helper_neon_mull_u16 helper_neon_mull_u16_x86_64
#define helper_neon_mull_u8 helper_neon_mull_u8_x86_64
#define helper_neon_mul_p8 helper_neon_mul_p8_x86_64
#define helper_neon_mul_u16 helper_neon_mul_u16_x86_64
#define helper_neon_mul_u8 helper_neon_mul_u8_x86_64
#define helper_neon_narrow_high_u16 helper_neon_narrow_high_u16_x86_64
#define helper_neon_narrow_high_u8 helper_neon_narrow_high_u8_x86_64
#define helper_neon_narrow_round_high_u16 helper_neon_narrow_round_high_u16_x86_64
#define helper_neon_narrow_round_high_u8 helper_neon_narrow_round_high_u8_x86_64
#define helper_neon_narrow_sat_s16 helper_neon_narrow_sat_s16_x86_64
#define helper_neon_narrow_sat_s32 helper_neon_narrow_sat_s32_x86_64
#define helper_neon_narrow_sat_s8 helper_neon_narrow_sat_s8_x86_64
#define helper_neon_narrow_sat_u16 helper_neon_narrow_sat_u16_x86_64
#define helper_neon_narrow_sat_u32 helper_neon_narrow_sat_u32_x86_64
#define helper_neon_narrow_sat_u8 helper_neon_narrow_sat_u8_x86_64
#define helper_neon_narrow_u16 helper_neon_narrow_u16_x86_64
#define helper_neon_narrow_u8 helper_neon_narrow_u8_x86_64
#define helper_neon_negl_u16 helper_neon_negl_u16_x86_64
#define helper_neon_negl_u32 helper_neon_negl_u32_x86_64
#define helper_neon_paddl_u16 helper_neon_paddl_u16_x86_64
#define helper_neon_paddl_u32 helper_neon_paddl_u32_x86_64
#define helper_neon_padd_u16 helper_neon_padd_u16_x86_64
#define helper_neon_padd_u8 helper_neon_padd_u8_x86_64
#define helper_neon_pmax_s16 helper_neon_pmax_s16_x86_64
#define helper_neon_pmax_s8 helper_neon_pmax_s8_x86_64
#define helper_neon_pmax_u16 helper_neon_pmax_u16_x86_64
#define helper_neon_pmax_u8 helper_neon_pmax_u8_x86_64
#define helper_neon_pmin_s16 helper_neon_pmin_s16_x86_64
#define helper_neon_pmin_s8 helper_neon_pmin_s8_x86_64
#define helper_neon_pmin_u16 helper_neon_pmin_u16_x86_64
#define helper_neon_pmin_u8 helper_neon_pmin_u8_x86_64
#define helper_neon_pmull_64_hi helper_neon_pmull_64_hi_x86_64
#define helper_neon_pmull_64_lo helper_neon_pmull_64_lo_x86_64
#define helper_neon_qabs_s16 helper_neon_qabs_s16_x86_64
#define helper_neon_qabs_s32 helper_neon_qabs_s32_x86_64
#define helper_neon_qabs_s64 helper_neon_qabs_s64_x86_64
#define helper_neon_qabs_s8 helper_neon_qabs_s8_x86_64
#define helper_neon_qadd_s16 helper_neon_qadd_s16_x86_64
#define helper_neon_qadd_s32 helper_neon_qadd_s32_x86_64
#define helper_neon_qadd_s64 helper_neon_qadd_s64_x86_64
#define helper_neon_qadd_s8 helper_neon_qadd_s8_x86_64
#define helper_neon_qadd_u16 helper_neon_qadd_u16_x86_64
#define helper_neon_qadd_u32 helper_neon_qadd_u32_x86_64
#define helper_neon_qadd_u64 helper_neon_qadd_u64_x86_64
#define helper_neon_qadd_u8 helper_neon_qadd_u8_x86_64
#define helper_neon_qdmulh_s16 helper_neon_qdmulh_s16_x86_64
#define helper_neon_qdmulh_s32 helper_neon_qdmulh_s32_x86_64
#define helper_neon_qneg_s16 helper_neon_qneg_s16_x86_64
#define helper_neon_qneg_s32 helper_neon_qneg_s32_x86_64
#define helper_neon_qneg_s64 helper_neon_qneg_s64_x86_64
#define helper_neon_qneg_s8 helper_neon_qneg_s8_x86_64
#define helper_neon_qrdmulh_s16 helper_neon_qrdmulh_s16_x86_64
#define helper_neon_qrdmulh_s32 helper_neon_qrdmulh_s32_x86_64
#define helper_neon_qrshl_s16 helper_neon_qrshl_s16_x86_64
#define helper_neon_qrshl_s32 helper_neon_qrshl_s32_x86_64
#define helper_neon_qrshl_s64 helper_neon_qrshl_s64_x86_64
#define helper_neon_qrshl_s8 helper_neon_qrshl_s8_x86_64
#define helper_neon_qrshl_u16 helper_neon_qrshl_u16_x86_64
#define helper_neon_qrshl_u32 helper_neon_qrshl_u32_x86_64
#define helper_neon_qrshl_u64 helper_neon_qrshl_u64_x86_64
#define helper_neon_qrshl_u8 helper_neon_qrshl_u8_x86_64
#define helper_neon_qshl_s16 helper_neon_qshl_s16_x86_64
#define helper_neon_qshl_s32 helper_neon_qshl_s32_x86_64
#define helper_neon_qshl_s64 helper_neon_qshl_s64_x86_64
#define helper_neon_qshl_s8 helper_neon_qshl_s8_x86_64
#define helper_neon_qshl_u16 helper_neon_qshl_u16_x86_64
#define helper_neon_qshl_u32 helper_neon_qshl_u32_x86_64
#define helper_neon_qshl_u64 helper_neon_qshl_u64_x86_64
#define helper_neon_qshl_u8 helper_neon_qshl_u8_x86_64
#define helper_neon_qshlu_s16 helper_neon_qshlu_s16_x86_64
#define helper_neon_qshlu_s32 helper_neon_qshlu_s32_x86_64
#define helper_neon_qshlu_s64 helper_neon_qshlu_s64_x86_64
#define helper_neon_qshlu_s8 helper_neon_qshlu_s8_x86_64
#define helper_neon_qsub_s16 helper_neon_qsub_s16_x86_64
#define helper_neon_qsub_s32 helper_neon_qsub_s32_x86_64
#define helper_neon_qsub_s64 helper_neon_qsub_s64_x86_64
#define helper_neon_qsub_s8 helper_neon_qsub_s8_x86_64
#define helper_neon_qsub_u16 helper_neon_qsub_u16_x86_64
#define helper_neon_qsub_u32 helper_neon_qsub_u32_x86_64
#define helper_neon_qsub_u64 helper_neon_qsub_u64_x86_64
#define helper_neon_qsub_u8 helper_neon_qsub_u8_x86_64
#define helper_neon_qunzip16 helper_neon_qunzip16_x86_64
#define helper_neon_qunzip32 helper_neon_qunzip32_x86_64
#define helper_neon_qunzip8 helper_neon_qunzip8_x86_64
#define helper_neon_qzip16 helper_neon_qzip16_x86_64
#define helper_neon_qzip32 helper_neon_qzip32_x86_64
#define helper_neon_qzip8 helper_neon_qzip8_x86_64
#define helper_neon_rbit_u8 helper_neon_rbit_u8_x86_64
#define helper_neon_rhadd_s16 helper_neon_rhadd_s16_x86_64
#define helper_neon_rhadd_s32 helper_neon_rhadd_s32_x86_64
#define helper_neon_rhadd_s8 helper_neon_rhadd_s8_x86_64
#define helper_neon_rhadd_u16 helper_neon_rhadd_u16_x86_64
#define helper_neon_rhadd_u32 helper_neon_rhadd_u32_x86_64
#define helper_neon_rhadd_u8 helper_neon_rhadd_u8_x86_64
#define helper_neon_rshl_s16 helper_neon_rshl_s16_x86_64
#define helper_neon_rshl_s32 helper_neon_rshl_s32_x86_64
#define helper_neon_rshl_s64 helper_neon_rshl_s64_x86_64
#define helper_neon_rshl_s8 helper_neon_rshl_s8_x86_64
#define helper_neon_rshl_u16 helper_neon_rshl_u16_x86_64
#define helper_neon_rshl_u32 helper_neon_rshl_u32_x86_64
#define helper_neon_rshl_u64 helper_neon_rshl_u64_x86_64
#define helper_neon_rshl_u8 helper_neon_rshl_u8_x86_64
#define helper_neon_shl_s16 helper_neon_shl_s16_x86_64
#define helper_neon_shl_s32 helper_neon_shl_s32_x86_64
#define helper_neon_shl_s64 helper_neon_shl_s64_x86_64
#define helper_neon_shl_s8 helper_neon_shl_s8_x86_64
#define helper_neon_shl_u16 helper_neon_shl_u16_x86_64
#define helper_neon_shl_u32 helper_neon_shl_u32_x86_64
#define helper_neon_shl_u64 helper_neon_shl_u64_x86_64
#define helper_neon_shl_u8 helper_neon_shl_u8_x86_64
#define helper_neon_sqadd_u16 helper_neon_sqadd_u16_x86_64
#define helper_neon_sqadd_u32 helper_neon_sqadd_u32_x86_64
#define helper_neon_sqadd_u64 helper_neon_sqadd_u64_x86_64
#define helper_neon_sqadd_u8 helper_neon_sqadd_u8_x86_64
#define helper_neon_subl_u16 helper_neon_subl_u16_x86_64
#define helper_neon_subl_u32 helper_neon_subl_u32_x86_64
#define helper_neon_sub_u16 helper_neon_sub_u16_x86_64
#define helper_neon_sub_u8 helper_neon_sub_u8_x86_64
#define helper_neon_tbl helper_neon_tbl_x86_64
#define helper_neon_tst_u16 helper_neon_tst_u16_x86_64
#define helper_neon_tst_u32 helper_neon_tst_u32_x86_64
#define helper_neon_tst_u8 helper_neon_tst_u8_x86_64
#define helper_neon_unarrow_sat16 helper_neon_unarrow_sat16_x86_64
#define helper_neon_unarrow_sat32 helper_neon_unarrow_sat32_x86_64
#define helper_neon_unarrow_sat8 helper_neon_unarrow_sat8_x86_64
#define helper_neon_unzip16 helper_neon_unzip16_x86_64
#define helper_neon_unzip8 helper_neon_unzip8_x86_64
#define helper_neon_uqadd_s16 helper_neon_uqadd_s16_x86_64
#define helper_neon_uqadd_s32 helper_neon_uqadd_s32_x86_64
#define helper_neon_uqadd_s64 helper_neon_uqadd_s64_x86_64
#define helper_neon_uqadd_s8 helper_neon_uqadd_s8_x86_64
#define helper_neon_widen_s16 helper_neon_widen_s16_x86_64
#define helper_neon_widen_s8 helper_neon_widen_s8_x86_64
#define helper_neon_widen_u16 helper_neon_widen_u16_x86_64
#define helper_neon_widen_u8 helper_neon_widen_u8_x86_64
#define helper_neon_zip16 helper_neon_zip16_x86_64
#define helper_neon_zip8 helper_neon_zip8_x86_64
#define helper_pre_hvc helper_pre_hvc_x86_64
#define helper_pre_smc helper_pre_smc_x86_64
#define helper_qadd16 helper_qadd16_x86_64
#define helper_qadd8 helper_qadd8_x86_64
#define helper_qaddsubx helper_qaddsubx_x86_64
#define helper_qsub16 helper_qsub16_x86_64
#define helper_qsub8 helper_qsub8_x86_64
#define helper_qsubaddx helper_qsubaddx_x86_64
#define helper_rbit helper_rbit_x86_64
#define helper_recpe_f32 helper_recpe_f32_x86_64
#define helper_recpe_f64 helper_recpe_f64_x86_64
#define helper_recpe_u32 helper_recpe_u32_x86_64
#define helper_recps_f32 helper_recps_f32_x86_64
#define helper_ret_ldb_cmmu helper_ret_ldb_cmmu_x86_64
#define helper_ret_ldsb_mmu helper_ret_ldsb_mmu_x86_64
#define helper_ret_ldub_mmu helper_ret_ldub_mmu_x86_64
#define helper_ret_stb_mmu helper_ret_stb_mmu_x86_64
#define helper_rintd helper_rintd_x86_64
#define helper_rintd_exact helper_rintd_exact_x86_64
#define helper_rints helper_rints_x86_64
#define helper_rints_exact helper_rints_exact_x86_64
#define helper_ror_cc helper_ror_cc_x86_64
#define helper_rsqrte_f32 helper_rsqrte_f32_x86_64
#define helper_rsqrte_f64 helper_rsqrte_f64_x86_64
#define helper_rsqrte_u32 helper_rsqrte_u32_x86_64
#define helper_rsqrts_f32 helper_rsqrts_f32_x86_64
#define helper_sadd16 helper_sadd16_x86_64
#define helper_sadd8 helper_sadd8_x86_64
#define helper_saddsubx helper_saddsubx_x86_64
#define helper_sar_cc helper_sar_cc_x86_64
#define helper_sdiv helper_sdiv_x86_64
#define helper_sel_flags helper_sel_flags_x86_64
#define helper_set_cp_reg helper_set_cp_reg_x86_64
#define helper_set_cp_reg64 helper_set_cp_reg64_x86_64
#define helper_set_neon_rmode helper_set_neon_rmode_x86_64
#define helper_set_r13_banked helper_set_r13_banked_x86_64
#define helper_set_rmode helper_set_rmode_x86_64
#define helper_set_user_reg helper_set_user_reg_x86_64
#define helper_shadd16 helper_shadd16_x86_64
#define helper_shadd8 helper_shadd8_x86_64
#define helper_shaddsubx helper_shaddsubx_x86_64
#define helper_shl_cc helper_shl_cc_x86_64
#define helper_shr_cc helper_shr_cc_x86_64
#define helper_shsub16 helper_shsub16_x86_64
#define helper_shsub8 helper_shsub8_x86_64
#define helper_shsubaddx helper_shsubaddx_x86_64
#define helper_ssat helper_ssat_x86_64
#define helper_ssat16 helper_ssat16_x86_64
#define helper_ssub16 helper_ssub16_x86_64
#define helper_ssub8 helper_ssub8_x86_64
#define helper_ssubaddx helper_ssubaddx_x86_64
#define helper_stb_mmu helper_stb_mmu_x86_64
#define helper_stl_mmu helper_stl_mmu_x86_64
#define helper_stq_mmu helper_stq_mmu_x86_64
#define helper_stw_mmu helper_stw_mmu_x86_64
#define helper_sub_saturate helper_sub_saturate_x86_64
#define helper_sub_usaturate helper_sub_usaturate_x86_64
#define helper_sxtb16 helper_sxtb16_x86_64
#define helper_uadd16 helper_uadd16_x86_64
#define helper_uadd8 helper_uadd8_x86_64
#define helper_uaddsubx helper_uaddsubx_x86_64
#define helper_udiv helper_udiv_x86_64
#define helper_uhadd16 helper_uhadd16_x86_64
#define helper_uhadd8 helper_uhadd8_x86_64
#define helper_uhaddsubx helper_uhaddsubx_x86_64
#define helper_uhsub16 helper_uhsub16_x86_64
#define helper_uhsub8 helper_uhsub8_x86_64
#define helper_uhsubaddx helper_uhsubaddx_x86_64
#define helper_uqadd16 helper_uqadd16_x86_64
#define helper_uqadd8 helper_uqadd8_x86_64
#define helper_uqaddsubx helper_uqaddsubx_x86_64
#define helper_uqsub16 helper_uqsub16_x86_64
#define helper_uqsub8 helper_uqsub8_x86_64
#define helper_uqsubaddx helper_uqsubaddx_x86_64
#define helper_usad8 helper_usad8_x86_64
#define helper_usat helper_usat_x86_64
#define helper_usat16 helper_usat16_x86_64
#define helper_usub16 helper_usub16_x86_64
#define helper_usub8 helper_usub8_x86_64
#define helper_usubaddx helper_usubaddx_x86_64
#define helper_uxtb16 helper_uxtb16_x86_64
#define helper_v7m_mrs helper_v7m_mrs_x86_64
#define helper_v7m_msr helper_v7m_msr_x86_64
#define helper_vfp_absd helper_vfp_absd_x86_64
#define helper_vfp_abss helper_vfp_abss_x86_64
#define helper_vfp_addd helper_vfp_addd_x86_64
#define helper_vfp_adds helper_vfp_adds_x86_64
#define helper_vfp_cmpd helper_vfp_cmpd_x86_64
#define helper_vfp_cmped helper_vfp_cmped_x86_64
#define helper_vfp_cmpes helper_vfp_cmpes_x86_64
#define helper_vfp_cmps helper_vfp_cmps_x86_64
#define helper_vfp_divd helper_vfp_divd_x86_64
#define helper_vfp_divs helper_vfp_divs_x86_64
#define helper_vfp_fcvtds helper_vfp_fcvtds_x86_64
#define helper_vfp_fcvt_f16_to_f32 helper_vfp_fcvt_f16_to_f32_x86_64
#define helper_vfp_fcvt_f16_to_f64 helper_vfp_fcvt_f16_to_f64_x86_64
#define helper_vfp_fcvt_f32_to_f16 helper_vfp_fcvt_f32_to_f16_x86_64
#define helper_vfp_fcvt_f64_to_f16 helper_vfp_fcvt_f64_to_f16_x86_64
#define helper_vfp_fcvtsd helper_vfp_fcvtsd_x86_64
#define helper_vfp_get_fpscr helper_vfp_get_fpscr_x86_64
#define helper_vfp_maxd helper_vfp_maxd_x86_64
#define helper_vfp_maxnumd helper_vfp_maxnumd_x86_64
#define helper_vfp_maxnums helper_vfp_maxnums_x86_64
#define helper_vfp_maxs helper_vfp_maxs_x86_64
#define helper_vfp_mind helper_vfp_mind_x86_64
#define helper_vfp_minnumd helper_vfp_minnumd_x86_64
#define helper_vfp_minnums helper_vfp_minnums_x86_64
#define helper_vfp_mins helper_vfp_mins_x86_64
#define helper_vfp_muladdd helper_vfp_muladdd_x86_64
#define helper_vfp_muladds helper_vfp_muladds_x86_64
#define helper_vfp_muld helper_vfp_muld_x86_64
#define helper_vfp_muls helper_vfp_muls_x86_64
#define helper_vfp_negd helper_vfp_negd_x86_64
#define helper_vfp_negs helper_vfp_negs_x86_64
#define helper_vfp_set_fpscr helper_vfp_set_fpscr_x86_64
#define helper_vfp_shtod helper_vfp_shtod_x86_64
#define helper_vfp_shtos helper_vfp_shtos_x86_64
#define helper_vfp_sitod helper_vfp_sitod_x86_64
#define helper_vfp_sitos helper_vfp_sitos_x86_64
#define helper_vfp_sltod helper_vfp_sltod_x86_64
#define helper_vfp_sltos helper_vfp_sltos_x86_64
#define helper_vfp_sqrtd helper_vfp_sqrtd_x86_64
#define helper_vfp_sqrts helper_vfp_sqrts_x86_64
#define helper_vfp_sqtod helper_vfp_sqtod_x86_64
#define helper_vfp_sqtos helper_vfp_sqtos_x86_64
#define helper_vfp_subd helper_vfp_subd_x86_64
#define helper_vfp_subs helper_vfp_subs_x86_64
#define helper_vfp_toshd helper_vfp_toshd_x86_64
#define helper_vfp_toshd_round_to_zero helper_vfp_toshd_round_to_zero_x86_64
#define helper_vfp_toshs helper_vfp_toshs_x86_64
#define helper_vfp_toshs_round_to_zero helper_vfp_toshs_round_to_zero_x86_64
#define helper_vfp_tosid helper_vfp_tosid_x86_64
#define helper_vfp_tosis helper_vfp_tosis_x86_64
#define helper_vfp_tosizd helper_vfp_tosizd_x86_64
#define helper_vfp_tosizs helper_vfp_tosizs_x86_64
#define helper_vfp_tosld helper_vfp_tosld_x86_64
#define helper_vfp_tosld_round_to_zero helper_vfp_tosld_round_to_zero_x86_64
#define helper_vfp_tosls helper_vfp_tosls_x86_64
#define helper_vfp_tosls_round_to_zero helper_vfp_tosls_round_to_zero_x86_64
#define helper_vfp_tosqd helper_vfp_tosqd_x86_64
#define helper_vfp_tosqs helper_vfp_tosqs_x86_64
#define helper_vfp_touhd helper_vfp_touhd_x86_64
#define helper_vfp_touhd_round_to_zero helper_vfp_touhd_round_to_zero_x86_64
#define helper_vfp_touhs helper_vfp_touhs_x86_64
#define helper_vfp_touhs_round_to_zero helper_vfp_touhs_round_to_zero_x86_64
#define helper_vfp_touid helper_vfp_touid_x86_64
#define helper_vfp_touis helper_vfp_touis_x86_64
#define helper_vfp_touizd helper_vfp_touizd_x86_64
#define helper_vfp_touizs helper_vfp_touizs_x86_64
#define helper_vfp_tould helper_vfp_tould_x86_64
#define helper_vfp_tould_round_to_zero helper_vfp_tould_round_to_zero_x86_64
#define helper_vfp_touls helper_vfp_touls_x86_64
#define helper_vfp_touls_round_to_zero helper_vfp_touls_round_to_zero_x86_64
#define helper_vfp_touqd helper_vfp_touqd_x86_64
#define helper_vfp_touqs helper_vfp_touqs_x86_64
#define helper_vfp_uhtod helper_vfp_uhtod_x86_64
#define helper_vfp_uhtos helper_vfp_uhtos_x86_64
#define helper_vfp_uitod helper_vfp_uitod_x86_64
#define helper_vfp_uitos helper_vfp_uitos_x86_64
#define helper_vfp_ultod helper_vfp_ultod_x86_64
#define helper_vfp_ultos helper_vfp_ultos_x86_64
#define helper_vfp_uqtod helper_vfp_uqtod_x86_64
#define helper_vfp_uqtos helper_vfp_uqtos_x86_64
#define helper_wfe helper_wfe_x86_64
#define helper_wfi helper_wfi_x86_64
#define hex2decimal hex2decimal_x86_64
#define hw_breakpoint_update hw_breakpoint_update_x86_64
#define hw_breakpoint_update_all hw_breakpoint_update_all_x86_64
#define hw_watchpoint_update hw_watchpoint_update_x86_64
#define hw_watchpoint_update_all hw_watchpoint_update_all_x86_64
#define _init _init_x86_64
#define init_cpreg_list init_cpreg_list_x86_64
#define init_lists init_lists_x86_64
#define input_type_enum input_type_enum_x86_64
#define int128_2_64 int128_2_64_x86_64
#define int128_add int128_add_x86_64
#define int128_addto int128_addto_x86_64
#define int128_and int128_and_x86_64
#define int128_eq int128_eq_x86_64
#define int128_ge int128_ge_x86_64
#define int128_get64 int128_get64_x86_64
#define int128_gt int128_gt_x86_64
#define int128_le int128_le_x86_64
#define int128_lt int128_lt_x86_64
#define int128_make64 int128_make64_x86_64
#define int128_max int128_max_x86_64
#define int128_min int128_min_x86_64
#define int128_ne int128_ne_x86_64
#define int128_neg int128_neg_x86_64
#define int128_nz int128_nz_x86_64
#define int128_rshift int128_rshift_x86_64
#define int128_sub int128_sub_x86_64
#define int128_subfrom int128_subfrom_x86_64
#define int128_zero int128_zero_x86_64
#define int16_to_float32 int16_to_float32_x86_64
#define int16_to_float64 int16_to_float64_x86_64
#define int32_to_float128 int32_to_float128_x86_64
#define int32_to_float32 int32_to_float32_x86_64
#define int32_to_float64 int32_to_float64_x86_64
#define int32_to_floatx80 int32_to_floatx80_x86_64
#define int64_to_float128 int64_to_float128_x86_64
#define int64_to_float32 int64_to_float32_x86_64
#define int64_to_float64 int64_to_float64_x86_64
#define int64_to_floatx80 int64_to_floatx80_x86_64
#define invalidate_and_set_dirty invalidate_and_set_dirty_x86_64
#define invalidate_page_bitmap invalidate_page_bitmap_x86_64
#define io_mem_read io_mem_read_x86_64
#define io_mem_write io_mem_write_x86_64
#define io_readb io_readb_x86_64
#define io_readl io_readl_x86_64
#define io_readq io_readq_x86_64
#define io_readw io_readw_x86_64
#define iotlb_to_region iotlb_to_region_x86_64
#define io_writeb io_writeb_x86_64
#define io_writel io_writel_x86_64
#define io_writeq io_writeq_x86_64
#define io_writew io_writew_x86_64
#define is_a64 is_a64_x86_64
#define is_help_option is_help_option_x86_64
#define isr_read isr_read_x86_64
#define is_valid_option_list is_valid_option_list_x86_64
#define iwmmxt_load_creg iwmmxt_load_creg_x86_64
#define iwmmxt_load_reg iwmmxt_load_reg_x86_64
#define iwmmxt_store_creg iwmmxt_store_creg_x86_64
#define iwmmxt_store_reg iwmmxt_store_reg_x86_64
#define __jit_debug_descriptor __jit_debug_descriptor_x86_64
#define __jit_debug_register_code __jit_debug_register_code_x86_64
#define kvm_to_cpreg_id kvm_to_cpreg_id_x86_64
#define last_ram_offset last_ram_offset_x86_64
#define ldl_be_p ldl_be_p_x86_64
#define ldl_be_phys ldl_be_phys_x86_64
#define ldl_he_p ldl_he_p_x86_64
#define ldl_le_p ldl_le_p_x86_64
#define ldl_le_phys ldl_le_phys_x86_64
#define ldl_phys ldl_phys_x86_64
#define ldl_phys_internal ldl_phys_internal_x86_64
#define ldq_be_p ldq_be_p_x86_64
#define ldq_be_phys ldq_be_phys_x86_64
#define ldq_he_p ldq_he_p_x86_64
#define ldq_le_p ldq_le_p_x86_64
#define ldq_le_phys ldq_le_phys_x86_64
#define ldq_phys ldq_phys_x86_64
#define ldq_phys_internal ldq_phys_internal_x86_64
#define ldst_name ldst_name_x86_64
#define ldub_p ldub_p_x86_64
#define ldub_phys ldub_phys_x86_64
#define lduw_be_p lduw_be_p_x86_64
#define lduw_be_phys lduw_be_phys_x86_64
#define lduw_he_p lduw_he_p_x86_64
#define lduw_le_p lduw_le_p_x86_64
#define lduw_le_phys lduw_le_phys_x86_64
#define lduw_phys lduw_phys_x86_64
#define lduw_phys_internal lduw_phys_internal_x86_64
#define le128 le128_x86_64
#define linked_bp_matches linked_bp_matches_x86_64
#define listener_add_address_space listener_add_address_space_x86_64
#define load_cpu_offset load_cpu_offset_x86_64
#define load_reg load_reg_x86_64
#define load_reg_var load_reg_var_x86_64
#define log_cpu_state log_cpu_state_x86_64
#define lpae_cp_reginfo lpae_cp_reginfo_x86_64
#define lt128 lt128_x86_64
#define machine_class_init machine_class_init_x86_64
#define machine_finalize machine_finalize_x86_64
#define machine_info machine_info_x86_64
#define machine_initfn machine_initfn_x86_64
#define machine_register_types machine_register_types_x86_64
#define machvirt_init machvirt_init_x86_64
#define machvirt_machine_init machvirt_machine_init_x86_64
#define maj maj_x86_64
#define mapping_conflict mapping_conflict_x86_64
#define mapping_contiguous mapping_contiguous_x86_64
#define mapping_have_same_region mapping_have_same_region_x86_64
#define mapping_merge mapping_merge_x86_64
#define mem_add mem_add_x86_64
#define mem_begin mem_begin_x86_64
#define mem_commit mem_commit_x86_64
#define memory_access_is_direct memory_access_is_direct_x86_64
#define memory_access_size memory_access_size_x86_64
#define memory_init memory_init_x86_64
#define memory_listener_match memory_listener_match_x86_64
#define memory_listener_register memory_listener_register_x86_64
#define memory_listener_unregister memory_listener_unregister_x86_64
#define memory_map_init memory_map_init_x86_64
#define memory_mapping_filter memory_mapping_filter_x86_64
#define memory_mapping_list_add_mapping_sorted memory_mapping_list_add_mapping_sorted_x86_64
#define memory_mapping_list_add_merge_sorted memory_mapping_list_add_merge_sorted_x86_64
#define memory_mapping_list_free memory_mapping_list_free_x86_64
#define memory_mapping_list_init memory_mapping_list_init_x86_64
#define memory_region_access_valid memory_region_access_valid_x86_64
#define memory_region_add_subregion memory_region_add_subregion_x86_64
#define memory_region_add_subregion_common memory_region_add_subregion_common_x86_64
#define memory_region_add_subregion_overlap memory_region_add_subregion_overlap_x86_64
#define memory_region_big_endian memory_region_big_endian_x86_64
#define memory_region_clear_pending memory_region_clear_pending_x86_64
#define memory_region_del_subregion memory_region_del_subregion_x86_64
#define memory_region_destructor_alias memory_region_destructor_alias_x86_64
#define memory_region_destructor_none memory_region_destructor_none_x86_64
#define memory_region_destructor_ram memory_region_destructor_ram_x86_64
#define memory_region_destructor_ram_from_ptr memory_region_destructor_ram_from_ptr_x86_64
#define memory_region_dispatch_read memory_region_dispatch_read_x86_64
#define memory_region_dispatch_read1 memory_region_dispatch_read1_x86_64
#define memory_region_dispatch_write memory_region_dispatch_write_x86_64
#define memory_region_escape_name memory_region_escape_name_x86_64
#define memory_region_finalize memory_region_finalize_x86_64
#define memory_region_find memory_region_find_x86_64
#define memory_region_get_addr memory_region_get_addr_x86_64
#define memory_region_get_alignment memory_region_get_alignment_x86_64
#define memory_region_get_container memory_region_get_container_x86_64
#define memory_region_get_fd memory_region_get_fd_x86_64
#define memory_region_get_may_overlap memory_region_get_may_overlap_x86_64
#define memory_region_get_priority memory_region_get_priority_x86_64
#define memory_region_get_ram_addr memory_region_get_ram_addr_x86_64
#define memory_region_get_ram_ptr memory_region_get_ram_ptr_x86_64
#define memory_region_get_size memory_region_get_size_x86_64
#define memory_region_info memory_region_info_x86_64
#define memory_region_init memory_region_init_x86_64
#define memory_region_init_alias memory_region_init_alias_x86_64
#define memory_region_initfn memory_region_initfn_x86_64
#define memory_region_init_io memory_region_init_io_x86_64
#define memory_region_init_ram memory_region_init_ram_x86_64
#define memory_region_init_ram_ptr memory_region_init_ram_ptr_x86_64
#define memory_region_init_reservation memory_region_init_reservation_x86_64
#define memory_region_is_iommu memory_region_is_iommu_x86_64
#define memory_region_is_logging memory_region_is_logging_x86_64
#define memory_region_is_mapped memory_region_is_mapped_x86_64
#define memory_region_is_ram memory_region_is_ram_x86_64
#define memory_region_is_rom memory_region_is_rom_x86_64
#define memory_region_is_romd memory_region_is_romd_x86_64
#define memory_region_is_skip_dump memory_region_is_skip_dump_x86_64
#define memory_region_is_unassigned memory_region_is_unassigned_x86_64
#define memory_region_name memory_region_name_x86_64
#define memory_region_need_escape memory_region_need_escape_x86_64
#define memory_region_oldmmio_read_accessor memory_region_oldmmio_read_accessor_x86_64
#define memory_region_oldmmio_write_accessor memory_region_oldmmio_write_accessor_x86_64
#define memory_region_present memory_region_present_x86_64
#define memory_region_read_accessor memory_region_read_accessor_x86_64
#define memory_region_readd_subregion memory_region_readd_subregion_x86_64
#define memory_region_ref memory_region_ref_x86_64
#define memory_region_resolve_container memory_region_resolve_container_x86_64
#define memory_region_rom_device_set_romd memory_region_rom_device_set_romd_x86_64
#define memory_region_section_get_iotlb memory_region_section_get_iotlb_x86_64
#define memory_region_set_address memory_region_set_address_x86_64
#define memory_region_set_alias_offset memory_region_set_alias_offset_x86_64
#define memory_region_set_enabled memory_region_set_enabled_x86_64
#define memory_region_set_readonly memory_region_set_readonly_x86_64
#define memory_region_set_skip_dump memory_region_set_skip_dump_x86_64
#define memory_region_size memory_region_size_x86_64
#define memory_region_to_address_space memory_region_to_address_space_x86_64
#define memory_region_transaction_begin memory_region_transaction_begin_x86_64
#define memory_region_transaction_commit memory_region_transaction_commit_x86_64
#define memory_region_unref memory_region_unref_x86_64
#define memory_region_update_container_subregions memory_region_update_container_subregions_x86_64
#define memory_region_write_accessor memory_region_write_accessor_x86_64
#define memory_region_wrong_endianness memory_region_wrong_endianness_x86_64
#define memory_try_enable_merging memory_try_enable_merging_x86_64
#define module_call_init module_call_init_x86_64
#define module_load module_load_x86_64
#define mpidr_cp_reginfo mpidr_cp_reginfo_x86_64
#define mpidr_read mpidr_read_x86_64
#define msr_mask msr_mask_x86_64
#define mul128By64To192 mul128By64To192_x86_64
#define mul128To256 mul128To256_x86_64
#define mul64To128 mul64To128_x86_64
#define muldiv64 muldiv64_x86_64
#define neon_2rm_is_float_op neon_2rm_is_float_op_x86_64
#define neon_2rm_sizes neon_2rm_sizes_x86_64
#define neon_3r_sizes neon_3r_sizes_x86_64
#define neon_get_scalar neon_get_scalar_x86_64
#define neon_load_reg neon_load_reg_x86_64
#define neon_load_reg64 neon_load_reg64_x86_64
#define neon_load_scratch neon_load_scratch_x86_64
#define neon_ls_element_type neon_ls_element_type_x86_64
#define neon_reg_offset neon_reg_offset_x86_64
#define neon_store_reg neon_store_reg_x86_64
#define neon_store_reg64 neon_store_reg64_x86_64
#define neon_store_scratch neon_store_scratch_x86_64
#define new_ldst_label new_ldst_label_x86_64
#define next_list next_list_x86_64
#define normalizeFloat128Subnormal normalizeFloat128Subnormal_x86_64
#define normalizeFloat16Subnormal normalizeFloat16Subnormal_x86_64
#define normalizeFloat32Subnormal normalizeFloat32Subnormal_x86_64
#define normalizeFloat64Subnormal normalizeFloat64Subnormal_x86_64
#define normalizeFloatx80Subnormal normalizeFloatx80Subnormal_x86_64
#define normalizeRoundAndPackFloat128 normalizeRoundAndPackFloat128_x86_64
#define normalizeRoundAndPackFloat32 normalizeRoundAndPackFloat32_x86_64
#define normalizeRoundAndPackFloat64 normalizeRoundAndPackFloat64_x86_64
#define normalizeRoundAndPackFloatx80 normalizeRoundAndPackFloatx80_x86_64
#define not_v6_cp_reginfo not_v6_cp_reginfo_x86_64
#define not_v7_cp_reginfo not_v7_cp_reginfo_x86_64
#define not_v8_cp_reginfo not_v8_cp_reginfo_x86_64
#define object_child_foreach object_child_foreach_x86_64
#define object_class_foreach object_class_foreach_x86_64
#define object_class_foreach_tramp object_class_foreach_tramp_x86_64
#define object_class_get_list object_class_get_list_x86_64
#define object_class_get_list_tramp object_class_get_list_tramp_x86_64
#define object_class_get_parent object_class_get_parent_x86_64
#define object_deinit object_deinit_x86_64
#define object_dynamic_cast object_dynamic_cast_x86_64
#define object_finalize object_finalize_x86_64
#define object_finalize_child_property object_finalize_child_property_x86_64
#define object_get_child_property object_get_child_property_x86_64
#define object_get_link_property object_get_link_property_x86_64
#define object_get_root object_get_root_x86_64
#define object_initialize_with_type object_initialize_with_type_x86_64
#define object_init_with_type object_init_with_type_x86_64
#define object_instance_init object_instance_init_x86_64
#define object_new_with_type object_new_with_type_x86_64
#define object_post_init_with_type object_post_init_with_type_x86_64
#define object_property_add_alias object_property_add_alias_x86_64
#define object_property_add_link object_property_add_link_x86_64
#define object_property_add_uint16_ptr object_property_add_uint16_ptr_x86_64
#define object_property_add_uint32_ptr object_property_add_uint32_ptr_x86_64
#define object_property_add_uint64_ptr object_property_add_uint64_ptr_x86_64
#define object_property_add_uint8_ptr object_property_add_uint8_ptr_x86_64
#define object_property_allow_set_link object_property_allow_set_link_x86_64
#define object_property_del object_property_del_x86_64
#define object_property_del_all object_property_del_all_x86_64
#define object_property_find object_property_find_x86_64
#define object_property_get object_property_get_x86_64
#define object_property_get_bool object_property_get_bool_x86_64
#define object_property_get_int object_property_get_int_x86_64
#define object_property_get_link object_property_get_link_x86_64
#define object_property_get_qobject object_property_get_qobject_x86_64
#define object_property_get_str object_property_get_str_x86_64
#define object_property_get_type object_property_get_type_x86_64
#define object_property_is_child object_property_is_child_x86_64
#define object_property_set object_property_set_x86_64
#define object_property_set_description object_property_set_description_x86_64
#define object_property_set_link object_property_set_link_x86_64
#define object_property_set_qobject object_property_set_qobject_x86_64
#define object_release_link_property object_release_link_property_x86_64
#define object_resolve_abs_path object_resolve_abs_path_x86_64
#define object_resolve_child_property object_resolve_child_property_x86_64
#define object_resolve_link object_resolve_link_x86_64
#define object_resolve_link_property object_resolve_link_property_x86_64
#define object_resolve_partial_path object_resolve_partial_path_x86_64
#define object_resolve_path object_resolve_path_x86_64
#define object_resolve_path_component object_resolve_path_component_x86_64
#define object_resolve_path_type object_resolve_path_type_x86_64
#define object_set_link_property object_set_link_property_x86_64
#define object_unparent object_unparent_x86_64
#define omap_cachemaint_write omap_cachemaint_write_x86_64
#define omap_cp_reginfo omap_cp_reginfo_x86_64
#define omap_threadid_write omap_threadid_write_x86_64
#define omap_ticonfig_write omap_ticonfig_write_x86_64
#define omap_wfi_write omap_wfi_write_x86_64
#define op_bits op_bits_x86_64
#define open_modeflags open_modeflags_x86_64
#define op_to_mov op_to_mov_x86_64
#define op_to_movi op_to_movi_x86_64
#define output_type_enum output_type_enum_x86_64
#define packFloat128 packFloat128_x86_64
#define packFloat16 packFloat16_x86_64
#define packFloat32 packFloat32_x86_64
#define packFloat64 packFloat64_x86_64
#define packFloatx80 packFloatx80_x86_64
#define page_find page_find_x86_64
#define page_find_alloc page_find_alloc_x86_64
#define page_flush_tb page_flush_tb_x86_64
#define page_flush_tb_1 page_flush_tb_1_x86_64
#define page_init page_init_x86_64
#define page_size_init page_size_init_x86_64
#define par par_x86_64
#define parse_array parse_array_x86_64
#define parse_error parse_error_x86_64
#define parse_escape parse_escape_x86_64
#define parse_keyword parse_keyword_x86_64
#define parse_literal parse_literal_x86_64
#define parse_object parse_object_x86_64
#define parse_optional parse_optional_x86_64
#define parse_option_bool parse_option_bool_x86_64
#define parse_option_number parse_option_number_x86_64
#define parse_option_size parse_option_size_x86_64
#define parse_pair parse_pair_x86_64
#define parser_context_free parser_context_free_x86_64
#define parser_context_new parser_context_new_x86_64
#define parser_context_peek_token parser_context_peek_token_x86_64
#define parser_context_pop_token parser_context_pop_token_x86_64
#define parser_context_restore parser_context_restore_x86_64
#define parser_context_save parser_context_save_x86_64
#define parse_str parse_str_x86_64
#define parse_type_bool parse_type_bool_x86_64
#define parse_type_int parse_type_int_x86_64
#define parse_type_number parse_type_number_x86_64
#define parse_type_size parse_type_size_x86_64
#define parse_type_str parse_type_str_x86_64
#define parse_value parse_value_x86_64
#define par_write par_write_x86_64
#define patch_reloc patch_reloc_x86_64
#define phys_map_node_alloc phys_map_node_alloc_x86_64
#define phys_map_node_reserve phys_map_node_reserve_x86_64
#define phys_mem_alloc phys_mem_alloc_x86_64
#define phys_mem_set_alloc phys_mem_set_alloc_x86_64
#define phys_page_compact phys_page_compact_x86_64
#define phys_page_compact_all phys_page_compact_all_x86_64
#define phys_page_find phys_page_find_x86_64
#define phys_page_set phys_page_set_x86_64
#define phys_page_set_level phys_page_set_level_x86_64
#define phys_section_add phys_section_add_x86_64
#define phys_section_destroy phys_section_destroy_x86_64
#define phys_sections_free phys_sections_free_x86_64
#define pickNaN pickNaN_x86_64
#define pickNaNMulAdd pickNaNMulAdd_x86_64
#define pmccfiltr_write pmccfiltr_write_x86_64
#define pmccntr_read pmccntr_read_x86_64
#define pmccntr_sync pmccntr_sync_x86_64
#define pmccntr_write pmccntr_write_x86_64
#define pmccntr_write32 pmccntr_write32_x86_64
#define pmcntenclr_write pmcntenclr_write_x86_64
#define pmcntenset_write pmcntenset_write_x86_64
#define pmcr_write pmcr_write_x86_64
#define pmintenclr_write pmintenclr_write_x86_64
#define pmintenset_write pmintenset_write_x86_64
#define pmovsr_write pmovsr_write_x86_64
#define pmreg_access pmreg_access_x86_64
#define pmsav5_cp_reginfo pmsav5_cp_reginfo_x86_64
#define pmsav5_data_ap_read pmsav5_data_ap_read_x86_64
#define pmsav5_data_ap_write pmsav5_data_ap_write_x86_64
#define pmsav5_insn_ap_read pmsav5_insn_ap_read_x86_64
#define pmsav5_insn_ap_write pmsav5_insn_ap_write_x86_64
#define pmuserenr_write pmuserenr_write_x86_64
#define pmxevtyper_write pmxevtyper_write_x86_64
#define print_type_bool print_type_bool_x86_64
#define print_type_int print_type_int_x86_64
#define print_type_number print_type_number_x86_64
#define print_type_size print_type_size_x86_64
#define print_type_str print_type_str_x86_64
#define propagateFloat128NaN propagateFloat128NaN_x86_64
#define propagateFloat32MulAddNaN propagateFloat32MulAddNaN_x86_64
#define propagateFloat32NaN propagateFloat32NaN_x86_64
#define propagateFloat64MulAddNaN propagateFloat64MulAddNaN_x86_64
#define propagateFloat64NaN propagateFloat64NaN_x86_64
#define propagateFloatx80NaN propagateFloatx80NaN_x86_64
#define property_get_alias property_get_alias_x86_64
#define property_get_bool property_get_bool_x86_64
#define property_get_str property_get_str_x86_64
#define property_get_uint16_ptr property_get_uint16_ptr_x86_64
#define property_get_uint32_ptr property_get_uint32_ptr_x86_64
#define property_get_uint64_ptr property_get_uint64_ptr_x86_64
#define property_get_uint8_ptr property_get_uint8_ptr_x86_64
#define property_release_alias property_release_alias_x86_64
#define property_release_bool property_release_bool_x86_64
#define property_release_str property_release_str_x86_64
#define property_resolve_alias property_resolve_alias_x86_64
#define property_set_alias property_set_alias_x86_64
#define property_set_bool property_set_bool_x86_64
#define property_set_str property_set_str_x86_64
#define pstate_read pstate_read_x86_64
#define pstate_write pstate_write_x86_64
#define pxa250_initfn pxa250_initfn_x86_64
#define pxa255_initfn pxa255_initfn_x86_64
#define pxa260_initfn pxa260_initfn_x86_64
#define pxa261_initfn pxa261_initfn_x86_64
#define pxa262_initfn pxa262_initfn_x86_64
#define pxa270a0_initfn pxa270a0_initfn_x86_64
#define pxa270a1_initfn pxa270a1_initfn_x86_64
#define pxa270b0_initfn pxa270b0_initfn_x86_64
#define pxa270b1_initfn pxa270b1_initfn_x86_64
#define pxa270c0_initfn pxa270c0_initfn_x86_64
#define pxa270c5_initfn pxa270c5_initfn_x86_64
#define qapi_dealloc_end_implicit_struct qapi_dealloc_end_implicit_struct_x86_64
#define qapi_dealloc_end_list qapi_dealloc_end_list_x86_64
#define qapi_dealloc_end_struct qapi_dealloc_end_struct_x86_64
#define qapi_dealloc_get_visitor qapi_dealloc_get_visitor_x86_64
#define qapi_dealloc_next_list qapi_dealloc_next_list_x86_64
#define qapi_dealloc_pop qapi_dealloc_pop_x86_64
#define qapi_dealloc_push qapi_dealloc_push_x86_64
#define qapi_dealloc_start_implicit_struct qapi_dealloc_start_implicit_struct_x86_64
#define qapi_dealloc_start_list qapi_dealloc_start_list_x86_64
#define qapi_dealloc_start_struct qapi_dealloc_start_struct_x86_64
#define qapi_dealloc_start_union qapi_dealloc_start_union_x86_64
#define qapi_dealloc_type_bool qapi_dealloc_type_bool_x86_64
#define qapi_dealloc_type_enum qapi_dealloc_type_enum_x86_64
#define qapi_dealloc_type_int qapi_dealloc_type_int_x86_64
#define qapi_dealloc_type_number qapi_dealloc_type_number_x86_64
#define qapi_dealloc_type_size qapi_dealloc_type_size_x86_64
#define qapi_dealloc_type_str qapi_dealloc_type_str_x86_64
#define qapi_dealloc_visitor_cleanup qapi_dealloc_visitor_cleanup_x86_64
#define qapi_dealloc_visitor_new qapi_dealloc_visitor_new_x86_64
#define qapi_free_boolList qapi_free_boolList_x86_64
#define qapi_free_ErrorClassList qapi_free_ErrorClassList_x86_64
#define qapi_free_int16List qapi_free_int16List_x86_64
#define qapi_free_int32List qapi_free_int32List_x86_64
#define qapi_free_int64List qapi_free_int64List_x86_64
#define qapi_free_int8List qapi_free_int8List_x86_64
#define qapi_free_intList qapi_free_intList_x86_64
#define qapi_free_numberList qapi_free_numberList_x86_64
#define qapi_free_strList qapi_free_strList_x86_64
#define qapi_free_uint16List qapi_free_uint16List_x86_64
#define qapi_free_uint32List qapi_free_uint32List_x86_64
#define qapi_free_uint64List qapi_free_uint64List_x86_64
#define qapi_free_uint8List qapi_free_uint8List_x86_64
#define qapi_free_X86CPUFeatureWordInfo qapi_free_X86CPUFeatureWordInfo_x86_64
#define qapi_free_X86CPUFeatureWordInfoList qapi_free_X86CPUFeatureWordInfoList_x86_64
#define qapi_free_X86CPURegister32List qapi_free_X86CPURegister32List_x86_64
#define qbool_destroy_obj qbool_destroy_obj_x86_64
#define qbool_from_int qbool_from_int_x86_64
#define qbool_get_int qbool_get_int_x86_64
#define qbool_type qbool_type_x86_64
#define qbus_create qbus_create_x86_64
#define qbus_create_inplace qbus_create_inplace_x86_64
#define qbus_finalize qbus_finalize_x86_64
#define qbus_initfn qbus_initfn_x86_64
#define qbus_realize qbus_realize_x86_64
#define qdev_create qdev_create_x86_64
#define qdev_get_type qdev_get_type_x86_64
#define qdev_register_types qdev_register_types_x86_64
#define qdev_set_parent_bus qdev_set_parent_bus_x86_64
#define qdev_try_create qdev_try_create_x86_64
#define qdict_add_key qdict_add_key_x86_64
#define qdict_array_split qdict_array_split_x86_64
#define qdict_clone_shallow qdict_clone_shallow_x86_64
#define qdict_del qdict_del_x86_64
#define qdict_destroy_obj qdict_destroy_obj_x86_64
#define qdict_entry_key qdict_entry_key_x86_64
#define qdict_entry_value qdict_entry_value_x86_64
#define qdict_extract_subqdict qdict_extract_subqdict_x86_64
#define qdict_find qdict_find_x86_64
#define qdict_first qdict_first_x86_64
#define qdict_flatten qdict_flatten_x86_64
#define qdict_flatten_qdict qdict_flatten_qdict_x86_64
#define qdict_flatten_qlist qdict_flatten_qlist_x86_64
#define qdict_get qdict_get_x86_64
#define qdict_get_bool qdict_get_bool_x86_64
#define qdict_get_double qdict_get_double_x86_64
#define qdict_get_int qdict_get_int_x86_64
#define qdict_get_obj qdict_get_obj_x86_64
#define qdict_get_qdict qdict_get_qdict_x86_64
#define qdict_get_qlist qdict_get_qlist_x86_64
#define qdict_get_str qdict_get_str_x86_64
#define qdict_get_try_bool qdict_get_try_bool_x86_64
#define qdict_get_try_int qdict_get_try_int_x86_64
#define qdict_get_try_str qdict_get_try_str_x86_64
#define qdict_haskey qdict_haskey_x86_64
#define qdict_has_prefixed_entries qdict_has_prefixed_entries_x86_64
#define qdict_iter qdict_iter_x86_64
#define qdict_join qdict_join_x86_64
#define qdict_new qdict_new_x86_64
#define qdict_next qdict_next_x86_64
#define qdict_next_entry qdict_next_entry_x86_64
#define qdict_put_obj qdict_put_obj_x86_64
#define qdict_size qdict_size_x86_64
#define qdict_type qdict_type_x86_64
#define qemu_clock_get_us qemu_clock_get_us_x86_64
#define qemu_clock_ptr qemu_clock_ptr_x86_64
#define qemu_clocks qemu_clocks_x86_64
#define qemu_get_cpu qemu_get_cpu_x86_64
#define qemu_get_guest_memory_mapping qemu_get_guest_memory_mapping_x86_64
#define qemu_get_guest_simple_memory_mapping qemu_get_guest_simple_memory_mapping_x86_64
#define qemu_get_ram_block qemu_get_ram_block_x86_64
#define qemu_get_ram_block_host_ptr qemu_get_ram_block_host_ptr_x86_64
#define qemu_get_ram_fd qemu_get_ram_fd_x86_64
#define qemu_get_ram_ptr qemu_get_ram_ptr_x86_64
#define qemu_host_page_mask qemu_host_page_mask_x86_64
#define qemu_host_page_size qemu_host_page_size_x86_64
#define qemu_init_vcpu qemu_init_vcpu_x86_64
#define qemu_ld_helpers qemu_ld_helpers_x86_64
#define qemu_log_close qemu_log_close_x86_64
#define qemu_log_enabled qemu_log_enabled_x86_64
#define qemu_log_flush qemu_log_flush_x86_64
#define qemu_loglevel_mask qemu_loglevel_mask_x86_64
#define qemu_log_vprintf qemu_log_vprintf_x86_64
#define qemu_oom_check qemu_oom_check_x86_64
#define qemu_parse_fd qemu_parse_fd_x86_64
#define qemu_ram_addr_from_host qemu_ram_addr_from_host_x86_64
#define qemu_ram_addr_from_host_nofail qemu_ram_addr_from_host_nofail_x86_64
#define qemu_ram_alloc qemu_ram_alloc_x86_64
#define qemu_ram_alloc_from_ptr qemu_ram_alloc_from_ptr_x86_64
#define qemu_ram_foreach_block qemu_ram_foreach_block_x86_64
#define qemu_ram_free qemu_ram_free_x86_64
#define qemu_ram_free_from_ptr qemu_ram_free_from_ptr_x86_64
#define qemu_ram_ptr_length qemu_ram_ptr_length_x86_64
#define qemu_ram_remap qemu_ram_remap_x86_64
#define qemu_ram_setup_dump qemu_ram_setup_dump_x86_64
#define qemu_ram_unset_idstr qemu_ram_unset_idstr_x86_64
#define qemu_real_host_page_size qemu_real_host_page_size_x86_64
#define qemu_st_helpers qemu_st_helpers_x86_64
#define qemu_tcg_init_vcpu qemu_tcg_init_vcpu_x86_64
#define qemu_try_memalign qemu_try_memalign_x86_64
#define qentry_destroy qentry_destroy_x86_64
#define qerror_human qerror_human_x86_64
#define qerror_report qerror_report_x86_64
#define qerror_report_err qerror_report_err_x86_64
#define qfloat_destroy_obj qfloat_destroy_obj_x86_64
#define qfloat_from_double qfloat_from_double_x86_64
#define qfloat_get_double qfloat_get_double_x86_64
#define qfloat_type qfloat_type_x86_64
#define qint_destroy_obj qint_destroy_obj_x86_64
#define qint_from_int qint_from_int_x86_64
#define qint_get_int qint_get_int_x86_64
#define qint_type qint_type_x86_64
#define qlist_append_obj qlist_append_obj_x86_64
#define qlist_copy qlist_copy_x86_64
#define qlist_copy_elem qlist_copy_elem_x86_64
#define qlist_destroy_obj qlist_destroy_obj_x86_64
#define qlist_empty qlist_empty_x86_64
#define qlist_entry_obj qlist_entry_obj_x86_64
#define qlist_first qlist_first_x86_64
#define qlist_iter qlist_iter_x86_64
#define qlist_new qlist_new_x86_64
#define qlist_next qlist_next_x86_64
#define qlist_peek qlist_peek_x86_64
#define qlist_pop qlist_pop_x86_64
#define qlist_size qlist_size_x86_64
#define qlist_size_iter qlist_size_iter_x86_64
#define qlist_type qlist_type_x86_64
#define qmp_input_end_implicit_struct qmp_input_end_implicit_struct_x86_64
#define qmp_input_end_list qmp_input_end_list_x86_64
#define qmp_input_end_struct qmp_input_end_struct_x86_64
#define qmp_input_get_next_type qmp_input_get_next_type_x86_64
#define qmp_input_get_object qmp_input_get_object_x86_64
#define qmp_input_get_visitor qmp_input_get_visitor_x86_64
#define qmp_input_next_list qmp_input_next_list_x86_64
#define qmp_input_optional qmp_input_optional_x86_64
#define qmp_input_pop qmp_input_pop_x86_64
#define qmp_input_push qmp_input_push_x86_64
#define qmp_input_start_implicit_struct qmp_input_start_implicit_struct_x86_64
#define qmp_input_start_list qmp_input_start_list_x86_64
#define qmp_input_start_struct qmp_input_start_struct_x86_64
#define qmp_input_type_bool qmp_input_type_bool_x86_64
#define qmp_input_type_int qmp_input_type_int_x86_64
#define qmp_input_type_number qmp_input_type_number_x86_64
#define qmp_input_type_str qmp_input_type_str_x86_64
#define qmp_input_visitor_cleanup qmp_input_visitor_cleanup_x86_64
#define qmp_input_visitor_new qmp_input_visitor_new_x86_64
#define qmp_input_visitor_new_strict qmp_input_visitor_new_strict_x86_64
#define qmp_output_add_obj qmp_output_add_obj_x86_64
#define qmp_output_end_list qmp_output_end_list_x86_64
#define qmp_output_end_struct qmp_output_end_struct_x86_64
#define qmp_output_first qmp_output_first_x86_64
#define qmp_output_get_qobject qmp_output_get_qobject_x86_64
#define qmp_output_get_visitor qmp_output_get_visitor_x86_64
#define qmp_output_last qmp_output_last_x86_64
#define qmp_output_next_list qmp_output_next_list_x86_64
#define qmp_output_pop qmp_output_pop_x86_64
#define qmp_output_push_obj qmp_output_push_obj_x86_64
#define qmp_output_start_list qmp_output_start_list_x86_64
#define qmp_output_start_struct qmp_output_start_struct_x86_64
#define qmp_output_type_bool qmp_output_type_bool_x86_64
#define qmp_output_type_int qmp_output_type_int_x86_64
#define qmp_output_type_number qmp_output_type_number_x86_64
#define qmp_output_type_str qmp_output_type_str_x86_64
#define qmp_output_visitor_cleanup qmp_output_visitor_cleanup_x86_64
#define qmp_output_visitor_new qmp_output_visitor_new_x86_64
#define qobject_decref qobject_decref_x86_64
#define qobject_to_qbool qobject_to_qbool_x86_64
#define qobject_to_qdict qobject_to_qdict_x86_64
#define qobject_to_qfloat qobject_to_qfloat_x86_64
#define qobject_to_qint qobject_to_qint_x86_64
#define qobject_to_qlist qobject_to_qlist_x86_64
#define qobject_to_qstring qobject_to_qstring_x86_64
#define qobject_type qobject_type_x86_64
#define qstring_append qstring_append_x86_64
#define qstring_append_chr qstring_append_chr_x86_64
#define qstring_append_int qstring_append_int_x86_64
#define qstring_destroy_obj qstring_destroy_obj_x86_64
#define qstring_from_escaped_str qstring_from_escaped_str_x86_64
#define qstring_from_str qstring_from_str_x86_64
#define qstring_from_substr qstring_from_substr_x86_64
#define qstring_get_length qstring_get_length_x86_64
#define qstring_get_str qstring_get_str_x86_64
#define qstring_new qstring_new_x86_64
#define qstring_type qstring_type_x86_64
#define ram_block_add ram_block_add_x86_64
#define ram_size ram_size_x86_64
#define range_compare range_compare_x86_64
#define range_covers_byte range_covers_byte_x86_64
#define range_get_last range_get_last_x86_64
#define range_merge range_merge_x86_64
#define ranges_can_merge ranges_can_merge_x86_64
#define raw_read raw_read_x86_64
#define raw_write raw_write_x86_64
#define rcon rcon_x86_64
#define read_raw_cp_reg read_raw_cp_reg_x86_64
#define recip_estimate recip_estimate_x86_64
#define recip_sqrt_estimate recip_sqrt_estimate_x86_64
#define register_cp_regs_for_features register_cp_regs_for_features_x86_64
#define register_multipage register_multipage_x86_64
#define register_subpage register_subpage_x86_64
#define register_tm_clones register_tm_clones_x86_64
#define register_types_object register_types_object_x86_64
#define regnames regnames_x86_64
#define render_memory_region render_memory_region_x86_64
#define reset_all_temps reset_all_temps_x86_64
#define reset_temp reset_temp_x86_64
#define rol32 rol32_x86_64
#define rol64 rol64_x86_64
#define ror32 ror32_x86_64
#define ror64 ror64_x86_64
#define roundAndPackFloat128 roundAndPackFloat128_x86_64
#define roundAndPackFloat16 roundAndPackFloat16_x86_64
#define roundAndPackFloat32 roundAndPackFloat32_x86_64
#define roundAndPackFloat64 roundAndPackFloat64_x86_64
#define roundAndPackFloatx80 roundAndPackFloatx80_x86_64
#define roundAndPackInt32 roundAndPackInt32_x86_64
#define roundAndPackInt64 roundAndPackInt64_x86_64
#define roundAndPackUint64 roundAndPackUint64_x86_64
#define round_to_inf round_to_inf_x86_64
#define run_on_cpu run_on_cpu_x86_64
#define s0 s0_x86_64
#define S0 S0_x86_64
#define s1 s1_x86_64
#define S1 S1_x86_64
#define sa1100_initfn sa1100_initfn_x86_64
#define sa1110_initfn sa1110_initfn_x86_64
#define save_globals save_globals_x86_64
#define scr_write scr_write_x86_64
#define sctlr_write sctlr_write_x86_64
#define set_bit set_bit_x86_64
#define set_bits set_bits_x86_64
#define set_default_nan_mode set_default_nan_mode_x86_64
#define set_feature set_feature_x86_64
#define set_float_detect_tininess set_float_detect_tininess_x86_64
#define set_float_exception_flags set_float_exception_flags_x86_64
#define set_float_rounding_mode set_float_rounding_mode_x86_64
#define set_flush_inputs_to_zero set_flush_inputs_to_zero_x86_64
#define set_flush_to_zero set_flush_to_zero_x86_64
#define set_swi_errno set_swi_errno_x86_64
#define sextract32 sextract32_x86_64
#define sextract64 sextract64_x86_64
#define shift128ExtraRightJamming shift128ExtraRightJamming_x86_64
#define shift128Right shift128Right_x86_64
#define shift128RightJamming shift128RightJamming_x86_64
#define shift32RightJamming shift32RightJamming_x86_64
#define shift64ExtraRightJamming shift64ExtraRightJamming_x86_64
#define shift64RightJamming shift64RightJamming_x86_64
#define shifter_out_im shifter_out_im_x86_64
#define shortShift128Left shortShift128Left_x86_64
#define shortShift192Left shortShift192Left_x86_64
#define simple_mpu_ap_bits simple_mpu_ap_bits_x86_64
#define size_code_gen_buffer size_code_gen_buffer_x86_64
#define softmmu_lock_user softmmu_lock_user_x86_64
#define softmmu_lock_user_string softmmu_lock_user_string_x86_64
#define softmmu_tget32 softmmu_tget32_x86_64
#define softmmu_tget8 softmmu_tget8_x86_64
#define softmmu_tput32 softmmu_tput32_x86_64
#define softmmu_unlock_user softmmu_unlock_user_x86_64
#define sort_constraints sort_constraints_x86_64
#define sp_el0_access sp_el0_access_x86_64
#define spsel_read spsel_read_x86_64
#define spsel_write spsel_write_x86_64
#define start_list start_list_x86_64
#define stb_p stb_p_x86_64
#define stb_phys stb_phys_x86_64
#define stl_be_p stl_be_p_x86_64
#define stl_be_phys stl_be_phys_x86_64
#define stl_he_p stl_he_p_x86_64
#define stl_le_p stl_le_p_x86_64
#define stl_le_phys stl_le_phys_x86_64
#define stl_phys stl_phys_x86_64
#define stl_phys_internal stl_phys_internal_x86_64
#define stl_phys_notdirty stl_phys_notdirty_x86_64
#define store_cpu_offset store_cpu_offset_x86_64
#define store_reg store_reg_x86_64
#define store_reg_bx store_reg_bx_x86_64
#define store_reg_from_load store_reg_from_load_x86_64
#define stq_be_p stq_be_p_x86_64
#define stq_be_phys stq_be_phys_x86_64
#define stq_he_p stq_he_p_x86_64
#define stq_le_p stq_le_p_x86_64
#define stq_le_phys stq_le_phys_x86_64
#define stq_phys stq_phys_x86_64
#define string_input_get_visitor string_input_get_visitor_x86_64
#define string_input_visitor_cleanup string_input_visitor_cleanup_x86_64
#define string_input_visitor_new string_input_visitor_new_x86_64
#define strongarm_cp_reginfo strongarm_cp_reginfo_x86_64
#define strstart strstart_x86_64
#define strtosz strtosz_x86_64
#define strtosz_suffix strtosz_suffix_x86_64
#define stw_be_p stw_be_p_x86_64
#define stw_be_phys stw_be_phys_x86_64
#define stw_he_p stw_he_p_x86_64
#define stw_le_p stw_le_p_x86_64
#define stw_le_phys stw_le_phys_x86_64
#define stw_phys stw_phys_x86_64
#define stw_phys_internal stw_phys_internal_x86_64
#define sub128 sub128_x86_64
#define sub16_sat sub16_sat_x86_64
#define sub16_usat sub16_usat_x86_64
#define sub192 sub192_x86_64
#define sub8_sat sub8_sat_x86_64
#define sub8_usat sub8_usat_x86_64
#define subFloat128Sigs subFloat128Sigs_x86_64
#define subFloat32Sigs subFloat32Sigs_x86_64
#define subFloat64Sigs subFloat64Sigs_x86_64
#define subFloatx80Sigs subFloatx80Sigs_x86_64
#define subpage_accepts subpage_accepts_x86_64
#define subpage_init subpage_init_x86_64
#define subpage_ops subpage_ops_x86_64
#define subpage_read subpage_read_x86_64
#define subpage_register subpage_register_x86_64
#define subpage_write subpage_write_x86_64
#define suffix_mul suffix_mul_x86_64
#define swap_commutative swap_commutative_x86_64
#define swap_commutative2 swap_commutative2_x86_64
#define switch_mode switch_mode_x86_64
#define switch_v7m_sp switch_v7m_sp_x86_64
#define syn_aa32_bkpt syn_aa32_bkpt_x86_64
#define syn_aa32_hvc syn_aa32_hvc_x86_64
#define syn_aa32_smc syn_aa32_smc_x86_64
#define syn_aa32_svc syn_aa32_svc_x86_64
#define syn_breakpoint syn_breakpoint_x86_64
#define sync_globals sync_globals_x86_64
#define syn_cp14_rrt_trap syn_cp14_rrt_trap_x86_64
#define syn_cp14_rt_trap syn_cp14_rt_trap_x86_64
#define syn_cp15_rrt_trap syn_cp15_rrt_trap_x86_64
#define syn_cp15_rt_trap syn_cp15_rt_trap_x86_64
#define syn_data_abort syn_data_abort_x86_64
#define syn_fp_access_trap syn_fp_access_trap_x86_64
#define syn_insn_abort syn_insn_abort_x86_64
#define syn_swstep syn_swstep_x86_64
#define syn_uncategorized syn_uncategorized_x86_64
#define syn_watchpoint syn_watchpoint_x86_64
#define syscall_err syscall_err_x86_64
#define system_bus_class_init system_bus_class_init_x86_64
#define system_bus_info system_bus_info_x86_64
#define t2ee_cp_reginfo t2ee_cp_reginfo_x86_64
#define table_logic_cc table_logic_cc_x86_64
#define target_parse_constraint target_parse_constraint_x86_64
#define target_words_bigendian target_words_bigendian_x86_64
#define tb_add_jump tb_add_jump_x86_64
#define tb_alloc tb_alloc_x86_64
#define tb_alloc_page tb_alloc_page_x86_64
#define tb_check_watchpoint tb_check_watchpoint_x86_64
#define tb_find_fast tb_find_fast_x86_64
#define tb_find_pc tb_find_pc_x86_64
#define tb_find_slow tb_find_slow_x86_64
#define tb_flush tb_flush_x86_64
#define tb_flush_jmp_cache tb_flush_jmp_cache_x86_64
#define tb_free tb_free_x86_64
#define tb_gen_code tb_gen_code_x86_64
#define tb_hash_remove tb_hash_remove_x86_64
#define tb_invalidate_phys_addr tb_invalidate_phys_addr_x86_64
#define tb_invalidate_phys_page_range tb_invalidate_phys_page_range_x86_64
#define tb_invalidate_phys_range tb_invalidate_phys_range_x86_64
#define tb_jmp_cache_hash_func tb_jmp_cache_hash_func_x86_64
#define tb_jmp_cache_hash_page tb_jmp_cache_hash_page_x86_64
#define tb_jmp_remove tb_jmp_remove_x86_64
#define tb_link_page tb_link_page_x86_64
#define tb_page_remove tb_page_remove_x86_64
#define tb_phys_hash_func tb_phys_hash_func_x86_64
#define tb_phys_invalidate tb_phys_invalidate_x86_64
#define tb_reset_jump tb_reset_jump_x86_64
#define tb_set_jmp_target tb_set_jmp_target_x86_64
#define tcg_accel_class_init tcg_accel_class_init_x86_64
#define tcg_accel_type tcg_accel_type_x86_64
#define tcg_add_param_i32 tcg_add_param_i32_x86_64
#define tcg_add_param_i64 tcg_add_param_i64_x86_64
#define tcg_add_target_add_op_defs tcg_add_target_add_op_defs_x86_64
#define tcg_allowed tcg_allowed_x86_64
#define tcg_canonicalize_memop tcg_canonicalize_memop_x86_64
#define tcg_commit tcg_commit_x86_64
#define tcg_cond_to_jcc tcg_cond_to_jcc_x86_64
#define tcg_constant_folding tcg_constant_folding_x86_64
#define tcg_const_i32 tcg_const_i32_x86_64
#define tcg_const_i64 tcg_const_i64_x86_64
#define tcg_const_local_i32 tcg_const_local_i32_x86_64
#define tcg_const_local_i64 tcg_const_local_i64_x86_64
#define tcg_context_init tcg_context_init_x86_64
#define tcg_cpu_address_space_init tcg_cpu_address_space_init_x86_64
#define tcg_cpu_exec tcg_cpu_exec_x86_64
#define tcg_current_code_size tcg_current_code_size_x86_64
#define tcg_dump_info tcg_dump_info_x86_64
#define tcg_dump_ops tcg_dump_ops_x86_64
#define tcg_exec_all tcg_exec_all_x86_64
#define tcg_find_helper tcg_find_helper_x86_64
#define tcg_func_start tcg_func_start_x86_64
#define tcg_gen_abs_i32 tcg_gen_abs_i32_x86_64
#define tcg_gen_add2_i32 tcg_gen_add2_i32_x86_64
#define tcg_gen_add_i32 tcg_gen_add_i32_x86_64
#define tcg_gen_add_i64 tcg_gen_add_i64_x86_64
#define tcg_gen_addi_i32 tcg_gen_addi_i32_x86_64
#define tcg_gen_addi_i64 tcg_gen_addi_i64_x86_64
#define tcg_gen_andc_i32 tcg_gen_andc_i32_x86_64
#define tcg_gen_and_i32 tcg_gen_and_i32_x86_64
#define tcg_gen_and_i64 tcg_gen_and_i64_x86_64
#define tcg_gen_andi_i32 tcg_gen_andi_i32_x86_64
#define tcg_gen_andi_i64 tcg_gen_andi_i64_x86_64
#define tcg_gen_br tcg_gen_br_x86_64
#define tcg_gen_brcond_i32 tcg_gen_brcond_i32_x86_64
#define tcg_gen_brcond_i64 tcg_gen_brcond_i64_x86_64
#define tcg_gen_brcondi_i32 tcg_gen_brcondi_i32_x86_64
#define tcg_gen_bswap16_i32 tcg_gen_bswap16_i32_x86_64
#define tcg_gen_bswap32_i32 tcg_gen_bswap32_i32_x86_64
#define tcg_gen_callN tcg_gen_callN_x86_64
#define tcg_gen_code tcg_gen_code_x86_64
#define tcg_gen_code_common tcg_gen_code_common_x86_64
#define tcg_gen_code_search_pc tcg_gen_code_search_pc_x86_64
#define tcg_gen_concat_i32_i64 tcg_gen_concat_i32_i64_x86_64
#define tcg_gen_debug_insn_start tcg_gen_debug_insn_start_x86_64
#define tcg_gen_deposit_i32 tcg_gen_deposit_i32_x86_64
#define tcg_gen_exit_tb tcg_gen_exit_tb_x86_64
#define tcg_gen_ext16s_i32 tcg_gen_ext16s_i32_x86_64
#define tcg_gen_ext16u_i32 tcg_gen_ext16u_i32_x86_64
#define tcg_gen_ext32s_i64 tcg_gen_ext32s_i64_x86_64
#define tcg_gen_ext32u_i64 tcg_gen_ext32u_i64_x86_64
#define tcg_gen_ext8s_i32 tcg_gen_ext8s_i32_x86_64
#define tcg_gen_ext8u_i32 tcg_gen_ext8u_i32_x86_64
#define tcg_gen_ext_i32_i64 tcg_gen_ext_i32_i64_x86_64
#define tcg_gen_extu_i32_i64 tcg_gen_extu_i32_i64_x86_64
#define tcg_gen_goto_tb tcg_gen_goto_tb_x86_64
#define tcg_gen_ld_i32 tcg_gen_ld_i32_x86_64
#define tcg_gen_ld_i64 tcg_gen_ld_i64_x86_64
#define tcg_gen_ldst_op_i32 tcg_gen_ldst_op_i32_x86_64
#define tcg_gen_ldst_op_i64 tcg_gen_ldst_op_i64_x86_64
#define tcg_gen_movcond_i32 tcg_gen_movcond_i32_x86_64
#define tcg_gen_movcond_i64 tcg_gen_movcond_i64_x86_64
#define tcg_gen_mov_i32 tcg_gen_mov_i32_x86_64
#define tcg_gen_mov_i64 tcg_gen_mov_i64_x86_64
#define tcg_gen_movi_i32 tcg_gen_movi_i32_x86_64
#define tcg_gen_movi_i64 tcg_gen_movi_i64_x86_64
#define tcg_gen_mul_i32 tcg_gen_mul_i32_x86_64
#define tcg_gen_muls2_i32 tcg_gen_muls2_i32_x86_64
#define tcg_gen_mulu2_i32 tcg_gen_mulu2_i32_x86_64
#define tcg_gen_neg_i32 tcg_gen_neg_i32_x86_64
#define tcg_gen_neg_i64 tcg_gen_neg_i64_x86_64
#define tcg_gen_not_i32 tcg_gen_not_i32_x86_64
#define tcg_gen_op0 tcg_gen_op0_x86_64
#define tcg_gen_op1i tcg_gen_op1i_x86_64
#define tcg_gen_op2_i32 tcg_gen_op2_i32_x86_64
#define tcg_gen_op2_i64 tcg_gen_op2_i64_x86_64
#define tcg_gen_op2i_i32 tcg_gen_op2i_i32_x86_64
#define tcg_gen_op2i_i64 tcg_gen_op2i_i64_x86_64
#define tcg_gen_op3_i32 tcg_gen_op3_i32_x86_64
#define tcg_gen_op3_i64 tcg_gen_op3_i64_x86_64
#define tcg_gen_op4_i32 tcg_gen_op4_i32_x86_64
#define tcg_gen_op4i_i32 tcg_gen_op4i_i32_x86_64
#define tcg_gen_op4ii_i32 tcg_gen_op4ii_i32_x86_64
#define tcg_gen_op4ii_i64 tcg_gen_op4ii_i64_x86_64
#define tcg_gen_op5ii_i32 tcg_gen_op5ii_i32_x86_64
#define tcg_gen_op6_i32 tcg_gen_op6_i32_x86_64
#define tcg_gen_op6i_i32 tcg_gen_op6i_i32_x86_64
#define tcg_gen_op6i_i64 tcg_gen_op6i_i64_x86_64
#define tcg_gen_orc_i32 tcg_gen_orc_i32_x86_64
#define tcg_gen_or_i32 tcg_gen_or_i32_x86_64
#define tcg_gen_or_i64 tcg_gen_or_i64_x86_64
#define tcg_gen_ori_i32 tcg_gen_ori_i32_x86_64
#define tcg_gen_qemu_ld_i32 tcg_gen_qemu_ld_i32_x86_64
#define tcg_gen_qemu_ld_i64 tcg_gen_qemu_ld_i64_x86_64
#define tcg_gen_qemu_st_i32 tcg_gen_qemu_st_i32_x86_64
#define tcg_gen_qemu_st_i64 tcg_gen_qemu_st_i64_x86_64
#define tcg_gen_rotl_i32 tcg_gen_rotl_i32_x86_64
#define tcg_gen_rotli_i32 tcg_gen_rotli_i32_x86_64
#define tcg_gen_rotr_i32 tcg_gen_rotr_i32_x86_64
#define tcg_gen_rotri_i32 tcg_gen_rotri_i32_x86_64
#define tcg_gen_sar_i32 tcg_gen_sar_i32_x86_64
#define tcg_gen_sari_i32 tcg_gen_sari_i32_x86_64
#define tcg_gen_setcond_i32 tcg_gen_setcond_i32_x86_64
#define tcg_gen_shl_i32 tcg_gen_shl_i32_x86_64
#define tcg_gen_shl_i64 tcg_gen_shl_i64_x86_64
#define tcg_gen_shli_i32 tcg_gen_shli_i32_x86_64
#define tcg_gen_shli_i64 tcg_gen_shli_i64_x86_64
#define tcg_gen_shr_i32 tcg_gen_shr_i32_x86_64
#define tcg_gen_shifti_i64 tcg_gen_shifti_i64_x86_64
#define tcg_gen_shr_i64 tcg_gen_shr_i64_x86_64
#define tcg_gen_shri_i32 tcg_gen_shri_i32_x86_64
#define tcg_gen_shri_i64 tcg_gen_shri_i64_x86_64
#define tcg_gen_st_i32 tcg_gen_st_i32_x86_64
#define tcg_gen_st_i64 tcg_gen_st_i64_x86_64
#define tcg_gen_sub_i32 tcg_gen_sub_i32_x86_64
#define tcg_gen_sub_i64 tcg_gen_sub_i64_x86_64
#define tcg_gen_subi_i32 tcg_gen_subi_i32_x86_64
#define tcg_gen_trunc_i64_i32 tcg_gen_trunc_i64_i32_x86_64
#define tcg_gen_trunc_shr_i64_i32 tcg_gen_trunc_shr_i64_i32_x86_64
#define tcg_gen_xor_i32 tcg_gen_xor_i32_x86_64
#define tcg_gen_xor_i64 tcg_gen_xor_i64_x86_64
#define tcg_gen_xori_i32 tcg_gen_xori_i32_x86_64
#define tcg_get_arg_str_i32 tcg_get_arg_str_i32_x86_64
#define tcg_get_arg_str_i64 tcg_get_arg_str_i64_x86_64
#define tcg_get_arg_str_idx tcg_get_arg_str_idx_x86_64
#define tcg_global_mem_new_i32 tcg_global_mem_new_i32_x86_64
#define tcg_global_mem_new_i64 tcg_global_mem_new_i64_x86_64
#define tcg_global_mem_new_internal tcg_global_mem_new_internal_x86_64
#define tcg_global_reg_new_i32 tcg_global_reg_new_i32_x86_64
#define tcg_global_reg_new_i64 tcg_global_reg_new_i64_x86_64
#define tcg_global_reg_new_internal tcg_global_reg_new_internal_x86_64
#define tcg_handle_interrupt tcg_handle_interrupt_x86_64
#define tcg_init tcg_init_x86_64
#define tcg_invert_cond tcg_invert_cond_x86_64
#define tcg_la_bb_end tcg_la_bb_end_x86_64
#define tcg_la_br_end tcg_la_br_end_x86_64
#define tcg_la_func_end tcg_la_func_end_x86_64
#define tcg_liveness_analysis tcg_liveness_analysis_x86_64
#define tcg_malloc tcg_malloc_x86_64
#define tcg_malloc_internal tcg_malloc_internal_x86_64
#define tcg_op_defs_org tcg_op_defs_org_x86_64
#define tcg_opt_gen_mov tcg_opt_gen_mov_x86_64
#define tcg_opt_gen_movi tcg_opt_gen_movi_x86_64
#define tcg_optimize tcg_optimize_x86_64
#define tcg_out16 tcg_out16_x86_64
#define tcg_out32 tcg_out32_x86_64
#define tcg_out64 tcg_out64_x86_64
#define tcg_out8 tcg_out8_x86_64
#define tcg_out_addi tcg_out_addi_x86_64
#define tcg_out_branch tcg_out_branch_x86_64
#define tcg_out_brcond32 tcg_out_brcond32_x86_64
#define tcg_out_brcond64 tcg_out_brcond64_x86_64
#define tcg_out_bswap32 tcg_out_bswap32_x86_64
#define tcg_out_bswap64 tcg_out_bswap64_x86_64
#define tcg_out_call tcg_out_call_x86_64
#define tcg_out_cmp tcg_out_cmp_x86_64
#define tcg_out_ext16s tcg_out_ext16s_x86_64
#define tcg_out_ext16u tcg_out_ext16u_x86_64
#define tcg_out_ext32s tcg_out_ext32s_x86_64
#define tcg_out_ext32u tcg_out_ext32u_x86_64
#define tcg_out_ext8s tcg_out_ext8s_x86_64
#define tcg_out_ext8u tcg_out_ext8u_x86_64
#define tcg_out_jmp tcg_out_jmp_x86_64
#define tcg_out_jxx tcg_out_jxx_x86_64
#define tcg_out_label tcg_out_label_x86_64
#define tcg_out_ld tcg_out_ld_x86_64
#define tcg_out_modrm tcg_out_modrm_x86_64
#define tcg_out_modrm_offset tcg_out_modrm_offset_x86_64
#define tcg_out_modrm_sib_offset tcg_out_modrm_sib_offset_x86_64
#define tcg_out_mov tcg_out_mov_x86_64
#define tcg_out_movcond32 tcg_out_movcond32_x86_64
#define tcg_out_movcond64 tcg_out_movcond64_x86_64
#define tcg_out_movi tcg_out_movi_x86_64
#define tcg_out_op tcg_out_op_x86_64
#define tcg_out_pop tcg_out_pop_x86_64
#define tcg_out_push tcg_out_push_x86_64
#define tcg_out_qemu_ld tcg_out_qemu_ld_x86_64
#define tcg_out_qemu_ld_direct tcg_out_qemu_ld_direct_x86_64
#define tcg_out_qemu_ld_slow_path tcg_out_qemu_ld_slow_path_x86_64
#define tcg_out_qemu_st tcg_out_qemu_st_x86_64
#define tcg_out_qemu_st_direct tcg_out_qemu_st_direct_x86_64
#define tcg_out_qemu_st_slow_path tcg_out_qemu_st_slow_path_x86_64
#define tcg_out_reloc tcg_out_reloc_x86_64
#define tcg_out_rolw_8 tcg_out_rolw_8_x86_64
#define tcg_out_setcond32 tcg_out_setcond32_x86_64
#define tcg_out_setcond64 tcg_out_setcond64_x86_64
#define tcg_out_shifti tcg_out_shifti_x86_64
#define tcg_out_st tcg_out_st_x86_64
#define tcg_out_tb_finalize tcg_out_tb_finalize_x86_64
#define tcg_out_tb_init tcg_out_tb_init_x86_64
#define tcg_out_tlb_load tcg_out_tlb_load_x86_64
#define tcg_out_vex_modrm tcg_out_vex_modrm_x86_64
#define tcg_patch32 tcg_patch32_x86_64
#define tcg_patch8 tcg_patch8_x86_64
#define tcg_pcrel_diff tcg_pcrel_diff_x86_64
#define tcg_pool_reset tcg_pool_reset_x86_64
#define tcg_prologue_init tcg_prologue_init_x86_64
#define tcg_ptr_byte_diff tcg_ptr_byte_diff_x86_64
#define tcg_reg_alloc tcg_reg_alloc_x86_64
#define tcg_reg_alloc_bb_end tcg_reg_alloc_bb_end_x86_64
#define tcg_reg_alloc_call tcg_reg_alloc_call_x86_64
#define tcg_reg_alloc_mov tcg_reg_alloc_mov_x86_64
#define tcg_reg_alloc_movi tcg_reg_alloc_movi_x86_64
#define tcg_reg_alloc_op tcg_reg_alloc_op_x86_64
#define tcg_reg_alloc_start tcg_reg_alloc_start_x86_64
#define tcg_reg_free tcg_reg_free_x86_64
#define tcg_reg_sync tcg_reg_sync_x86_64
#define tcg_set_frame tcg_set_frame_x86_64
#define tcg_set_nop tcg_set_nop_x86_64
#define tcg_swap_cond tcg_swap_cond_x86_64
#define tcg_target_callee_save_regs tcg_target_callee_save_regs_x86_64
#define tcg_target_call_iarg_regs tcg_target_call_iarg_regs_x86_64
#define tcg_target_call_oarg_regs tcg_target_call_oarg_regs_x86_64
#define tcg_target_const_match tcg_target_const_match_x86_64
#define tcg_target_init tcg_target_init_x86_64
#define tcg_target_qemu_prologue tcg_target_qemu_prologue_x86_64
#define tcg_target_reg_alloc_order tcg_target_reg_alloc_order_x86_64
#define tcg_temp_alloc tcg_temp_alloc_x86_64
#define tcg_temp_free_i32 tcg_temp_free_i32_x86_64
#define tcg_temp_free_i64 tcg_temp_free_i64_x86_64
#define tcg_temp_free_internal tcg_temp_free_internal_x86_64
#define tcg_temp_local_new_i32 tcg_temp_local_new_i32_x86_64
#define tcg_temp_local_new_i64 tcg_temp_local_new_i64_x86_64
#define tcg_temp_new_i32 tcg_temp_new_i32_x86_64
#define tcg_temp_new_i64 tcg_temp_new_i64_x86_64
#define tcg_temp_new_internal tcg_temp_new_internal_x86_64
#define tcg_temp_new_internal_i32 tcg_temp_new_internal_i32_x86_64
#define tcg_temp_new_internal_i64 tcg_temp_new_internal_i64_x86_64
#define tdb_hash tdb_hash_x86_64
#define teecr_write teecr_write_x86_64
#define teehbr_access teehbr_access_x86_64
#define temp_allocate_frame temp_allocate_frame_x86_64
#define temp_dead temp_dead_x86_64
#define temps_are_copies temps_are_copies_x86_64
#define temp_save temp_save_x86_64
#define temp_sync temp_sync_x86_64
#define tgen_arithi tgen_arithi_x86_64
#define tgen_arithr tgen_arithr_x86_64
#define thumb2_logic_op thumb2_logic_op_x86_64
#define ti925t_initfn ti925t_initfn_x86_64
#define tlb_add_large_page tlb_add_large_page_x86_64
#define tlb_flush_entry tlb_flush_entry_x86_64
#define tlbi_aa64_asid_is_write tlbi_aa64_asid_is_write_x86_64
#define tlbi_aa64_asid_write tlbi_aa64_asid_write_x86_64
#define tlbi_aa64_vaa_is_write tlbi_aa64_vaa_is_write_x86_64
#define tlbi_aa64_vaa_write tlbi_aa64_vaa_write_x86_64
#define tlbi_aa64_va_is_write tlbi_aa64_va_is_write_x86_64
#define tlbi_aa64_va_write tlbi_aa64_va_write_x86_64
#define tlbiall_is_write tlbiall_is_write_x86_64
#define tlbiall_write tlbiall_write_x86_64
#define tlbiasid_is_write tlbiasid_is_write_x86_64
#define tlbiasid_write tlbiasid_write_x86_64
#define tlbimvaa_is_write tlbimvaa_is_write_x86_64
#define tlbimvaa_write tlbimvaa_write_x86_64
#define tlbimva_is_write tlbimva_is_write_x86_64
#define tlbimva_write tlbimva_write_x86_64
#define tlb_is_dirty_ram tlb_is_dirty_ram_x86_64
#define tlb_protect_code tlb_protect_code_x86_64
#define tlb_reset_dirty_range tlb_reset_dirty_range_x86_64
#define tlb_reset_dirty_range_all tlb_reset_dirty_range_all_x86_64
#define tlb_set_dirty tlb_set_dirty_x86_64
#define tlb_set_dirty1 tlb_set_dirty1_x86_64
#define tlb_unprotect_code_phys tlb_unprotect_code_phys_x86_64
#define tlb_vaddr_to_host tlb_vaddr_to_host_x86_64
#define token_get_type token_get_type_x86_64
#define token_get_value token_get_value_x86_64
#define token_is_escape token_is_escape_x86_64
#define token_is_keyword token_is_keyword_x86_64
#define token_is_operator token_is_operator_x86_64
#define tokens_append_from_iter tokens_append_from_iter_x86_64
#define to_qiv to_qiv_x86_64
#define to_qov to_qov_x86_64
#define tosa_init tosa_init_x86_64
#define tosa_machine_init tosa_machine_init_x86_64
#define tswap32 tswap32_x86_64
#define tswap64 tswap64_x86_64
#define type_class_get_size type_class_get_size_x86_64
#define type_get_by_name type_get_by_name_x86_64
#define type_get_parent type_get_parent_x86_64
#define type_has_parent type_has_parent_x86_64
#define type_initialize type_initialize_x86_64
#define type_initialize_interface type_initialize_interface_x86_64
#define type_is_ancestor type_is_ancestor_x86_64
#define type_new type_new_x86_64
#define type_object_get_size type_object_get_size_x86_64
#define type_register_internal type_register_internal_x86_64
#define type_table_add type_table_add_x86_64
#define type_table_get type_table_get_x86_64
#define type_table_lookup type_table_lookup_x86_64
#define uint16_to_float32 uint16_to_float32_x86_64
#define uint16_to_float64 uint16_to_float64_x86_64
#define uint32_to_float32 uint32_to_float32_x86_64
#define uint32_to_float64 uint32_to_float64_x86_64
#define uint64_to_float128 uint64_to_float128_x86_64
#define uint64_to_float32 uint64_to_float32_x86_64
#define uint64_to_float64 uint64_to_float64_x86_64
#define unassigned_io_ops unassigned_io_ops_x86_64
#define unassigned_io_read unassigned_io_read_x86_64
#define unassigned_io_write unassigned_io_write_x86_64
#define unassigned_mem_accepts unassigned_mem_accepts_x86_64
#define unassigned_mem_ops unassigned_mem_ops_x86_64
#define unassigned_mem_read unassigned_mem_read_x86_64
#define unassigned_mem_write unassigned_mem_write_x86_64
#define update_spsel update_spsel_x86_64
#define v6_cp_reginfo v6_cp_reginfo_x86_64
#define v6k_cp_reginfo v6k_cp_reginfo_x86_64
#define v7_cp_reginfo v7_cp_reginfo_x86_64
#define v7mp_cp_reginfo v7mp_cp_reginfo_x86_64
#define v7m_pop v7m_pop_x86_64
#define v7m_push v7m_push_x86_64
#define v8_cp_reginfo v8_cp_reginfo_x86_64
#define v8_el2_cp_reginfo v8_el2_cp_reginfo_x86_64
#define v8_el3_cp_reginfo v8_el3_cp_reginfo_x86_64
#define v8_el3_no_el2_cp_reginfo v8_el3_no_el2_cp_reginfo_x86_64
#define vapa_cp_reginfo vapa_cp_reginfo_x86_64
#define vbar_write vbar_write_x86_64
#define vfp_exceptbits_from_host vfp_exceptbits_from_host_x86_64
#define vfp_exceptbits_to_host vfp_exceptbits_to_host_x86_64
#define vfp_get_fpcr vfp_get_fpcr_x86_64
#define vfp_get_fpscr vfp_get_fpscr_x86_64
#define vfp_get_fpsr vfp_get_fpsr_x86_64
#define vfp_reg_offset vfp_reg_offset_x86_64
#define vfp_set_fpcr vfp_set_fpcr_x86_64
#define vfp_set_fpscr vfp_set_fpscr_x86_64
#define vfp_set_fpsr vfp_set_fpsr_x86_64
#define visit_end_implicit_struct visit_end_implicit_struct_x86_64
#define visit_end_list visit_end_list_x86_64
#define visit_end_struct visit_end_struct_x86_64
#define visit_end_union visit_end_union_x86_64
#define visit_get_next_type visit_get_next_type_x86_64
#define visit_next_list visit_next_list_x86_64
#define visit_optional visit_optional_x86_64
#define visit_start_implicit_struct visit_start_implicit_struct_x86_64
#define visit_start_list visit_start_list_x86_64
#define visit_start_struct visit_start_struct_x86_64
#define visit_start_union visit_start_union_x86_64
#define vmsa_cp_reginfo vmsa_cp_reginfo_x86_64
#define vmsa_tcr_el1_write vmsa_tcr_el1_write_x86_64
#define vmsa_ttbcr_raw_write vmsa_ttbcr_raw_write_x86_64
#define vmsa_ttbcr_reset vmsa_ttbcr_reset_x86_64
#define vmsa_ttbcr_write vmsa_ttbcr_write_x86_64
#define vmsa_ttbr_write vmsa_ttbr_write_x86_64
#define write_cpustate_to_list write_cpustate_to_list_x86_64
#define write_list_to_cpustate write_list_to_cpustate_x86_64
#define write_raw_cp_reg write_raw_cp_reg_x86_64
#define X86CPURegister32_lookup X86CPURegister32_lookup_x86_64
#define x86_op_defs x86_op_defs_x86_64
#define xpsr_read xpsr_read_x86_64
#define xpsr_write xpsr_write_x86_64
#define xscale_cpar_write xscale_cpar_write_x86_64
#define xscale_cp_reginfo xscale_cp_reginfo_x86_64
#endif
